@@ -44,11 +44,14 @@ assignOptions <- function(options) {
 		    #in Analysis "cross", AnalysisVariables can be "Force;Speed;mean". 1st is Y, 2nd is X. "mean" can also be "max"
 		    #Analysis "cross" can have a double XY plot, AnalysisVariables = "Speed,Power;Load;mean"
 		    #	1st: Speed,power are Y (left and right), 2n: Load is X.
-		    #In interssession, x should be along time. In order to recicle paintCrossVariables, a 4th member is sent: "Date".
+		    #In interssession, x can be date. In order to recicle paintCrossVariables, a 4th member is sent: "Date".
 		    #	Power;Load;mean;Date will be an Power / Date (with Load as seriesName)
 		    #	Speed;Load;mean;Date will be an Speed / Date (with Load as seriesName)
 		    #	Force;Load;mean;Date will be an Force / Date (with Load as seriesName)
 		    #
+		    #Intersession Pmax(F0,V0) has not Date on X, so AnalusisVariables are:
+		    # 	Pmax(F0,V0);Pmax(F0,V0);mean
+		    #
 		    #in Analysis "powerBars", AnalysisVariables can be:
 		    #	"TimeToPeakPower;Range", or eg: "NoTimeToPeakPower;NoRange"
 		    #
@@ -80,9 +83,17 @@ assignOptions <- function(options) {
 		    OperatingSystem	= options[28],	#if this changes, change it also at call_graph.R
 		    Debug		= options[31],
 		    CrossValidate	= options[32],
-		    TriggersOn		= as.numeric(unlist(strsplit(options[33], "\\;")))
-		    #TriggerOn on capture is +1/-1 to indicate use or not.
-		    #On analyze is first ms where trigger is pressed at each repetition, or -1 if they are not going to be used
+		    TriggersCut 	= options[33],  #if TRUE ten cut by triggers, else use TriggersOnList (if any) only for vertical ablines on instaneous graphs
+		    TriggersOnList	= as.numeric(unlist(strsplit(options[34], "\\;")))
+
+		    #Triggers:
+		    #  at capture.R
+		    #  		if triggers are used to cut: TriggersCut == TRUE, TriggersOnList == 1
+		    #  		if not use triggers: TriggersCut == FALSE, TriggersOnList == -1 #but nothing will be plotted on capture
+		    #  at graph.R
+		    # 		if triggers are used to cut: TriggersCut == TRUE, TriggersOnList == xxx, yyy, zzz, ...
+		    # 		... but if there are not enough triggers, then just plot
+		    #  		if not use triggers: TriggersCut == FALSE, TriggersOnList == xxx, yyy, zzz, ...
 
 		    #Unassigned here:
 		    #	englishWords [29]
@@ -90,6 +101,15 @@ assignOptions <- function(options) {
 		    ))
 }
 
+cutByTriggers <- function(op)
+{
+	if(op$TriggersCut == TRUE && op$TriggersOnList != -1)
+		return(TRUE);
+
+	return(FALSE);
+}
+
+
 #gearedDown comes as:
 #4 and should be converted to 4
 #-4 and should be converted to 1/4 : 0.25
@@ -701,8 +721,7 @@ findPropulsiveEnd <- function(accel, concentric, maxSpeedTInConcentric,
 		propulsiveEndsAt <- -g * sin(anglePush * pi / 180)
 	} else if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
 		massBodyUsed <- getMassBodyByExercise(massBody, exercisePercentBodyWeight)
-		
-		#propulsive phase ends at: [massBodyUsed*sin(anglePush) + massExtra*sin(angleWeight)] / (massBodyUsed + massExtra)
+		#propulsive phase ends at: g * [massBodyUsed*sin(anglePush) + massExtra*sin(angleWeight)] / (massBodyUsed + massExtra)
 		propulsiveEndsAt <- -g * (massBodyUsed * sin(anglePush * pi / 180) + massExtra * sin(angleWeight * pi / 180)) / (massBodyUsed + massExtra)
 	}
 
@@ -825,19 +844,18 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel,
                                    massBody, massExtra, massTotal,
                                    exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
 { 
-  force = NULL
-  if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
-    force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
-    } else if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY") {
-      force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel) / gearedDown
-    } else if(encoderConfigurationName == "LINEARONPLANE"){
-      force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
-    } else {
-      force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
-    }
-  power <- force*speed
-
-  return(list(mass=massTotal, force=force, power=power))
+        force = NULL
+        if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
+                force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(accel + g*sin(angleWeight * pi / 180))
+        } else if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY") {
+                force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel) / gearedDown
+        } else if(encoderConfigurationName == "LINEARONPLANE"){
+                force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
+        } else {
+                force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
+        }
+        power <- force*speed
+        return(list(mass=massTotal, force=force, power=power))
 }
 
 #diameter: diameter of the axis (where string is wrapped)
@@ -898,9 +916,9 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
               encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
     #With a moving pulley, the displacement of the body is half of the displacement of the rope in the inertial machine side
     #So, the multiplier is 4 instead of 2 to get the rotational kinematics.
-    angle = position.m * 4 / diameter.m
-    angleSpeed = speed * 4 / diameter.m
-    angleAccel = accel * 4 / diameter.m
+    angle = position.m * 2 / gearedDown / diameter.m
+    angleSpeed = speed * 2 / gearedDown / diameter.m
+    angleAccel = accel * 2 / gearedDown / diameter.m
     anglePush = 90 #TODO: send from C#
     #The configuration covers horizontal, vertical and inclined movements
     #If the movement is vertical g*sin(alpha) = g
