@@ -62,7 +62,9 @@ assignOptions <- function(options)
                 hline50fmax.raw 	= options[10],
                 hline50fmax.fitted 	= options[11],
                 drawRfdOptions          = drawRfdOptions,
-                drawImpulseOptions      = options[16]
+                drawImpulseOptions      = options[16],
+		testLength 		= as.numeric(options[17]),
+		title 	 		= options[18]
         ))
 }
 
@@ -88,28 +90,29 @@ getForceModel <- function(time, force, startTime, # startTime is the instant whe
                           fmaxi,           # fmaxi is the initial value for the force. For numeric purpouses
                           initf)              # initf is the sustained force before the increase
 {
-
-        timeTrimmed = time[which(time == startTime):length(time)]
-        forceTrimmed = force[which(time == startTime):length(time)]
-        timeTrimmed = timeTrimmed -  startTime
-        data = data.frame(time = timeTrimmed, force = forceTrimmed)
+        #We force that the function crosses the (0,0) to better fit the monoexponential
+        force = force
+        time = time - startTime
+        
+        data = data.frame(time = time, force = force)
         model = nls( force ~ fmax*(1-exp(-K*time)), data, start=list(fmax=fmaxi, K=1), control=nls.control(warnOnly=TRUE))
         fmax = summary(model)$coeff[1,1]
         K = summary(model)$coeff[2,1]
-        return(list(fmax = fmax - initf, K = K))
+        return(list(fmax = fmax, K = K))
 }
 
 getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentChange = 5)
 {
         originalTest = read.csv(inputFile, header = F, dec = op$decimalChar, sep = ";", skip = 2)
         colnames(originalTest) <- c("time", "force")
-        originalTest$time = as.numeric(originalTest$time)
+        originalTest$time = as.numeric(originalTest$time / 1000000)  # Time is converted from microseconds to seconds
         
         #Instantaneous RFD
         rfd = getRFD(originalTest)
         
         #Finding the decrease of the foce to detect the end of the maximum voluntary force
-        trimmingSamples = getTrimmingSamples(originalTest, rfd, averageLength = averageLength, percentChange = percentChange)
+        trimmingSamples = getTrimmingSamples(originalTest, rfd, averageLength = averageLength, percentChange = percentChange,
+					     testLength = op$testLength)
         startSample = trimmingSamples$startSample
         startTime = originalTest$time[startSample]
         
@@ -117,51 +120,31 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
         endTime = originalTest$time[endSample]
         
         # Initial force. It is needed to perform an initial steady force to avoid jerks and great peaks in the force
-        if(startSample < 11)
+        if(startSample <= 20)
         {
                 print("Not previos steady tension applied before performing the test")
                 return(NA)
         }
+        
+
         initf = mean(originalTest$force[(startSample - 20):(startSample - 10)]) #ATENTION. This value is different from f0.raw
-        fmax.raw = max(originalTest$force)
+        fmax.raw = max(originalTest$force[startSample:endSample])
         
         #Trimming the data before and after contraction
-        test = originalTest[startSample:endSample,]
+        testTrimmed = originalTest[startSample:endSample,]
         
         f.smoothed = getMovingAverageForce(originalTest, averageLength = averageLength) #Running average with equal weight averageLength seconds
-        fmax.smoothed = max(f.smoothed, na.rm =T)
+        fmax.smoothed = max(f.smoothed, na.rm = TRUE)
         
-        model = getForceModel(test$time, test$force, startTime, fmax.smoothed, initf)
-        f.fitted = initf + model$fmax*(1-exp(-model$K*(originalTest$time - startTime)))
+        model = getForceModel(testTrimmed$time, testTrimmed$force, startTime, fmax.smoothed, initf)
+        f.fitted =model$fmax*(1-exp(-model$K*(originalTest$time - startTime)))
         
-        f0.raw = test$force[1]                                                       #Force at t=0ms. ATENTION. This value is different than initf
-        f100.raw = test$force[which.min(abs(test$time - (startTime + 0.1)))]         #Force at t=100ms
-        f100.fitted = model$fmax*(1 - exp( - model$K * 0.1)) + initf
-        f200.raw = test$force[which.min(abs(test$time - (startTime + 0.2)))]         #Force at t=200ms
-        f200.fitted = model$fmax*(1 - exp( - model$K * 0.2)) + initf
-        f90.raw = test$force[which.min(abs(test$time - (startTime + 0.09)))]         #Force at t=90ms
-        f110.raw = test$force[which.min(abs(test$time - (startTime + 0.11)))]        #Force at t=110ms
-        f190.raw = test$force[which.min(abs(test$time - (startTime + 0.19)))]        #Force at t=190ms
-        f210.raw = test$force[which.min(abs(test$time - (startTime + 0.21)))]        #Force at t=210ms
-        f50fmax.raw = test$force[which.min(abs(test$force - fmax.raw/2))]
-        f50fmax.fitted = (model$fmax + initf)/2
+        f0.raw = testTrimmed$force[1]                                                  # Force at t=0ms. ATENTION. This value is different than initf
+        rfd0.fitted = model$fmax * model$K                                      # RFD at t=0ms using the exponential model
+        tfmax.raw = testTrimmed$time[which.min(abs(testTrimmed$force - fmax.raw))]            # Time needed to reach the Fmax
         
-        rfd0.fitted = model$fmax * model$K # RFD at t=0ms using the exponential model
-        rfd100.raw = (f110.raw - f90.raw) / 0.02  #rfd at t= 100ms. Mean value using de previous and the next value and divided by 20ms
-        rfd0_100.raw = (f100.raw - f0.raw) / 0.1  #Mean rfd during t=[0..100]
-        rfd0_100.fitted = (f100.fitted - initf) / 0.1
-        rfd200.raw = (f210.raw - f190.raw) / 0.02
-        rfd0_200.raw = (f200.raw - f0.raw) / 0.2
-        rfd0_200.fitted = (f200.fitted - initf) / 0.2
-        rfd100_200.raw = ((f200.raw - f100.raw) * 10)
-        
-        tfmax.raw = test$time[which.min(abs(test$force - fmax.raw))]
-        t50fmax.raw = test$time[which.min(abs(test$force - fmax.raw/2))]
-        t50fmax.fitted = originalTest$time[which.min(abs(f.fitted - (model$fmax + initf)/ 2))]
-        rfd50pfmax.raw = (test$force[which.min(abs(test$force - fmax.raw/2)) + 1] - test$force[which.min(abs(test$force - fmax.raw/2)) - 1]) * 100 / 2 #RFD at the moment that the force is 50% of the fmax
-        rfd50pfmax.fitted = model$fmax * model$K * exp(-model$K*(t50fmax.fitted - startTime))
-        
-        return(list(nameOfFile = inputFile, time = originalTest[, "time"], fmax.fitted = model$fmax, k.fitted = model$K,
+        return(list(nameOfFile = inputFile, time = originalTest[, "time"],
+                    fmax.fitted = model$fmax, k.fitted = model$K, tau.fitted = 1/model$K,
                     startTime = startTime, endTime = endTime,
                     startSample = startSample, endSample = endSample,
                     totalSample = length(originalTest$time),
@@ -169,22 +152,7 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
                     f0.raw = f0.raw,
                     fmax.raw = fmax.raw, fmax.smoothed = fmax.smoothed,
                     tfmax.raw = tfmax.raw,
-                    f100.raw = f100.raw,
-                    f100.fitted = f100.fitted,
-                    f200.raw = f200.raw,
-                    f200.fitted = f200.fitted,
-                    f50fmax.raw = f50fmax.raw,
-                    f50fmax.fitted = f50fmax.fitted,
-                    rfd0.fitted = rfd0.fitted,
-                    rfd100.raw = rfd100.raw,
-                    rfd0_100.raw = rfd0_100.raw,
-                    rfd0_100.fitted = rfd0_100.fitted,
-                    rfd0_200.raw = rfd0_200.raw,
-                    rfd0_200.fitted = rfd0_200.fitted,
-                    rfd200.raw = rfd200.raw,
                     rfd = rfd,
-                    t50fmax.raw = t50fmax.raw, rfd50pfmax.raw = rfd50pfmax.raw,
-                    t50fmax.fitted = t50fmax.fitted, rfd50pfmax.fitted = rfd50pfmax.fitted,
                     f.raw = originalTest$force, f.smoothed = f.smoothed, f.fitted = f.fitted,
                     endTime = endTime))
 }
@@ -194,6 +162,10 @@ drawDynamicsFromLoadCell <- function(
         hline50fmax.raw=F, hline50fmax.fitted=F,
         rfdDrawingOptions, xlimits = NA)
 {
+        dynamics$time = dynamics$time - dynamics$startTime
+        dynamics$tfmax.raw = dynamics$tfmax.raw - dynamics$startTime
+        dynamics$endTime = dynamics$endTime - dynamics$startTime
+        dynamics$startTime = 0
         if(is.na(dynamics$time[1]))
         {
                 print("Dynamics not available:")
@@ -215,23 +187,25 @@ drawDynamicsFromLoadCell <- function(
         #Plotting raw data from startTime to endTime (Only the analysed data)
         if (!is.na(xlimits[1])){
                 xWidth = xlimits[2] - xlimits[1]
-                plot(dynamics$time[dynamics$startSample:dynamics$endSample] , dynamics$f.raw[dynamics$startSample:dynamics$endSample],
+                plot(dynamics$time[dynamics$startSample:dynamics$endSample], dynamics$f.raw[dynamics$startSample:dynamics$endSample],
                      type="l", xlab="Time[s]", ylab="Force[N]",
                      xlim = xlimits, ylim=c(0, yHeight),
                      #main = dynamics$nameOfFile,
+		     main = op$title,
 		     yaxs= "i", xaxs = "i")
                 xmin = xlimits[1]
                 xmax = xlimits[2]
-                points(dynamics$time[dynamics$startSample:dynamics$endSample] , dynamics$f.raw[dynamics$startSample:dynamics$endSample])
+                #points(dynamics$time[dynamics$startSample:dynamics$endSample] , dynamics$f.raw[dynamics$startSample:dynamics$endSample])
         } else if (is.na(xlimits[1])){
-                xmin = dynamics$startTime - (dynamics$endTime - dynamics$startTime)*0.1
-                xmax = min(c(dynamics$endTime*1.1 - dynamics$startTime*0.1, dynamics$t0 + 1))
+                xmin = -0.2
+                xmax = dynamics$endTime*1.1 - dynamics$startTime*0.1
                 xWidth = xmax - xmin
-                plot(dynamics$time[dynamics$startSample:dynamics$endSample] , dynamics$f.raw[dynamics$startSample:dynamics$endSample],
+                plot(dynamics$time[dynamics$startSample:dynamics$endSample], dynamics$f.raw[dynamics$startSample:dynamics$endSample],
                      type="l", xlab="Time[s]", ylab="Force[N]",
                      xlim = c(xmin, xmax),
                      ylim=c(0, yHeight),
                      #main = dynamics$nameOfFile,
+		     main = op$title,
 		     yaxs= "i", xaxs = "i")
         }
         
@@ -257,8 +231,8 @@ drawDynamicsFromLoadCell <- function(
                 print(impulseOptions)
                 if(impulseOptions$type == "IMP_RANGE")
                 {
-                        startImpulseSample = which.min(abs(dynamics$time - (dynamics$startTime + impulseOptions$start/1000)))
-                        endImpulseSample = which.min(abs(dynamics$time - (dynamics$startTime + impulseOptions$end/1000)))
+                        startImpulseSample = which.min(abs(dynamics$time - impulseOptions$start/1000))
+                        endImpulseSample = which.min(abs(dynamics$time - impulseOptions$end/1000))
                 } else if(impulseOptions$type == "IMP_UNTIL_PERCENT_F_MAX")
                 {
                         startImpulseSample = dynamics$startSample
@@ -274,6 +248,7 @@ drawDynamicsFromLoadCell <- function(
 
                 if(impulseOptions$impulseFunction == "RAW")
                 {
+                        impulseColor = "black"
                         
                         #Drawing the area under the force curve (Impulse)
                         polygon(c(dynamics$time[startImpulseSample:endImpulseSample], dynamics$time[endImpulseSample] , dynamics$time[startImpulseSample]),
@@ -297,6 +272,7 @@ drawDynamicsFromLoadCell <- function(
                         impulse = impulse / 2
                 } else if(impulseOptions$impulseFunction == "FITTED")
                 {
+                        impulseColor = "blue"
                         
                         #Drawing the area under the force curve (Impulse)
                         polygon(c(dynamics$time[startImpulseSample:endImpulseSample], dynamics$time[endImpulseSample] , dynamics$time[startImpulseSample]),
@@ -335,16 +311,35 @@ drawDynamicsFromLoadCell <- function(
         
         #Plotting fitted data
         lines(dynamics$time, dynamics$f.fitted, col="blue")
-        #text(x = dynamics$time[dynamics$totalSample] - 0.1, y = dynamics$fmax.fitted + dynamics$initf,
-        #     labels = paste("Fmax =", round(dynamics$fmax.fitted + dynamics$initf, digits = 2), "N"), pos = 1, col="blue")
-        abline(h = dynamics$fmax.fitted + dynamics$initf, lty = 2, col = "blue")
-        text(x = xmin + (xmax - xmin)*0.25, y = dynamics$fmax.fitted + dynamics$initf,
-             labels = paste("Fmax =", round(dynamics$fmax.fitted + dynamics$initf,digits = 2), "N"),
+        abline(h = dynamics$fmax.fitted, lty = 2, col = "blue")
+        text(x = xmin + (xmax - xmin)*0.25, y = dynamics$fmax.fitted,
+             labels = paste("Fmax =", round(dynamics$fmax.fitted,digits = 2), "N"),
              col = "blue", pos = 3, cex = 1.5)
         
         #Plottting smoothed data
         #lines(dynamics$time, dynamics$f.smoothed, col="grey")
         
+        #Plotting RFD
+        #lines(dynamics$time, dynamics$rfd/100, col = "red")
+        
+        #Plotting tau
+        abline(v = dynamics$tau.fitted, col = "green4", lty = 3)
+        abline(h = dynamics$fmax.fitted*0.6321206, col = "green4", lty = 3)
+        points(dynamics$tau.fitted, dynamics$fmax.fitted*0.6321206, col = "green4")
+        arrows(x0 = 0, y0 = dynamics$f0.raw,
+               x1 = dynamics$tau.fitted, y1 = dynamics$f0.raw)
+        text(x = (dynamics$tau.fitted / 2), y = dynamics$f0.raw,
+              labels = paste("τ =", round(dynamics$tau.fitted, digits = 2), "s"), pos = 3, cex = 1.5, col = "blue")
+        # text(x = (dynamics$tau.fitted / 2), y = -20,
+        #      labels = paste("τ =", round(dynamics$tau.fitted, digits = 2), "s"), pos = 3, cex = 1.5, xpd = TRUE)
+        
+        arrows(x0 = 0, y0 = 0,
+               x1 = 0, y1 = dynamics$fmax.fitted*0.6321206)
+        
+        text(x = 0, y = dynamics$fmax.fitted*0.6321206 / 2,
+              labels = "63% of fmax", pos = 2, cex = 1.5, srt = 90, col = "blue")
+        
+        #Plotting fmax.raw
         text( x = dynamics$tfmax.raw, y = dynamics$fmax.raw,
               labels = paste("Fmax = ", round(dynamics$fmax.raw, digits=2), " N", sep=""), pos = 3, cex = 1.5)
         points(x = dynamics$tfmax.raw, y = dynamics$fmax.raw)
@@ -358,8 +353,8 @@ drawDynamicsFromLoadCell <- function(
                 text( x = dynamics$t50fmax.raw + 0.5, y = dynamics$fmax.raw/2, labels = paste("Fmax/2 =", round(dynamics$fmax.raw/2, digits=2), "N", sep=""), pos = 3)
         }
         if(hline50fmax.fitted){
-                abline( h = (dynamics$fmax.fitted + dynamics$initf)/2, lty = 2, col = "blue")
-                text( x =dynamics$t50fmax.fitted + 0.5, y = (dynamics$fmax.fitted + dynamics$initf)/2, labels = paste("Fmax/2 =", round((dynamics$fmax.fitted + dynamics$initf)/2, digits=2), "N", sep=""), pos = 1, col="blue")
+                abline( h = (dynamics$fmax.fitted)/2, lty = 2, col = "blue")
+                text( x =dynamics$t50fmax.fitted + 0.5, y = (dynamics$fmax.fitted)/2, labels = paste("Fmax/2 =", round((dynamics$fmax.fitted)/2, digits=2), "N", sep=""), pos = 1, col="blue")
         }
         if(vline50fmax.raw){
                 abline(v = dynamics$t50fmax.raw, lty = 2)
@@ -381,9 +376,15 @@ drawDynamicsFromLoadCell <- function(
         print("-----------RFD-----------")
         print(paste("op$drawRfdOptions =", op$drawRfdOptions))
         
-        legendText = c(paste("Fmax =", round(dynamics$fmax.fitted, digits = 2), "N"), paste("K = ", round(dynamics$k.fitted, digits = 2), "N/s"))
-        legendColor = c("blue", "blue")
+        legendText = c(
+		       paste("Fmax =", round(dynamics$fmax.fitted, digits = 2), "N"),
+		       paste("K = ", round(dynamics$k.fitted, digits = 2),"s⁻¹"),
+		       paste("τ = ", round(dynamics$tau.fitted, digits = 2),"s")
+		       )
+        legendColor = c("blue", "blue", "blue")
         
+        #The coordinates where the lines and dots are plotted are calculated with the sampled data in raw and fitted data.
+        #The slopes are calculated in that points
         for (n in 1:length(rfdDrawingOptions))
         {
                 RFDoptions = readRFDOptions(op$drawRfdOptions[n])
@@ -397,11 +398,15 @@ drawDynamicsFromLoadCell <- function(
                 {
                         
                         RFD = NULL
-                        sample2 = NA
-                        pointForce1 = NA
-                        pointForce2 = NA
+                        pointForce1 = NULL
                         color = ""
                         
+                        #Needed when only one point is plotted
+                        sample2 = NULL
+                        pointForce2 = NULL
+                        time2 = NULL
+                        force2 = NULL
+                        
                         if(RFDoptions$rfdFunction == "FITTED")
                         {
                                 color = "blue"
@@ -412,96 +417,94 @@ drawDynamicsFromLoadCell <- function(
                         
                         if(RFDoptions$type == "INSTANTANEOUS") # TODO: || percent ...(all except AVG)
                         {
+                                #Converting RFDoptions$start to seconds
+                                RFDoptions$start = RFDoptions$start/1000
+                                
+                                time1 = RFDoptions$start
+                                
                                 if (RFDoptions$rfdFunction == "FITTED")
                                 {
-                                        #Slope of the line
-                                        RFD = dynamics$fmax.fitted * dynamics$k.fitted * exp(-dynamics$k.fitted * RFDoptions$start) 
+                                        #Slope of the line. Deriving the model:
+                                        RFD = dynamics$fmax.fitted * dynamics$k.fitted * exp(-dynamics$k.fitted * time1)
                                         #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$fmax.fitted*(1 - exp(-dynamics$k.fitted * RFDoptions$start)) + dynamics$initf
+                                        force1 = dynamics$fmax.fitted * (1 - exp(-dynamics$k.fitted * RFDoptions$start))
                                         
-                                        legendText = c(legendText, paste("RFD", RFDoptions$start, " = ", round(RFD, digits = 1), " N/s", sep = ""))
+                                        legendText = c(legendText, paste("RFD", RFDoptions$start*1000, " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "blue")
                                         
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
-                                        color = "black"
-                                        sample1 =  which.min(abs(dynamics$time - dynamics$startTime - RFDoptions$start))
-                                        
-                                        #Slope of the line
-                                        RFD = dynamics$rfd[sample1]
+                                        #Slope of the line of the sampled point.
+                                        RFD = getForceAtTime(dynamics$time, dynamics$rfd, time1)
                                         
                                         #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$f.raw[sample1]
+                                        force1 = getForceAtTime(dynamics$time, dynamics$f.raw, RFDoptions$start)
                                         
-                                        legendText = c(legendText, paste("RFD", RFDoptions$start, " = ", round(RFD, digits = 1), " N/s", sep = ""))
+                                        legendText = c(legendText, paste("RFD", RFDoptions$start*1000, " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "black")
                                 }
                         } else if(RFDoptions$type == "AVERAGE")
                         {
+                                #Converting RFDoptions to seconds
+                                RFDoptions$start = RFDoptions$start/1000
+                                RFDoptions$end = RFDoptions$end/1000
+                                
+                                time1 = RFDoptions$start
+                                time2 = RFDoptions$end
+                                
                                 if (RFDoptions$rfdFunction == "FITTED")
                                 {
-                                        #Slope of the line
-                                        RFD = dynamics$fmax.fitted*(exp( -dynamics$k.fitted * RFDoptions$start) - exp( -dynamics$k.fitted * RFDoptions$end)) / (RFDoptions$end - RFDoptions$start)
-                                        #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$fmax.fitted*(1 - exp( -dynamics$k.fitted * RFDoptions$start)) + dynamics$initf
+                                        #Y axis of the points
+                                        force1 = dynamics$fmax.fitted * (1 - exp(-dynamics$k.fitted * RFDoptions$start))
+                                        force2 = dynamics$fmax.fitted * (1 - exp(-dynamics$k.fitted * RFDoptions$end))
                                         
-                                        legendText = c(legendText, paste("RFD", RFDoptions$start, "-", RFDoptions$end, " = ", round(RFD, digits = 1), " N/s", sep = ""))
+                                        #Slope of the line
+                                        RFD = (force2 - force1) / (time2 - time1)
+                                        
+                                        legendText = c(legendText, paste("RFD", RFDoptions$start*1000, "-", RFDoptions$end*1000, " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "blue")
                                         
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
-                                        
-                                        sample1 =  which.min(abs(dynamics$time - dynamics$startTime - RFDoptions$start/1000))
-                                        sample2 = which.min(abs(dynamics$time - dynamics$startTime - RFDoptions$end/1000))
+                                        force1 = getForceAtTime(dynamics$time, dynamics$f.raw, RFDoptions$start)
+                                        force2 = getForceAtTime(dynamics$time, dynamics$f.raw, RFDoptions$end)
                                         
                                         #Slope of the line
-                                        RFD = (dynamics$f.raw[sample2] - dynamics$f.raw[sample1]) / (dynamics$time[sample2] - dynamics$time[sample1])
+                                        RFD = (force2 - force1) / (time2 - time1)
                                         
-                                        #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$f.raw[sample1]
-                                        pointForce2 = dynamics$f.raw[sample2]
-                                        
-                                        legendText = c(legendText, paste("RFD", RFDoptions$start, "-", RFDoptions$end, " = ", round(RFD, digits = 1), " N/s", sep = ""))
+                                        legendText = c(legendText, paste("RFD", RFDoptions$start*1000, "-", RFDoptions$end*1000, " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "black")
                                 }
                                 
                         } else if(RFDoptions$type == "PERCENT_F_MAX")
                         {
+                                percent = RFDoptions$start
                                 
                                 if (RFDoptions$rfdFunction == "FITTED")
                                 {
+                                        time1 = - log(1 - percent/100) / dynamics$k.fitted
                                         
-                                        #Force that is the % of the raw fmax
-                                        fpfmax = dynamics$fmax.raw*RFDoptions$start/100
-                                        
-                                        #Translating RFDoptions$start to time in seconds
-                                        percent = RFDoptions$start
-                                        RFDoptions$start = dynamics$time[which.min(abs(dynamics$f.fitted - fpfmax))] - dynamics$startTime
-                                        
-                                        #RFD at the point with a % of the fmax.raw
-                                        RFD = dynamics$fmax.fitted * dynamics$k.fitted * exp(-dynamics$k.fitted * RFDoptions$start)
+                                        #RFD at the point with a % of the fmax.fitted
+                                        RFD = dynamics$fmax.fitted * dynamics$k.fitted * exp(-dynamics$k.fitted * time1)
                                         
                                         #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$fmax.fitted*(1 - exp(-dynamics$k.fitted * RFDoptions$start)) + dynamics$initf
+                                        
+                                        force1 = dynamics$fmax.fitted * (1 - exp(-dynamics$k.fitted * time1))
                                         
                                         legendText = c(legendText, paste("RFD", percent, "%Fmax", " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "blue")
                                         
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
-                                        #Calculing at which sample force is equal to the percent of fmax specified in RFDoptions$start
-                                        sample1 = which.min(abs(dynamics$f.raw - dynamics$fmax.raw*RFDoptions$start/100))
-                                        
-                                        #Translating RFDoptions$start to time in seconds
-                                        RFDoptions$start = dynamics$time[sample1] - dynamics$startTime
+                                        time1 = getTimeAtForce(dynamics$time, dynamics$f.raw, dynamics$fmax.raw * percent / 100)
                                         
                                         #Slope of the line
-                                        RFD = dynamics$rfd[sample1]
+                                        RFD = getForceAtTime(dynamics$time, dynamics$rfd, time1)
                                         
                                         #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$f.raw[sample1]
+                                        force1 = getForceAtTime(dynamics$time, dynamics$f.raw, time1)
                                         
-                                        legendText = c(legendText, paste("RFD", RFDoptions$start, "%", "Fmax", " = ", round(RFD, digits = 1), " N/s", sep = ""))
+                                        legendText = c(legendText, paste("RFD", percent, "%", "Fmax", " = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "black")
                                         
                                 }
@@ -511,20 +514,34 @@ drawDynamicsFromLoadCell <- function(
                                 if (RFDoptions$rfdFunction == "FITTED")
                                 {
                                         #max is always in the initial point.
+                                        time1 = 0
+                                        
+                                        #Slope of the line. Deriving the model:
+                                        RFD = dynamics$fmax.fitted * dynamics$k.fitted
+                                        
+                                        #Y coordinate of a point of the line
+                                        pointForce1 = 0
+                                        
+                                        force1 = 0
+                                        
+                                        legendText = c(legendText, paste("RFDMax", " = ", round(RFD, digits = 1), " N/s", sep = ""))
+                                        legendColor = c(legendColor, "blue")
                                         
                                 } else if(RFDoptions$rfdFunction == "RAW")
                                 {
-                                        #Calculing the sample at which the rfd is max
-                                        sample1 = which.max(dynamics$rfd)
+                                        #Calculing the sample at which the rfd is max. Using only the initial
+                                        sample1 = dynamics$startSample + which.max(dynamics$rfd[dynamics$startSample:dynamics$endSample]) -1
+                                        
+                                        time1 = dynamics$time[sample1]
                                         
                                         #Translating RFDoptions$start to time in seconds
-                                        RFDoptions$start = dynamics$time[sample1] - dynamics$startTime
+                                        RFDoptions$start = dynamics$time[sample1]
                                         
                                         #Slope of the line
                                         RFD = dynamics$rfd[sample1]
                                         
                                         #Y coordinate of a point of the line
-                                        pointForce1 = dynamics$f.raw[sample1]
+                                        force1 = dynamics$f.raw[sample1]
                                         
                                         legendText = c(legendText, paste("RFDmax = ", round(RFD, digits = 1), " N/s", sep = ""))
                                         legendColor = c(legendColor, "black")
@@ -533,37 +550,27 @@ drawDynamicsFromLoadCell <- function(
                                 
                         }
                         
-                        #The Y coordinate of the line at t=0
-                        intercept = pointForce1 - RFD * (dynamics$startTime + RFDoptions$start)
+                        #The Y coordinate of the line when it crosses the Y axis
+                        intercept = force1 - RFD * time1
                         
                         #The slope of the line seen in the screen(pixels units), NOT in the time-force units
                         windowSlope = RFD*(plotHeight/yHeight)/(plotWidth/xWidth)
                         
                         #Drawing the line
-                        abline(a = intercept, b = RFD, lty = 2, col = color)
                         text(x = (yHeight - 5 - intercept)/RFD, y = yHeight - 5,
                              label = paste(round(RFD, digits=0), "N/s"),
                              srt=atan(windowSlope)*180/pi, pos = 2, col = color)
                         #Drawing the points where the line touch the function
-                        points(x = c(RFDoptions$start + dynamics$startTime, RFDoptions$end/1000 + dynamics$startTime), y = c(pointForce1, pointForce2), col = color)
-
+                        points(x = c(time1, time2), y = c(force1, force2), col = color)
+                        abline(a = intercept, b = RFD, lty = 2, col = color)
                 }
         }
-
-	if(impulseLegend != "")
+	if(impulseLegend != ""){
 		legendText = c(legendText, impulseLegend)
+                legendColor = c(legendColor, impulseColor)
+	}
 
 	legend(x = xmax, y = dynamics$fmax.fitted/2, legend = legendText, xjust = 1, yjust = 0.1, text.col = legendColor)
-        
-        #Plotting instantaneous RFD
-        # par(new = T)
-        # plot(dynamics$time[(dynamics$startSample):dynamics$endSample], dynamics$rfd[(dynamics$startSample):dynamics$endSample],
-        #      type = "l", col = "red", axes = F,
-        #      xlim = c(xmin, xmax), xlab = "", ylab = "", yaxs= "i", xaxs = "i")
-        # lines(dynamics$time[1:(dynamics$startSample)], dynamics$rfd[1:dynamics$startSample], col = "orange")
-        # lines(dynamics$time[dynamics$endSample:dynamics$totalSample], dynamics$rfd[dynamics$endSample:dynamics$totalSample], col = "orange")
-        # axis(4, col = "red", line = 1)
-        
 }
 
 getDynamicsFromLoadCellFolder <- function(folderName, resultFileName, export2Pdf)
@@ -604,36 +611,54 @@ getDynamicsFromLoadCellFolder <- function(folderName, resultFileName, export2Pdf
         
 }
 
-#Finds the sample in which the force decrease a given percentage of the maximum force.
+#Finds the sample in which the force start incresing (RFD > 20% of maxRFD)
+#and decrease a given percentage of the maximum force.
 #The maximum force is calculed from the moving average of averageLength seconds
-getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.1, percentChange = 5)
+getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.1, percentChange = 5, testLength = -1, startDetectingMethod = "SD")
 {
         movingAverageForce = getMovingAverageForce(test, averageLength = 0.1)
-        #maxAverageForce = max(movingAverageForce, na.rm = T)
-        #maxSample = min(which(movingAverageForce == maxAverageForce), na.rm = T)
         maxRFD = max(rfd[2:(length(rfd) - 1)])
         
-        #Detecting an RFD 
-        startSample = 2
-        
-        while(rfd[startSample] <= maxRFD*0.2)
-        {
-                startSample = startSample + 1
-        }
-        
-        
-        endSample = startSample + 1
-        maxAverageForce = movingAverageForce[endSample]
-        while(movingAverageForce[endSample] > maxAverageForce*(100 - percentChange) / 100 &
-              endSample < length(test$time))
-        {
-                if(movingAverageForce[endSample] > maxAverageForce)
+        #Detecting when the force is greater of the mean + 3*SD of 20 samples
+        #See Rate of force development: physiological and methodological considerations. Nicola A. Maffiuletti1 et al.
+        if (startDetectingMethod == "SD"){
+                startSample = 21
+                while(test$force[startSample] < mean(test$force[startSample:(startSample - 20)]) + 3*sd(test$force[startSample:(startSample - 20)]))
                 {
-                        maxAverageForce = movingAverageForce[endSample]
+                        startSample = startSample + 1
+                }
+                
+                while(test$force[startSample] - test$force[startSample -1] >= 0){ #Detecting the sample to decrease
+                        startSample = startSample - 1
+                }
+                
+        #Detecting when accurs a greate growth of the force
+        } else if (startDetectingMethod == "RFD"){
+                startSample = 2
+                while(rfd[startSample] <= maxRFD*0.2)
+                {
+                        startSample = startSample + 1
                 }
-                endSample = endSample + 1
         }
         
+        if (testLength <= -1){
+                endSample = startSample + 1
+                maxAverageForce = movingAverageForce[endSample]
+                while(movingAverageForce[endSample] > maxAverageForce*(100 - percentChange) / 100 &
+                      endSample < length(test$time))
+                {
+                        if(movingAverageForce[endSample] > maxAverageForce)
+                        {
+                                maxAverageForce = movingAverageForce[endSample]
+                        }
+                        endSample = endSample + 1
+                }
+        } else if(testLength >= 0 && testLength < 0.1){
+                print("Test interval too short")
+        } else {
+                endSample = which.min(abs(test$time[startSample] + testLength - test$time))
+        }
+
         return(list(startSample = startSample, endSample = endSample))
 }
 
@@ -704,6 +729,50 @@ readImpulseOptions <- function(optionsStr)
         } 
 }
 
+#Function to get the interpolated force at a given time in seconds)
+getForceAtTime <- function(time, force, desiredTime){
+        #find the closest sample
+        closestSample = which.min(abs(time - desiredTime))
+        
+        if(time[closestSample] - desiredTime >= 0){
+                previousSample = closestSample - 1
+                nextSample = closestSample
+        } else if(time[closestSample] - desiredTime < 0){
+                previousSample = closestSample
+                nextSample = closestSample + 1
+        }
+        print("Samples:")
+        print(paste(previousSample, nextSample))
+        print("Times:")
+        print(paste(time[previousSample], time[nextSample]))
+        print("Forces:")
+        print(paste(force[previousSample], force[nextSample]))
+        
+        #Interpolation between two samples
+        desiredForce = force[previousSample] + ((force[nextSample] - force[previousSample]) / (time[nextSample] - time[previousSample]))*(desiredTime - time[previousSample])
+        print("DesiredForce:")
+        print(desiredForce)
+        return(desiredForce)
+}
+
+#Function to get the interpolated time at a given force in N
+getTimeAtForce <- function(time, force, desiredForce){
+        #find the closest sample
+        nextSample = 1
+        while (force[nextSample] < desiredForce){
+                nextSample = nextSample +1
+        }
+        
+        previousSample = nextSample - 1
+        
+        if(force[nextSample] == desiredForce){
+                desiredTime = time[nextSample]
+        } else {
+                desiredTime = time[previousSample] + (desiredForce  - force[previousSample]) * (time[nextSample] - time[previousSample]) / (force[nextSample] - force[previousSample])
+        }
+        return(desiredTime)
+}
+
 
 prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
 dynamics = getDynamicsFromLoadCellFile(dataFile, op$averageLength, op$percentChange)
