@@ -24,13 +24,11 @@ using System.IO;
 
 public class Config
 {
-	public enum AutodetectPortEnum { ACTIVE, DISCARDFIRST, INACTIVE }
-	public enum SessionModeEnum { STANDARD, UNIQUE }
+	public enum SessionModeEnum { STANDARD, UNIQUE, MONTHLY }
 
-	public bool Maximized;
+	public Preferences.MaximizedTypes Maximized;
 	public bool CustomButtons;
 	public bool UseVideo;
-	public AutodetectPortEnum AutodetectPort;
 	public bool OnlyEncoderGravitatory;
 	public bool OnlyEncoderInertial;
 	public bool EncoderCaptureShowOnlyBars;
@@ -39,20 +37,19 @@ public class Config
 	public bool PersonWinHide;
 	public bool EncoderAnalyzeHide;
 	public SessionModeEnum SessionMode;
+	public bool Compujump;
+	public string CompujumpServerURL = "";
+	public int CompujumpStationID = -1;
+	public Constants.Menuitem_modes CompujumpStationMode = Constants.Menuitem_modes.UNDEFINED;
 	public string RunScriptOnExit;
 
 	public Config()
 	{
-		Maximized = false;
+		/*
+		Maximized = Preferences.MaximizedTypes.NO;
 		CustomButtons = false;
 		UseVideo = true;
 		
-		//currently disabled AutodetectPort by default on MACOSX
-		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX)
-			AutodetectPort = AutodetectPortEnum.INACTIVE;
-		else
-			AutodetectPort = AutodetectPortEnum.ACTIVE;
-
 		OnlyEncoderGravitatory = false;
 		OnlyEncoderInertial = false;
 		EncoderCaptureShowOnlyBars = false;
@@ -60,9 +57,48 @@ public class Config
 		PersonWinHide = false;
 		EncoderAnalyzeHide = false;
 		SessionMode = SessionModeEnum.STANDARD;
+		Compujump = false;
 		RunScriptOnExit = "";
+		*/
 	}
 
+	public void Read()
+	{
+		string contents = Util.ReadFile(UtilAll.GetConfigFileName(), false);
+		if (contents != null && contents != "") 
+		{
+			string line;
+			using (StringReader reader = new StringReader (contents)) {
+				do {
+					line = reader.ReadLine ();
+
+					if (line == null)
+						break;
+					if (line == "" || line[0] == '#')
+						continue;
+
+					string [] parts = line.Split(new char[] {'='});
+					if(parts.Length != 2)
+						continue;
+
+					if(parts[0] == "Compujump" && Util.StringToBool(parts[1]))
+						Compujump = true;
+					else if(parts[0] == "CompujumpServerURL" && parts[1] != "")
+						CompujumpServerURL = parts[1];
+					else if(parts[0] == "CompujumpStationID" && parts[1] != "" && Util.IsNumber(parts[1], false))
+						CompujumpStationID = Convert.ToInt32(parts[1]);
+					else if(parts[0] == "CompujumpStationMode" && Enum.IsDefined(typeof(Constants.Menuitem_modes), parts[1]))
+						CompujumpStationMode = (Constants.Menuitem_modes)
+							Enum.Parse(typeof(Constants.Menuitem_modes), parts[1]);
+					else if(parts[0] == "SessionMode" && Enum.IsDefined(typeof(SessionModeEnum), parts[1]))
+						SessionMode = (SessionModeEnum) 
+							Enum.Parse(typeof(SessionModeEnum), parts[1]);
+				} while(true);
+			}
+		}
+	}
+	
+	/*
 	public void Read()
 	{
 		string contents = Util.ReadFile(UtilAll.GetConfigFileName(), false);
@@ -88,9 +124,6 @@ public class Config
 						CustomButtons = true;
 					else if(parts[0] == "UseVideo" && ! Util.StringToBool(parts[1]))
 						UseVideo = false;
-					else if(parts[0] == "AutodetectPort" && Enum.IsDefined(typeof(AutodetectPortEnum), parts[1]))
-						AutodetectPort = (AutodetectPortEnum) 
-							Enum.Parse(typeof(AutodetectPortEnum), parts[1]);
 					else if(parts[0] == "OnlyEncoderGravitatory" && Util.StringToBool(parts[1]))
 						OnlyEncoderGravitatory = true;
 					else if(parts[0] == "OnlyEncoderInertial" && Util.StringToBool(parts[1]))
@@ -106,13 +139,16 @@ public class Config
 					else if(parts[0] == "SessionMode" && Enum.IsDefined(typeof(SessionModeEnum), parts[1]))
 						SessionMode = (SessionModeEnum) 
 							Enum.Parse(typeof(SessionModeEnum), parts[1]);
+					else if(parts[0] == "Compujump" && Util.StringToBool(parts[1]))
+						Compujump = true;
 					else if(parts[0] == "RunScriptOnExit" && parts[1] != "")
 						RunScriptOnExit = parts[1];
 				} while(true);
 			}
 		}
 	}
-	
+	*/
+	/*
 	public static void UpdateField(string field, string text)
 	{
 		//adapted from
@@ -162,7 +198,6 @@ public class Config
 				"Maximized = " + Maximized.ToString() + "\n" +
 				"CustomButtons = " + CustomButtons.ToString() + "\n" +
 				"UseVideo = " + UseVideo.ToString() + "\n" +
-				"AutodetectPort = " + AutodetectPort.ToString() + "\n" +
 				"OnlyEncoderGravitatory = " + OnlyEncoderGravitatory.ToString() + "\n" +
 				"OnlyEncoderInertial = " + OnlyEncoderInertial.ToString() + "\n" +
 				"EncoderCaptureShowOnlyBars = " + EncoderCaptureShowOnlyBars.ToString() + "\n" +
@@ -170,9 +205,11 @@ public class Config
 				"PersonWinHide = " + PersonWinHide.ToString() + "\n" +
 				"EncoderAnalyzeHide = " + EncoderAnalyzeHide.ToString() + "\n" +
 				"SessionMode = " + SessionMode.ToString() + "\n" +
+				"Compujump = " + Compujump.ToString() + "\n" +
 				"RunScriptOnExit = " + RunScriptOnExit.ToString() + "\n"
 		      );
 	}
+	*/
 
 	~Config() {}
 }
