@@ -198,6 +198,7 @@ public class Constants
 	public static string RFIDDisconnectedMessage = Catalog.GetString("RFID cable has been disconnected!") + "\n\n" +
 		Catalog.GetString("Please, connect it and restart Chronojump.");
 	public static string RFIDNotInServerMessage = Catalog.GetString("This RFID is not registered on server.");
+	public static string ServerDisconnectedMessage = Catalog.GetString("Server is disconnected.");
 
 	//server
 	public const string ServerPingTable = "SPing"; 
@@ -439,6 +440,7 @@ public class Constants
 	public static string FileNameEncoderGravitatory = "stock_down.png";
 	public static string FileNameEncoderInertial = "stock_inertial.png";
 	public static string FileNamePulse = "pulse_menu.png";
+	public static string FileNameForceSensor = "force_sensor.png";
 	public static string FileNameMultiChronopic = "multichronopic_menu.png";
 	
 	public static string FileNameJumpsFallCalculate = "dj-from-in.png";
@@ -616,6 +618,7 @@ public class Constants
 	};
 	
 	public static string DatabaseNotFound = Catalog.GetString("Error. Cannot find database.");
+	public static string WebsiteNotFound = Catalog.GetString("Sorry, cannot open website.");
 	public static string DirectoryCannotOpen = Catalog.GetString("Error. Cannot open directory.");
 	public static string FileNotFound = Catalog.GetString("Error. File not found.");
 	public static string FileCopyProblem = Catalog.GetString("Error. Cannot copy file.");
@@ -707,10 +710,11 @@ public class Constants
 	}
 	
 	public enum MultimediaItems {
-		PHOTO, VIDEO
+		PHOTO, PHOTOPNG, VIDEO
 	}
 	public const string ExtensionVideo = ".avi";
 	public const string ExtensionPhoto = ".jpg";
+	public const string ExtensionPhotoPng = ".png"; //used for Cairo resized images
 	public const string SmallPhotoDir = "small";
 	public static string MultimediaFileNoExists = Catalog.GetString("Sorry, this multimedia file does not exists.");
 	public static string PhotoTemp = "chronojump-last-photo";
@@ -788,7 +792,12 @@ public class Constants
 	//public static string ConcentricEccentric = "Concentric-eccentric";
 
 	public enum EncoderGI {ALL, GRAVITATORY, INERTIAL}
-	public enum EncoderCheckFileOp { CAPTURE_EXPORT_ALL, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_AB, ANALYZE_SAVE_TABLE}
+	public enum CheckFileOp {
+		JUMPS_PROFILE_SAVE_IMAGE,
+		ENCODER_CAPTURE_EXPORT_ALL, ENCODER_ANALYZE_SAVE_IMAGE,
+		ENCODER_ANALYZE_SAVE_AB, ENCODER_ANALYZE_SAVE_TABLE,
+		FORCESENSOR_SAVE_IMAGE_SIGNAL, FORCESENSOR_SAVE_IMAGE_RFD
+	}
 
 	public static double EncoderErrorCode = -1;
 	
@@ -960,7 +969,9 @@ public class Constants
 		"Sorry, no repetitions matched your criteria.",
 		"Need at least three jumps",
 		"Laterality", "RL", "R", "L",
-		"Inertia M."
+		"Inertia M.",
+		"Maximum mean power using the F-V profile",
+		"Mean power parabole using the Power-Load data"
 	};
 	/*
 	 * written here in order to be translated
@@ -1007,6 +1018,8 @@ public class Constants
 		Catalog.GetString("Sorry, no repetitions matched your criteria."),
 		Catalog.GetString("Need at least three jumps"),
 		Catalog.GetString("Laterality"), Catalog.GetString("RL"), Catalog.GetString("R"), Catalog.GetString("L"),
-		Catalog.GetString("Inertia M.")
+		Catalog.GetString("Inertia M."),
+		Catalog.GetString("Maximum mean power using the F-V profile"),
+		Catalog.GetString("Mean power parabole using the Power-Load data")
 	};
 }
