@@ -159,6 +159,7 @@ public class EncoderGraphROptions
 	public string translatedWords;
 	public bool debug;
 	public bool crossValidate;
+	private bool cutByTriggers;
 	private string triggerList;
 	
 	public EncoderGraphROptions(
@@ -167,7 +168,7 @@ public class EncoderGraphROptions
 			EncoderParams ep,
 			string title, string operatingSystem,
 			string englishWords, string translatedWords,
-			bool debug, bool crossValidate, string triggerList)
+			bool debug, bool crossValidate, bool cutByTriggers, string triggerList)
 	{
 		this.inputData = inputData;
 		this.outputGraph = outputGraph;
@@ -181,6 +182,7 @@ public class EncoderGraphROptions
 		this.translatedWords = translatedWords;
 		this.debug = debug;
 		this.crossValidate = crossValidate;
+		this.cutByTriggers = cutByTriggers;
 		this.triggerList = triggerList;
 	}
 
@@ -198,6 +200,7 @@ public class EncoderGraphROptions
 			"#translatedWords\n" + 	translatedWords + "\n" +
 			"#debug\n" +		Util.BoolToRBool(debug) + "\n" +
 			"#crossValidate\n" +	Util.BoolToRBool(crossValidate) + "\n" +
+			"#cutByTriggers\n" +	Util.BoolToRBool(cutByTriggers) + "\n" +
 			"#triggerList\n" +	triggerList + "\n";
 	}
 	
@@ -648,9 +651,9 @@ public class EncoderSQL
 		this.status = status;
 		this.videoURL = videoURL;
 		this.encoderConfiguration = encoderConfiguration;
-		this.future1 = future1;	//on curves: meanPower
-		this.future2 = future2;
-		this.future3 = future3;
+		this.future1 = future1;	//on curves: meanPower. Better use alter table
+		this.future2 = future2; //on curves: meanSpeed
+		this.future3 = future3; //on curves: meanForce
 		this.exerciseName = exerciseName;
 
 		if(eccon == "c")
