@@ -22,6 +22,7 @@ using System;
 using System.IO;
 using System.IO.Ports;
 using System.Collections.Generic; //List<T>
+using Gtk;
 
 public abstract class EncoderCapture
 {
@@ -111,7 +112,9 @@ public abstract class EncoderCapture
 
 
 	//if cont (continuous mode), then will not end when too much time passed before start
-	public void InitGlobal (int widthG, int heightG, int time, int timeEnd, bool cont, string eccon, string port, bool capturingInertialBG, bool showOnlyBars, bool simulated)
+	public void InitGlobal (int widthG, int heightG, int time, int timeEnd,
+			bool cont, string eccon, string port, bool capturingInertialBG, bool showOnlyBars,
+			bool simulated)
 	{
 		this.widthG = widthG;
 		this.heightG = heightG;
@@ -211,7 +214,8 @@ public abstract class EncoderCapture
 		inertialCalibrated = false;
 	}
 
-	public bool Capture(string outputData1, EncoderRProcCapture encoderRProcCapture, bool compujump, bool cutByTriggers)
+	public bool Capture(string outputData1, EncoderRProcCapture encoderRProcCapture,
+			bool compujump, Preferences.TriggerTypes cutByTriggers, double restClustersSeconds)
 	{
 		/*
 		 * removed at 1.7.0
@@ -225,6 +229,9 @@ public abstract class EncoderCapture
 		lastTriggerOn = 0;
 		inertialCalibratedFirstCross0Pos = 0;
 
+		//only for cutByTriggers == Preferences.TriggerTypes.START_AT_FIRST_ON
+		bool firstTriggerHappened = false;
+
 		if(capturingInertialBG)
 		{
 			/*
@@ -257,7 +264,19 @@ public abstract class EncoderCapture
 					continue;
 				}
 
-				if(cutByTriggers)
+				//TriggerTypes.START_AT_FIRST_ON starts capture at first trigger. So when this happens, reset capture
+				if(cutByTriggers == Preferences.TriggerTypes.START_AT_FIRST_ON && ! firstTriggerHappened)
+				{
+					LogB.Information("Cleaning on capture");
+
+					startCaptureFromHere();
+
+					firstTriggerHappened = true;
+					i = -1; //will be 0 on next loop start
+					continue;
+				}
+
+				if(cutByTriggers != Preferences.TriggerTypes.NO_TRIGGERS)
 				{
 					ecc = new EncoderCaptureCurve(lastTriggerOn, i);
 					lastTriggerOn = i;
@@ -316,23 +335,7 @@ public abstract class EncoderCapture
 						//remove this time on existing trigger records
 						triggerList.Substract(consecutiveZeros);
 
-						consecutiveZeros = -1;
-						encoderReadedInertialDisc = new List<int>();
-						encoderReaded = new List<int>();
-
-						if(capturingInertialBG)
-						{
-							//empty EncoderCaptureInertialBackgroundStatic.ListCaptured
-							EncoderCaptureInertialBackgroundStatic.Initialize();
-						}
-
-						if(! showOnlyBars)
-						{
-							EncoderCapturePoints = new List<Gdk.Point>();
-							EncoderCapturePointsInertialDisc = new List<Gdk.Point>();
-							EncoderCapturePointsCaptured = 0;
-							EncoderCapturePointsPainted = -1; 	//-1 means delete screen
-						}
+						startCaptureFromHere();
 
 						i = -1; //will be 0 on next loop start
 						continue;
@@ -345,13 +348,22 @@ public abstract class EncoderCapture
 				//but it has to be moved a little bit first, just to give time to the people
 				//if(consecutiveZeros >= consecutiveZerosMax && sum > 0) #Not OK because sum maybe is 0: +1,+1,-1,-1
 				//if(consecutiveZeros >= consecutiveZerosMax && ecca.ecc.Count > 0) #Not ok because when ecca is created, ecc.Count == 1
-				//
-				//process ends 
-				//when a curve has been found and then there are n seconds of inactivity, or
-				//when a curve has not been found and then there are 2*n seconds of inactivity
+				/*
+				 * process ends
+				 * (
+				 * when a curve has been found and then there are n seconds of inactivity, or
+				 * when not in cont and a curve has not been found and then there are 2*n seconds of inactivity
+				 * ) and if consecutiveZeros > restClustersSeconds * 1.500
+				 *
+				 * 1500 is conversion to milliseconds and * 1.5 to have enough time to move after clusters res
+				 */
 				if(
-						(Ecca.curvesAccepted > 0 && consecutiveZeros >= consecutiveZerosMax) ||
-						(! cont && Ecca.curvesAccepted == 0 && consecutiveZeros >= (2* consecutiveZerosMax)) )
+						(
+						 (Ecca.curvesAccepted > 0 && consecutiveZeros >= consecutiveZerosMax) ||
+						 (! cont && Ecca.curvesAccepted == 0 && consecutiveZeros >= (2* consecutiveZerosMax))
+						) &&
+						(restClustersSeconds == 0 || consecutiveZeros > restClustersSeconds * 1500)
+				  )
 				{
 					finish = true;
 					LogB.Information("SHOULD FINISH");
@@ -429,7 +441,7 @@ public abstract class EncoderCapture
 					sendCurveMaybe = false;
 
 				//if cutByTriggers, triggers send the curve at the beginning of this method
-				if(cutByTriggers)
+				if(cutByTriggers != Preferences.TriggerTypes.NO_TRIGGERS)
 					sendCurveMaybe = false;
 
 				if(sendCurveMaybe)
@@ -530,7 +542,9 @@ public abstract class EncoderCapture
 						 */
 
 
-						if( shouldSendCurve() )
+						//store in a boolean to not call shouldSendCurve() two times because it changes some variables
+						bool shouldSendCurveBool = shouldSendCurve();
+						if(shouldSendCurveBool)
 						{
 							//if compujump, wakeup screen if it's off
 							//do it on the first repetition because it will not be sleeping on the rest of repetitions
@@ -550,6 +564,7 @@ public abstract class EncoderCapture
 
 							lastDirectionStoredIsUp = ecc.up;
 						}
+
 					}
 
 					//on inertial is different
@@ -597,6 +612,27 @@ public abstract class EncoderCapture
 	}
 	*/
 
+	private void startCaptureFromHere()
+	{
+		consecutiveZeros = -1;
+		encoderReadedInertialDisc = new List<int>();
+		encoderReaded = new List<int>();
+
+		if(capturingInertialBG)
+		{
+			//empty EncoderCaptureInertialBackgroundStatic.ListCaptured
+			EncoderCaptureInertialBackgroundStatic.Initialize();
+		}
+
+		if(! showOnlyBars)
+		{
+			EncoderCapturePoints = new List<Gdk.Point>();
+			EncoderCapturePointsInertialDisc = new List<Gdk.Point>();
+			EncoderCapturePointsCaptured = 0;
+			EncoderCapturePointsPainted = -1; 	//-1 means delete screen
+		}
+	}
+
 	private bool simulatedGoingUp = false;
 	private int simulatedMaxValue = 400;
 	private int simulatedLength;
@@ -797,6 +833,16 @@ public abstract class EncoderCapture
 		return triggerList;
 	}
 
+	/*
+	 * graph.R will findCurvesByTriggers if (length(op$TriggersOn) >= 1)
+	 * else will findCurvesNew (like if not capturing by triggers)
+	 * We need to know what graph.R will do to show a message to user
+	 */
+	public bool MinimumOneTriggersOn()
+	{
+		return triggerList.MinimumOneOn();
+	}
+
 	public string Eccon {
 		get { return eccon; }
 	}
