@@ -143,7 +143,7 @@ public abstract class EncoderRProc
 
 public class EncoderRProcCapture : EncoderRProc 
 {
-	public bool CutByTriggers;
+	public Preferences.TriggerTypes CutByTriggers;
 
 	public EncoderRProcCapture()
 	{
@@ -256,6 +256,7 @@ public class EncoderRProcCapture : EncoderRProc
 				false,	//translate (graphs)
 				Debug,
 				false,	//crossValidate (unactive on capture at the moment)
+				(CutByTriggers != Preferences.TriggerTypes.NO_TRIGGERS),
 				printTriggers()
 				).ToString();
 
@@ -270,7 +271,7 @@ public class EncoderRProcCapture : EncoderRProc
 	{
 		//just use triggeres tp cut sets into repetitions, or not.
 		//Cut is done in C# but this will change minHeight behaviour and reduceCurveBySpeed
-		if(CutByTriggers)
+		if(CutByTriggers != Preferences.TriggerTypes.NO_TRIGGERS)
 			return "1";
 		else
 			return TriggerList.TriggersNotFoundString;
@@ -283,6 +284,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 	private string title;
 	private bool neuromuscularProfileDo;
 	private bool translate;
+	private bool cutByTriggers;
 	private TriggerList triggerList;
 
 	/*
@@ -296,10 +298,13 @@ public class EncoderRProcAnalyze : EncoderRProc
 	public EncoderRProcAnalyze() {
 	}
 
-	public void SendData(string title, bool neuromuscularProfileDo, bool translate, TriggerList triggerList) {
+	public void SendData(string title, bool neuromuscularProfileDo, bool translate,
+			bool cutByTriggers, TriggerList triggerList)
+	{
 		this.title = title;
 		this.neuromuscularProfileDo = neuromuscularProfileDo;
 		this.translate = translate;
+		this.cutByTriggers = cutByTriggers;
 		this.triggerList = triggerList;
 		
 		CancelRScript = false;
@@ -508,6 +513,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 				translate,
 				Debug,
 				CrossValidate,
+				cutByTriggers,
 				printTriggers()
 				).ToString();
 
