@@ -37,7 +37,8 @@ public class RunExecute : EventExecute
 
 	//used by the updateTimeProgressBar for display its time information
 	//changes a bit on runSimple and runInterval
-	//explained at each of the updateTimeProgressBar() 
+	//explained at each of the updateTimeProgressBar()
+	//measureRectionTime will be PLATFORM_INI_YES_TIME
 	protected enum runPhases {
 		PRE_RUNNING, PLATFORM_INI_YES_TIME, PLATFORM_INI_NO_TIME, RUNNING, PLATFORM_END
 	}
@@ -46,7 +47,9 @@ public class RunExecute : EventExecute
 	protected Constants.DoubleContact checkDoubleContactMode;
 	protected int checkDoubleContactTime;
 	
-	protected bool speedStartArrival;	
+	protected bool speedStartArrival; //if speedStartArrival then race time includes reaction time
+	protected bool measureReactionTime;
+	protected double reactionTimeMS; //reaction time in milliseconds
 	
 	public RunExecute() {
 	}
@@ -54,10 +57,11 @@ public class RunExecute : EventExecute
 	//run execution
 	public RunExecute(int personID, int sessionID, string type, double distance,   
 			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, 
-			int pDN, bool metersSecondsPreferred, bool volumeOn,
+			int pDN, bool metersSecondsPreferred,
+			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd,
 			Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime, 
-			bool speedStartArrival
+			bool speedStartArrival, bool measureReactionTime
 			)
 	{
 		this.personID = personID;
@@ -72,12 +76,16 @@ public class RunExecute : EventExecute
 		this.pDN = pDN;
 		this.metersSecondsPreferred = metersSecondsPreferred;
 		this.volumeOn = volumeOn;
+		this.gstreamer = gstreamer;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
 		this.checkDoubleContactMode = checkDoubleContactMode;
 		this.checkDoubleContactTime = checkDoubleContactTime;
 		this.speedStartArrival = speedStartArrival;	
-		
+		this.measureReactionTime = measureReactionTime;
+
+		reactionTimeMS = 0;
+
 		fakeButtonUpdateGraph = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 
@@ -125,7 +133,7 @@ public class RunExecute : EventExecute
 		if (platformState==Chronopic.Plataforma.ON) {
 			feedbackMessage = Catalog.GetString("You are IN, RUN when prepared!");
 			needShowFeedbackMessage = true; 
-			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
+			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
 
 			loggedState = States.ON;
 			startIn = true;
@@ -133,7 +141,7 @@ public class RunExecute : EventExecute
 		} else if (platformState==Chronopic.Plataforma.OFF) {
 			feedbackMessage = Catalog.GetString("You are OUT, RUN when prepared!");
 			needShowFeedbackMessage = true; 
-			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
+			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn, gstreamer);
 
 			loggedState = States.OFF;
 			startIn = false;
@@ -208,7 +216,7 @@ public class RunExecute : EventExecute
 					loggedState = States.ON;
 					
 					if(runPhase == runPhases.PRE_RUNNING) {
-						if(speedStartArrival) {
+						if(speedStartArrival || measureReactionTime) {
 							runPhase = runPhases.PLATFORM_INI_YES_TIME;
 							initializeTimer(); //timerCount = 0
 						} else
@@ -275,7 +283,14 @@ public class RunExecute : EventExecute
 
 							//add the first contact time if PLATFORM_INI_YES_TIME
 							if(timestampFirstContact > 0)
-								timestamp += timestampFirstContact;
+							{
+								if(measureReactionTime)
+									reactionTimeMS = timestampFirstContact;
+
+								// measuringReactionTime or not, if speedStartArrival, timestamp should include timpestampFirstContact
+								if(speedStartArrival)
+									timestamp += timestampFirstContact;
+							}
 
 							time = timestamp / 1000.0;
 							write();
@@ -334,7 +349,7 @@ public class RunExecute : EventExecute
 		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
 		 *		case runPhases.PRE_RUNNING
 		 *   2-  if we are on the platform, it should be a pulse
-		 *   		a) if speedStartArrival (time starts at arriving at platform) 
+		 *   		a) if speedStartArrival (time starts at arriving at platform) || measureReactionTime
 		 *   		then time starts and have to be time value on label:
 		 *			case runPhases.PLATFORM_INI_YES_TIME
 		 *   		b) if ! speedStartArrival (time starts at leaving platform)
@@ -402,7 +417,9 @@ public class RunExecute : EventExecute
 			description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / time).ToString(), pDN) + " (Watts)";
 		} else if(type == "Gesell-DBT") 
 			description = "0";
-		
+
+		if(measureReactionTime && reactionTimeMS > 0)
+			description += descriptionAddReactionTime(reactionTimeMS, pDN, speedStartArrival);
 
 		string table = Constants.RunTable;
 
@@ -423,7 +440,20 @@ public class RunExecute : EventExecute
 		needEndEvent = true; //used for hiding some buttons on eventWindow
 	}
 
-	
+	protected string reactionTimeIncludedStr = Catalog.GetString("Included on race time");
+	protected string reactionTimeNotIncludedStr = Catalog.GetString("Not included on race time");
+
+	protected string descriptionAddReactionTime(double rtimeMS, int ndec, bool speedStartArrival)
+	{
+		string str = "";
+		if(speedStartArrival)
+			str = reactionTimeIncludedStr;
+		else
+			str = reactionTimeNotIncludedStr;
+
+		return Util.TrimDecimals(rtimeMS / 1000.0, ndec) + " ms (" + str + ")";
+	}
+
 	public string RunnerName
 	{
 		get { return SqlitePerson.SelectAttribute(personID, Constants.Name); }
@@ -459,10 +489,11 @@ public class RunIntervalExecute : RunExecute
 	//run execution
 	public RunIntervalExecute(int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
 			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, 
-			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin,
+			bool volumeOn, Preferences.GstreamerTypes gstreamer,
+			RepetitiveConditionsWindow repetitiveConditionsWin,
 			double progressbarLimit, ExecutingGraphData egd ,
 			Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime, 
-			bool speedStartArrival
+			bool speedStartArrival, bool measureReactionTime
 			)
 	{
 		this.personID = personID;
@@ -495,13 +526,19 @@ public class RunIntervalExecute : RunExecute
 		this.metersSecondsPreferred = metersSecondsPreferred;
 		this.pDN = pDN;
 		this.volumeOn = volumeOn;
+		this.gstreamer = gstreamer;
 		this.repetitiveConditionsWin = repetitiveConditionsWin;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
 		this.checkDoubleContactMode = checkDoubleContactMode;
 		this.checkDoubleContactTime = checkDoubleContactTime;
 		this.speedStartArrival = speedStartArrival;	
-	
+		this.measureReactionTime = measureReactionTime;
+
+		reactionTimeMS = 0;
+		reactionTimeIncludedStr = Catalog.GetString("Included on race time of first track");
+		reactionTimeNotIncludedStr = Catalog.GetString("Not included on race time of first track");
+
 		fakeButtonUpdateGraph = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
 
@@ -562,7 +599,7 @@ public class RunIntervalExecute : RunExecute
 					//if we start out, and we arrive to the platform for the first time,
 					//don't record nothing
 					if(runPhase == runPhases.PRE_RUNNING) {
-						if(speedStartArrival) {
+						if(speedStartArrival || measureReactionTime) {
 							runPhase = runPhases.PLATFORM_INI_YES_TIME;
 							//run starts
 							initializeTimer(); //timerCount = 0
@@ -698,9 +735,16 @@ public class RunIntervalExecute : RunExecute
 
 						feedbackMessage = "";
 						needShowFeedbackMessage = true; 
-					} else if(runPhase == runPhases.PLATFORM_INI_YES_TIME) {
-						lastTc = timestamp/1000.0;
-					
+					} else if(runPhase == runPhases.PLATFORM_INI_YES_TIME)
+					{
+						lastTc = 0;
+						if(measureReactionTime)
+							reactionTimeMS = timestamp;
+
+						// measuringReactionTime or not, if speedStartArrival, 1st race time should include lastTc
+						if(speedStartArrival)
+							lastTc = timestamp/1000.0;
+
 						feedbackMessage = "";
 						needShowFeedbackMessage = true; 
 					} else {
@@ -753,7 +797,7 @@ public class RunIntervalExecute : RunExecute
 
 		if (waitSeconds < 0) {
 		       	if(! RSABellDone) {
-				Util.PlaySound(Constants.SoundTypes.GOOD, volumeOn);
+				Util.PlaySound(Constants.SoundTypes.GOOD, volumeOn, gstreamer);
 				RSABellDone = true;
 			}
 			return Catalog.GetString("Go!");
@@ -786,7 +830,7 @@ public class RunIntervalExecute : RunExecute
 		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
 		 *		case runPhases.PRE_RUNNING
 		 *   2-  if we are on the platform, it should be a pulse
-		 *   		a) if speedStartArrival (time starts at arriving at platform) 
+		 *   		a) if speedStartArrival (time starts at arriving at platform) || measureReactionTime
 		 *   		then time starts and have to be time value on label:
 		 *			case runPhases.PLATFORM_INI_YES_TIME
 		 *   		b) if ! speedStartArrival (time starts at leaving platform)
@@ -900,6 +944,10 @@ public class RunIntervalExecute : RunExecute
 		string description = "";
 		if(type == "MTGUG")
 			description = "u u u u u u"; //undefined 6 items of questionnaire
+		//note MTGUG will not have reaction time measurement to have description read correctly by the rest of the software
+		else if(measureReactionTime && reactionTimeMS > 0)
+			description += descriptionAddReactionTime(reactionTimeMS, pDN, speedStartArrival);
+
 
 
 		if(tempTable)
@@ -1008,7 +1056,6 @@ public class RunIntervalExecute : RunExecute
 	}
 	*/
 		
-		
 	~RunIntervalExecute() {}
 }
 
