@@ -34,26 +34,40 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_quit;
 	[Widget] Gtk.Image image_quit1;
 	[Widget] Gtk.Image image_quit2;
+	[Widget] Gtk.Image image_quit_from_app1;
 	[Widget] Gtk.Image image_session_new;
+	[Widget] Gtk.Image image_session_new2;
 	[Widget] Gtk.Image image_session_load;
+	[Widget] Gtk.Image image_session_edit;
+	[Widget] Gtk.Image image_session_delete;
+	[Widget] Gtk.Image image_session_preferences;
 	[Widget] Gtk.Image image_mode_encoder_capture;
 	[Widget] Gtk.Image image_manage_persons;
+	[Widget] Gtk.Image image_current_person_zoom;
 	[Widget] Gtk.Image image_person;
 	[Widget] Gtk.Image image_person1;
 	[Widget] Gtk.Image image_edit_current_person;
+	[Widget] Gtk.Image image_edit_current_person_h;
 	//[Widget] Gtk.Image image_persons_up;
 	//[Widget] Gtk.Image image_persons_down;
 	[Widget] Gtk.Image image_rest;
 	[Widget] Gtk.Image image_all_persons_events;
+	[Widget] Gtk.Image image_all_persons_events_h;
+	[Widget] Gtk.Image image_person_delete;
+	[Widget] Gtk.Image image_person_delete_h;
 	[Widget] Gtk.Image image_chronopic_connect_contacts;
 	[Widget] Gtk.Image image_chronopic_connect_encoder;
 	[Widget] Gtk.Image image_button_execute;
 	[Widget] Gtk.Image image_tests_capture;
 	[Widget] Gtk.Image image_tests_sprint;
+	[Widget] Gtk.Image image_tests_analyze_general;
 	[Widget] Gtk.Image image_info1;
 	[Widget] Gtk.Image image_info2;
 	[Widget] Gtk.Image image_info3;
 	[Widget] Gtk.Image image_info4;
+	[Widget] Gtk.Image image_run_simple_with_reaction_time_help;
+	[Widget] Gtk.Image image_run_interval_with_reaction_time_help;
+	[Widget] Gtk.Image image_reaction_time_device_help;
 	[Widget] Gtk.Image image_info_sessions_info;
 	[Widget] Gtk.Image image_add_test1;
 	[Widget] Gtk.Image image_add_test2;
@@ -63,7 +77,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_selector_start_jumps;
 	[Widget] Gtk.Image image_selector_start_runs;
 	[Widget] Gtk.Image image_selector_start_encoder;
-	[Widget] Gtk.Image image_selector_start_force_sensor;
 	[Widget] Gtk.Image image_selector_start_rt;
 	[Widget] Gtk.Image image_selector_start_other;
 	[Widget] Gtk.Image image_selector_start_cancel;
@@ -98,6 +111,18 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_inertial_extended;
 	[Widget] Gtk.Image image_encoder_calibrate;
 	[Widget] Gtk.Image image_encoder_recalibrate;
+	[Widget] Gtk.Image image_encoder_triggers;
+	[Widget] Gtk.Image image_encoder_rhythm_rest;
+
+	//force sensor
+	[Widget] Gtk.Image image_selector_start_force_sensor;
+	[Widget] Gtk.Image image_force_sensor_adjust_help;
+	[Widget] Gtk.Image image_force_sensor_capture_load;
+	[Widget] Gtk.Image image_force_sensor_analyze_load;
+	[Widget] Gtk.Image image_force_sensor_tare;
+	[Widget] Gtk.Image image_force_sensor_calibrate;
+	[Widget] Gtk.Image image_force_sensor_open_folder;
+	[Widget] Gtk.Image image_force_sensor_check_version;
 
 	private void putNonStandardIcons()
 	{
@@ -126,11 +151,13 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_settings.png");
 		image_settings.Pixbuf = pixbuf;
 		image_settings1.Pixbuf = pixbuf;
+		image_session_preferences.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_quit.png");
 		image_quit.Pixbuf = pixbuf;
 		image_quit1.Pixbuf = pixbuf;
 		image_quit2.Pixbuf = pixbuf;
+		image_quit_from_app1.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "muscle-concentric.png");
 		image_top_eccon.Pixbuf = pixbuf;
@@ -155,6 +182,16 @@ public partial class ChronoJumpWindow
 		image_extra_mass.Pixbuf = pixbuf;
 		image_encoder_inertial_top_weights.Pixbuf = pixbuf;
 		image_encoder_inertial_weights.Pixbuf = pixbuf;
+		image_force_sensor_calibrate.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_check.png");
+		image_force_sensor_open_folder.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "zoom.png");
+		image_current_person_zoom.Pixbuf = pixbuf;
+		image_force_sensor_check_version.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
+		image_current_person.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_gravity.png");
 		image_mode_encoder_gravitatory.Pixbuf = pixbuf;
@@ -185,8 +222,12 @@ public partial class ChronoJumpWindow
 		image_info2.Pixbuf = pixbuf;
 		image_info3.Pixbuf = pixbuf;
 		image_info4.Pixbuf = pixbuf;
+		image_run_simple_with_reaction_time_help.Pixbuf = pixbuf;
+		image_run_interval_with_reaction_time_help.Pixbuf = pixbuf;
+		image_reaction_time_device_help.Pixbuf = pixbuf;
 		image_info_sessions_info.Pixbuf = pixbuf;
 		image_encoder_1RM_info.Pixbuf = pixbuf;
+		image_force_sensor_adjust_help.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_add_test.png");
 		image_add_test1.Pixbuf = pixbuf;
@@ -210,12 +251,20 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_new_big.png");
 		image_session_new.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_new.png");
+		image_session_new2.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_open_big.png");
 		image_session_load.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_open.png");
+		image_session_open.Pixbuf = pixbuf;
 		image_encoder_capture_open.Pixbuf = pixbuf;
 		image_encoder_capture_open1.Pixbuf = pixbuf;
+		image_force_sensor_capture_load.Pixbuf = pixbuf;
+		image_force_sensor_analyze_load.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "zero.png");
+		image_force_sensor_tare.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "one.png");
 		image_encoder_capture_1set.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "cont.png");
@@ -230,6 +279,8 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_edit.png");
 		image_encoder_exercise_edit.Pixbuf = pixbuf;
 		image_edit_current_person.Pixbuf = pixbuf;
+		image_edit_current_person_h.Pixbuf = pixbuf;
+		image_session_edit.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 		image_encoder_exercise1.Pixbuf = pixbuf;
@@ -254,9 +305,11 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest.png");
 		image_rest.Pixbuf = pixbuf;
+		image_encoder_rhythm_rest.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_visibility.png");
 		image_all_persons_events.Pixbuf = pixbuf;
+		image_all_persons_events_h.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "inertial_rolled.png");
 		image_inertial_rolled.Pixbuf = pixbuf;
@@ -358,8 +411,8 @@ public partial class ChronoJumpWindow
 		UtilGtk.ColorsRadio(viewport_chronopics, extra_window_radio_multichronopic_run_analysis);
 
 		//open buttons (this is shown better in windows than the default open icon)
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameOpen);
-		image_session_open.Pixbuf = pixbuf;
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameOpen);
+		//image_session_open.Pixbuf = pixbuf;
 		//not changed because it's small. TODO: do bigger
 		//image_encoder_capture_open.Pixbuf = pixbuf;
 
@@ -375,6 +428,7 @@ public partial class ChronoJumpWindow
 		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
 		image_person_delete.Pixbuf = pixbuf;
+		image_person_delete_h.Pixbuf = pixbuf;
 		image_delete_last_test.Pixbuf = pixbuf;
 		image_jump_delete.Pixbuf = pixbuf;
 		image_jump_reactive_delete.Pixbuf = pixbuf;
@@ -387,6 +441,7 @@ public partial class ChronoJumpWindow
 		image_jump_type_delete_reactive.Pixbuf = pixbuf;
 		image_run_type_delete_simple.Pixbuf = pixbuf;
 		image_run_type_delete_intervallic.Pixbuf = pixbuf;
+		image_session_delete.Pixbuf = pixbuf;
 		
 		//zoom icons, done like this because there's one zoom icon created ad-hoc, 
 		//and is not nice that the other are different for an user theme change
@@ -399,7 +454,12 @@ public partial class ChronoJumpWindow
 		image_reaction_times_zoom.Pixbuf = pixbuf;
 		image_pulses_zoom.Pixbuf = pixbuf;
 		image_multi_chronopic_zoom.Pixbuf = pixbuf;
-		
+
+
+		//white background in chronopic viewports
+		UtilGtk.DeviceColors(viewport_chronopics, true);
+		UtilGtk.DeviceColors(viewport_chronopic_encoder, true);
+
 		//encoder
 		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_powerbars);
 		UtilGtk.ColorsRadio(viewport_chronopics, radiobutton_encoder_analyze_cross);
@@ -419,12 +479,17 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "gpm-statistics.png");
 		image_encoder_analyze_stats.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save.Pixbuf = pixbuf;
+		image_jumps_profile_save.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
 		image_encoder_signal_delete.Pixbuf = pixbuf;
 	
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "spreadsheet.png");
 		image_encoder_analyze_table_save.Pixbuf = pixbuf;
-		
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_analyze_general.png");
+		image_tests_analyze_general.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "jumps-profile-pie.png");
 		image_tab_jumps_profile.Pixbuf = pixbuf;
 		
@@ -493,7 +558,10 @@ public partial class ChronoJumpWindow
 		image_encoder_analyze_time_to_pp.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderInertialInstructions);
 		image_encoder_inertial_instructions.Pixbuf = pixbuf;
-		
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_encoder_triggers.png");
+		image_encoder_triggers.Pixbuf = pixbuf;
+
 		//auto mode
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameAutoPersonSkipIcon);
 		image_auto_person_skip.Pixbuf = pixbuf;
