@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -33,8 +33,6 @@ public partial class ChronoJumpWindow
 {
 	[Widget] Gtk.RadioButton extra_window_radio_multichronopic_start;
 	[Widget] Gtk.RadioButton extra_window_radio_multichronopic_run_analysis;
-	[Widget] Gtk.Label label_extra_window_radio_multichronopic_start;
-	[Widget] Gtk.Label label_extra_window_radio_multichronopic_run_analysis;
 
 	[Widget] Gtk.Label extra_window_label_multichronopic_need_two;
 	[Widget] Gtk.Button button_run_analysis_help;
@@ -54,11 +52,16 @@ public partial class ChronoJumpWindow
 			currentMultiChronopicType = new MultiChronopicType(Constants.MultiChronopicName);
 		else if(extra_window_radio_multichronopic_run_analysis.Active) 
 			currentMultiChronopicType = new MultiChronopicType(Constants.RunAnalysisName);
-		
+
+		vbox_last_test_buttons.Sensitive = false;
+
+		/*
+		 *	disabled on 1.6.3
 		if(chronopicWin.NumConnected() < 2) 
 			extra_window_multichronopic_can_do(false);
 		else
 			extra_window_multichronopic_can_do(true);
+			*/
 		
 		extra_window_multichronopic_initialize(currentMultiChronopicType);
 	}
@@ -121,7 +124,7 @@ public class EditMultiChronopicWindow : EditEventWindow
 
 	EditMultiChronopicWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent 	= parent;
 		
