@@ -54,6 +54,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Box hbox_top_person_encoder;
 	[Widget] Gtk.Label label_top_person_name;
 	[Widget] Gtk.Label label_top_encoder_person_name;
+	[Widget] Gtk.Button button_image_current_person_zoom;
+	[Widget] Gtk.Image image_current_person;
 	[Widget] Gtk.Button button_contacts_person_change;
 	[Widget] Gtk.Button button_encoder_person_change;
 	[Widget] Gtk.VBox vbox_encoder_capture_1_or_cont;
@@ -118,6 +120,9 @@ public partial class ChronoJumpWindow
 			//button_encoder_person_change.Visible = false;
 			//TODO: don't allow edit person on person treeview
 
+			//dont't show persons_bottom hbox where users can be edited, deleted if persons at lateral is selected on preferences
+			vbox_persons_bottom.Visible = false;
+
 			//don't allow to change encoderConfiguration
 			label_encoder_exercise_encoder.Visible = false;
 			vseparator_encoder_exercise_encoder.Visible = false;
@@ -217,6 +222,7 @@ public partial class ChronoJumpWindow
 		configChronojump.Maximized = preferences.maximized;
 		configChronojump.PersonWinHide = preferences.personWinHide;
 		configChronojump.EncoderCaptureShowOnlyBars = preferences.encoderCaptureShowOnlyBars;
+		configChronojump.EncoderUpdateTreeViewWhileCapturing = ! preferences.encoderCaptureShowOnlyBars;
 
 		configDo();
 	}
@@ -275,6 +281,9 @@ public partial class ChronoJumpWindow
 		if(! configChronojump.UseVideo) {
 			alignment_video_encoder.Visible = false;
 		}
+		//restriction for configured Compujump clients
+		//if(configChronojump.Compujump)
+		//	hbox_encoder_im_weights_n.Sensitive = false;
 		
 		//show only power
 		if(configChronojump.OnlyEncoderGravitatory)
@@ -307,18 +316,14 @@ public partial class ChronoJumpWindow
 		}
 		
 		encoderUpdateTreeViewWhileCapturing = configChronojump.EncoderUpdateTreeViewWhileCapturing;
-		
-		if(configChronojump.PersonWinHide)
-		{
-			notebook_session_person.Visible = false;
-			hbox_top_person.Visible = true;
-			hbox_top_person_encoder.Visible = true;
-		} else {
-			notebook_session_person.Visible = true;
-			hbox_top_person.Visible = false;
-			hbox_top_person_encoder.Visible = false;
-		}
-		
+
+		showPersonsOnTop(configChronojump.PersonWinHide);
+		menuitem_view_persons_on_top.Active = configChronojump.PersonWinHide;
+
+		showPersonPhoto(preferences.personPhoto);
+		menuitem_view_persons_show_photo.Active = preferences.personPhoto;
+
+
 		if(configChronojump.EncoderAnalyzeHide) {
 			hbox_encoder_sup_capture_analyze_two_buttons.Visible = false;
 		}
@@ -463,7 +468,20 @@ public partial class ChronoJumpWindow
 			LogB.Information("RFID person does not exist locally!!");
 
 			Person pServer = json.GetPersonByRFID(capturedRFID);
-			if(pServer.UniqueID == -1) {
+
+			if(! json.Connected) {
+				LogB.Information("Server is disconnected!");
+				if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
+				{
+					dialogMessageNotAtServer = new DialogMessage(
+							Constants.MessageTypes.WARNING,
+							Constants.ServerDisconnectedMessage
+							); //GTK
+
+					compujumpPersonLogoutDo();
+				}
+			}
+			else if(pServer.UniqueID == -1) {
 				LogB.Information("Person NOT found on server!");
 				if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
 				{
@@ -496,13 +514,18 @@ public partial class ChronoJumpWindow
 
 				if(json.LastPersonWasInserted)
 				{
-					if(json.LastPersonByRFIDImageURL != "")
+					string imageFile = json.LastPersonByRFIDImageURL;
+					if(imageFile != "")
 					{
+						string image_dest = Util.GetPhotoFileName(false, currentPerson.UniqueID);
+						if(UtilMultimedia.GetImageType(imageFile) == UtilMultimedia.ImageTypes.PNG)
+							image_dest = Util.GetPhotoPngFileName(false, currentPerson.UniqueID);
+
 						bool downloaded = json.DownloadImage(json.LastPersonByRFIDImageURL, currentPerson.UniqueID);
 						if(downloaded)
 							File.Copy(
 									Path.Combine(Path.GetTempPath(), currentPerson.UniqueID.ToString()),
-									Util.GetPhotoFileName(false, currentPerson.UniqueID),
+									image_dest,
 									true); //overwrite
 					}
 
@@ -612,10 +635,10 @@ public partial class ChronoJumpWindow
 		List<StationCount> stationsCount = json.GetOtherStationsWithPendingTasks(currentPerson.UniqueID, configChronojump.CompujumpStationID);
 
 		//4) show dialog
-		showDialogPersonPopup(tasks, stationsCount);
+		showDialogPersonPopup(tasks, stationsCount, json.Connected);
 	}
 
-	private void showDialogPersonPopup(List<Task> tasks, List<StationCount> stationsCount)
+	private void showDialogPersonPopup(List<Task> tasks, List<StationCount> stationsCount, bool serverConnected)
 	{
 		if(dialogPersonPopup != null)
 			dialogPersonPopup.DestroyDialog();
@@ -624,7 +647,7 @@ public partial class ChronoJumpWindow
 			dialogMessageNotAtServer.on_close_button_clicked(new object(), new EventArgs());
 
 		dialogPersonPopup = new DialogPersonPopup(
-				currentPerson.UniqueID, currentPerson.Name, capturedRFID, tasks, stationsCount);
+				currentPerson.UniqueID, currentPerson.Name, capturedRFID, tasks, stationsCount, serverConnected);
 
 		dialogPersonPopup.Fake_button_start_task.Clicked -= new EventHandler(compujumpTaskStart);
 		dialogPersonPopup.Fake_button_start_task.Clicked += new EventHandler(compujumpTaskStart);
