@@ -787,8 +787,16 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.RadioButton radiobutton_woman;
 	[Widget] Gtk.TextView textview_description;
 	[Widget] Gtk.TextView textview_ps_comments;
-	
-	[Widget] Gtk.Box vbox_photo;
+
+	[Widget] Gtk.Notebook notebook_main;
+	[Widget] Gtk.HButtonBox hbuttonbox_main;
+	[Widget] Gtk.VBox vbox_error;
+	[Widget] Gtk.Label label_error;
+	[Widget] Gtk.Button button_load_person;
+	[Widget] Gtk.Image image_load_person;
+
+	[Widget] Gtk.Button button_add_photo_file;
+	[Widget] Gtk.Button button_take_photo;
 	
 	[Widget] Gtk.Label label_date;
 	//[Widget] Gtk.Button button_change_date;
@@ -859,8 +867,9 @@ public class PersonAddModifyWindow
 	//
 	//if we are adding a person, currentPerson.UniqueID it's -1
 	//if we are modifying a person, currentPerson.UniqueID is obviously it's ID
-	//showPhotoStuff is false on raspberry to not use camera
-	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showPhotoStuff) {
+	//showCapturePhoto is false on raspberry to not use camera
+	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showCapturePhoto)
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_win.glade", "person_win", null);
 		gladeXML.Autoconnect(this);
@@ -892,30 +901,38 @@ public class PersonAddModifyWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameZoomInIcon);
 		image_zoom.Pixbuf = pixbuf;
 
-		if(showPhotoStuff) {
-			string photoFile = Util.GetPhotoFileName(true, currentPerson.UniqueID);
-			if(File.Exists(photoFile)) {
-				try {
-					pixbuf = new Pixbuf (photoFile); //from a file
-					image_photo_mini.Pixbuf = pixbuf;
-				} catch {
-					//on windows there are problem using the fileNames that are not on temp
-					string tempFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
-							Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
-					File.Copy(photoFile, tempFileName, true);
-					pixbuf = new Pixbuf (tempFileName);
-					image_photo_mini.Pixbuf = pixbuf;
-				}
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_outline.png");
+		image_load_person.Pixbuf = pixbuf;
+
+		button_take_photo.Visible = showCapturePhoto;
+
+		//delete a -1.png or -1.jpg added before on a new user where "accept" button was not pressed and window was closed
+		deleteOldPhotosIfAny(-1);
+
+		string photoFile = Util.UserPhotoURL(true, currentPerson.UniqueID);
+		if(photoFile != "") {
+			try {
+				pixbuf = new Pixbuf (photoFile); //from a file
+				image_photo_mini.Pixbuf = pixbuf;
+			} catch {
+				//on windows there are problem using the fileNames that are not on temp
+				string tempFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
+						Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
+				File.Copy(photoFile, tempFileName, true);
+				pixbuf = new Pixbuf (tempFileName);
+				image_photo_mini.Pixbuf = pixbuf;
 			}
-			//show zoom button only if big image exists
-			if(File.Exists(Util.GetPhotoFileName(false, currentPerson.UniqueID)))
-				button_zoom.Sensitive = true;
-			else
-				button_zoom.Sensitive = false;
+		}
+		//show zoom button only if big image exists
+		string photoBigFile = Util.UserPhotoURL(false, currentPerson.UniqueID);
+		if(photoBigFile != "")
+		{
+			button_zoom.Sensitive = true;
+			button_add_photo_file.Label = Catalog.GetString("Change photo");
 		}
 		else
-			vbox_photo.Visible = false;
-			
+			button_zoom.Sensitive = false;
+
 		fakeButtonAccept = new Gtk.Button();
 
 		entry1.CanFocus = true;
@@ -933,13 +950,89 @@ public class PersonAddModifyWindow
 				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
 		if(! adding) {
 			//on windows there are problem using the fileNames that are not on temp
-			string fileName = Util.GetPhotoFileName(false, currentPerson.UniqueID);
+			string fileName = Util.UserPhotoURL(false, currentPerson.UniqueID);
 			File.Copy(fileName, tempFileName, true);
 		}
 
 		new DialogImageTest(currentPerson.Name, tempFileName, DialogImageTest.ArchiveType.FILE);
 	}
 
+	/*
+	 * used when:
+	 * 1.- adding a photo to delete a possible duplicate, eg user 231 has 231.png and now will add 231.jpg
+	 * 2.- start this window to delete a -1.png or -1.jpg added before on a new user where "accept" button was not pressed and window was closed
+	 */
+	private void deleteOldPhotosIfAny(int uniqueID)
+	{
+		LogB.Information("deleteOldPhotosIfAny: " + uniqueID.ToString());
+		string file = Util.UserPhotoURL(false, uniqueID); //default
+		if(file != "")
+			Util.FileDelete(file);
+
+		file  = Util.UserPhotoURL(true, uniqueID); //small
+		if(file != "")
+			Util.FileDelete(file);
+	}
+
+	void on_button_add_photo_file_clicked (object o, EventArgs args)
+	{
+		Gtk.FileChooserDialog fc=
+			new Gtk.FileChooserDialog(Catalog.GetString("Select file"),
+					person_win,
+					FileChooserAction.Open,
+					Catalog.GetString("Cancel"),ResponseType.Cancel,
+					Catalog.GetString("Accept"),ResponseType.Accept
+					);
+
+		fc.Filter = new FileFilter();
+		fc.Filter.AddPattern("*.png");
+		fc.Filter.AddPattern("*.PNG");
+		fc.Filter.AddPattern("*.jpg");
+		fc.Filter.AddPattern("*.JPG");
+		fc.Filter.AddPattern("*.jpeg");
+		fc.Filter.AddPattern("*.JPEG");
+
+		if (fc.Run() == (int)ResponseType.Accept)
+		{
+			bool originalCopySuccess = false;
+			try {
+				deleteOldPhotosIfAny(currentPerson.UniqueID);
+				if(UtilMultimedia.GetImageType(fc.Filename) == UtilMultimedia.ImageTypes.JPEG)
+				{
+					File.Copy(fc.Filename, Util.GetPhotoFileName(false, currentPerson.UniqueID), true); //overwrite
+					originalCopySuccess = true;
+				}
+				else if(UtilMultimedia.GetImageType(fc.Filename) == UtilMultimedia.ImageTypes.PNG)
+				{
+					File.Copy(fc.Filename, Util.GetPhotoPngFileName(false, currentPerson.UniqueID), true); //overwrite
+					originalCopySuccess = true;
+				}
+			}
+			catch {
+				LogB.Warning("Catched! photo cannot be added");
+				new DialogMessage(Constants.MessageTypes.WARNING, string.Format(
+							Catalog.GetString("Cannot save file {0} "), fc.Filename));
+			}
+
+			if(originalCopySuccess)
+			{
+				//mini will be always png from now on (after 1.7.1-213)
+				string filenameMini = Util.GetPhotoPngFileName(true, currentPerson.UniqueID);
+				bool miniSuccess = UtilMultimedia.LoadAndResizeImage(fc.Filename, filenameMini, 150, -1); //-1: maintain aspect ratio
+
+				if(miniSuccess)
+				{
+					Pixbuf pixbuf = new Pixbuf (filenameMini);
+					image_photo_mini.Pixbuf = pixbuf;
+					button_add_photo_file.Label = Catalog.GetString("Change photo");
+					button_zoom.Sensitive = true;
+				}
+			}
+		}
+		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+		fc.Destroy();
+	}
+
 	Gtk.Window capturerWindow;
 	CapturerBin capturer;
 	void on_button_take_photo_clicked (object o, EventArgs args) 
@@ -980,7 +1073,10 @@ public class PersonAddModifyWindow
 		capturer.Run();
 	}
 
-	private void on_snapshot_done(Pixbuf pixbuf) {
+	//libCesarplayer method, jpeg
+	private void on_snapshot_done(Pixbuf pixbuf)
+	{
+		deleteOldPhotosIfAny(currentPerson.UniqueID);
 		string fileName = Path.Combine(Path.GetTempPath(), Constants.PhotoTemp +
 				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
 		
@@ -993,7 +1089,10 @@ public class PersonAddModifyWindow
 		button_zoom.Sensitive = true;
 	}
 
-	private void on_snapshot_mini_done(Pixbuf pixbuf) {
+	//libCesarplayer method, jpeg
+	private void on_snapshot_mini_done(Pixbuf pixbuf)
+	{
+		deleteOldPhotosIfAny(currentPerson.UniqueID);
 		string tempSmallFileName = Path.Combine(Path.GetTempPath(), Constants.PhotoSmallTemp +
 				Util.GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
 		
@@ -1079,10 +1178,10 @@ public class PersonAddModifyWindow
 	
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
 			Session mySession, Person currentPerson, int pDN, 
-			Gtk.CheckButton app1_checkbutton_video, bool showPhotoStuff)
+			Gtk.CheckButton app1_checkbutton_video, bool showCapturePhoto)
 	{
 		if (PersonAddModifyWindowBox == null) {
-			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson, showPhotoStuff);
+			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson, showCapturePhoto);
 		}
 
 		PersonAddModifyWindowBox.pDN = pDN;
@@ -1338,7 +1437,7 @@ public class PersonAddModifyWindow
 	
 	void on_button_height_metric_clicked(object obj, EventArgs args) 
 	{
-		genericWin = GenericWindow.Show(Catalog.GetString("Select your height"), Constants.GenericWindowShow.HEIGHTMETRIC);
+		genericWin = GenericWindow.Show(Catalog.GetString("Height"), Catalog.GetString("Select your height"), Constants.GenericWindowShow.HEIGHTMETRIC);
 		genericWin.Button_accept.Clicked += new EventHandler(on_button_height_metric_accepted);
 	}
 	void on_button_height_metric_accepted (object obj, EventArgs args)
@@ -1354,7 +1453,9 @@ public class PersonAddModifyWindow
 	
 	void on_button_weight_metric_clicked(object obj, EventArgs args) 
 	{
-		genericWin = GenericWindow.Show(Catalog.GetString("Select your weight in pounds"), Constants.GenericWindowShow.SPINDOUBLE);
+		genericWin = GenericWindow.Show(Catalog.GetString("Weight"),
+				Catalog.GetString("Select your weight in pounds"),
+				Constants.GenericWindowShow.SPINDOUBLE);
 		genericWin.Button_accept.Clicked += new EventHandler(on_button_weight_metric_accepted);
 	}
 	void on_button_weight_metric_accepted (object obj, EventArgs args)
@@ -1500,7 +1601,9 @@ public class PersonAddModifyWindow
 	void on_button_sport_add_clicked (object o, EventArgs args)
 	{
 		LogB.Information("sport add clicked");
-		genericWin = GenericWindow.Show(Catalog.GetString("Add new sport to database"), Constants.GenericWindowShow.ENTRY);
+		genericWin = GenericWindow.Show(Catalog.GetString("Add sport"),
+				Catalog.GetString("Add new sport to database"),
+				Constants.GenericWindowShow.ENTRY);
 		genericWin.Button_accept.Clicked += new EventHandler(on_sport_add_accepted);
 	}
 
@@ -1540,7 +1643,9 @@ public class PersonAddModifyWindow
 		}
 	}
 		
-	
+
+	Person loadingPerson;
+
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
 		string errorMessage = "";
@@ -1552,20 +1657,39 @@ public class PersonAddModifyWindow
 			errorMessage += "\n" + Catalog.GetString("Please, write the name of the person.");
 		if((double) spinbutton_weight.Value == 0)
 			errorMessage += "\n" + Catalog.GetString("Please, complete the weight of the person.");
-		if(errorMessage.Length > 0) {
-			ErrorWindow.Show(errorMessage);
+		if(errorMessage.Length > 0)
+		{
+			label_error.Text = errorMessage;
+			showErrorMessage(true, false);
 			return;
 		}
 
 		bool personExists;
+		bool personLoadable = false; // this person exists but is not in this session
 		if(adding)
+		{
 			personExists = Sqlite.Exists (false, Constants.PersonTable, personName);
+			if(personExists)
+			{
+				Person p = SqlitePerson.Select(false, "WHERE LOWER(name) = LOWER(\"" + personName + "\")");
+				if(p.UniqueID != -1)
+				{
+					personLoadable = ! SqlitePersonSession.PersonSelectExistsInSession(
+							p.UniqueID, currentSession.UniqueID);
+					loadingPerson = p;
+				}
+			}
+		}
 		else
 			personExists = SqlitePerson.ExistsAndItsNotMe (currentPerson.UniqueID, personName);
 
-		if(personExists) 
-			errorMessage += string.Format(Catalog.GetString("Person: '{0}' exists. Please, use another name"), 
+		if(personExists)
+		{
+			errorMessage += string.Format(Catalog.GetString("Person: '{0}' exists. Please, use another name."),
 					Util.RemoveTildeAndColonAndDot(personName) );
+			if(adding && personLoadable)
+				errorMessage += "\n" + Catalog.GetString("Or load this person from another session using this button:");
+		}
 		else {
 			//if weight has changed
 			if(!adding && (double) spinbutton_weight.Value != weightIni) {
@@ -1590,7 +1714,46 @@ public class PersonAddModifyWindow
 		}
 
 		if(errorMessage.Length > 0)
-			ErrorWindow.Show(errorMessage);
+		{
+			label_error.Text = errorMessage;
+			//show error message, show button_load_person if adding, personExists and not in this session
+			showErrorMessage(true, adding && personExists && personLoadable);
+		}
+	}
+
+	private void showErrorMessage(bool show, bool showLoadPerson)
+	{
+		vbox_error.Visible = show;
+		notebook_main.Visible = ! show;
+		hbuttonbox_main.Visible = ! show;
+
+		button_load_person.Visible = showLoadPerson;
+	}
+
+	private void on_button_load_person_clicked (object o, EventArgs args)
+	{
+		currentPerson = loadingPerson;
+		PersonAddModifyWindowBox.person_win.Hide();
+		PersonAddModifyWindowBox = null;
+
+		PersonSession myPS = SqlitePersonSession.Select(false, currentPerson.UniqueID, -1);
+
+		LogB.Information("Going to insert personSession");
+		//this inserts in DB
+		currentPersonSession = new PersonSession (
+				currentPerson.UniqueID, currentSession.UniqueID,
+				myPS.Height, myPS.Weight,
+				myPS.SportID, myPS.SpeciallityID,
+				myPS.Practice,
+				myPS.Comments,
+				false); //dbconOpened
+
+		fakeButtonAccept.Click();
+	}
+
+	private void on_button_error_go_back_clicked (object o, EventArgs args)
+	{
+		showErrorMessage(false, false);
 	}
 
 	void on_convertWeightWin_accepted (object o, EventArgs args) {
@@ -1640,6 +1803,25 @@ public class PersonAddModifyWindow
 					Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
 					textview_ps_comments.Buffer.Text, false); //dbconOpened
 			LogB.Information("inserted both");
+
+			//if we added photo while creating, filename is -1.png or -1.png, change name
+			string photo = Util.UserPhotoURL(false, -1);
+			if(photo != "")
+			{
+				if(UtilMultimedia.GetImageType(photo) == UtilMultimedia.ImageTypes.JPEG)
+					File.Move(photo, Util.GetPhotoFileName(false, currentPerson.UniqueID));
+				else if(UtilMultimedia.GetImageType(photo) == UtilMultimedia.ImageTypes.PNG)
+					File.Move(photo, Util.GetPhotoPngFileName(false, currentPerson.UniqueID));
+			}
+			photo = Util.UserPhotoURL(true, -1);
+			if(photo != "")
+			{
+				if(UtilMultimedia.GetImageType(photo) == UtilMultimedia.ImageTypes.JPEG)
+					File.Move(photo, Util.GetPhotoFileName(true, currentPerson.UniqueID));
+				else if(UtilMultimedia.GetImageType(photo) == UtilMultimedia.ImageTypes.PNG)
+					File.Move(photo, Util.GetPhotoPngFileName(true, currentPerson.UniqueID));
+			}
+
 		} else {
 			//here we update rows in the database
 			currentPerson = new Person (currentPerson.UniqueID, personName, sex, dateTime,
@@ -1729,19 +1911,21 @@ public class PersonAddMultipleWindow {
 	
 	[Widget] Gtk.Window person_multiple_infinite;
 		
+	[Widget] Gtk.VBox vbox_top;
 	[Widget] Gtk.Notebook notebook;
 	
 	[Widget] Gtk.RadioButton radio_csv;
 	[Widget] Gtk.RadioButton radio_manually;
-	[Widget] Gtk.Box hbox_csv;
 	[Widget] Gtk.Box hbox_manually;
 	[Widget] Gtk.SpinButton spin_manually;
 	
 	[Widget] Gtk.Image image_csv_headers;
 	[Widget] Gtk.Image image_csv_noheaders;
-	[Widget] Gtk.Image image_csv_headers_help;
-	[Widget] Gtk.Image image_csv_noheaders_help;
-	
+	[Widget] Gtk.Image image_load;
+	[Widget] Gtk.Label label_csv;
+	[Widget] Gtk.Label label_name;
+
+	[Widget] Gtk.Button button_manually_create;
 	[Widget] Gtk.Table table_headers_1_column;
 	[Widget] Gtk.Table table_no_headers_1_column;
 	[Widget] Gtk.Table table_headers_2_columns;
@@ -1749,14 +1933,10 @@ public class PersonAddMultipleWindow {
 	
 	[Widget] Gtk.Image image_name1;
 	[Widget] Gtk.Image image_name2;
-	[Widget] Gtk.Image image_name1_help;
-	[Widget] Gtk.Image image_name2_help;
-	
+
 	[Widget] Gtk.CheckButton check_headers;
 	[Widget] Gtk.CheckButton check_name_1_column;
 	
-	[Widget] Gtk.Label label_csv_help;
-
 	//use this to read/write table
 	ArrayList entries;
 	ArrayList radiosM;
@@ -1764,7 +1944,6 @@ public class PersonAddMultipleWindow {
 	ArrayList spins;
 	
 	int rows;
-	bool created_table;
 	
 	[Widget] Gtk.ScrolledWindow scrolledwindow;
 	[Widget] Gtk.Table table_main;
@@ -1780,7 +1959,6 @@ public class PersonAddMultipleWindow {
 	string errorExistsString;
 	string errorWeightString;
 	string errorRepeatedEntryString;
-	string tableAlreadyCreatedString = Catalog.GetString("Table has already been created.");
 
 	
 	PersonAddMultipleWindow (Gtk.Window parent, Session currentSession) {
@@ -1804,8 +1982,6 @@ public class PersonAddMultipleWindow {
 		PersonAddMultipleWindowBox.putNonStandardIcons ();
 		PersonAddMultipleWindowBox.tablesVisibility ();
 
-		PersonAddMultipleWindowBox.created_table = false;
-
 		PersonAddMultipleWindowBox.person_multiple_infinite.Show ();
 		
 		return PersonAddMultipleWindowBox;
@@ -1828,17 +2004,25 @@ public class PersonAddMultipleWindow {
 		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVHeadersIcon);
 		image_csv_headers.Pixbuf = pixbuf;
-		image_csv_headers_help.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVNoHeadersIcon);
 		image_csv_noheaders.Pixbuf = pixbuf;
-		image_csv_noheaders_help.Pixbuf = pixbuf;
 		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVName1Icon);
 		image_name1.Pixbuf = pixbuf;
-		image_name1_help.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVName2Icon);
 		image_name2.Pixbuf = pixbuf;
-		image_name2_help.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_open.png");
+		image_load.Pixbuf = pixbuf;
+
+		label_csv.Text = Catalog.GetString("CSV file has headers");
+		label_name.Text = Catalog.GetString("Full name in one column");
+
+		//label_csv_help.Text =
+			//"<b>" + Catalog.GetString("Import persons from an spreadsheet. Eg. Excel, LibreOffice, Google Drive.") + "</b>\n\n" +
+			//Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n" +
+		//	Catalog.GetString("Spreadsheet structure need to have this structure:");
+		//label_csv_help.UseMarkup = true;
 	}
 	
 	void tablesVisibility() {
@@ -1862,41 +2046,50 @@ public class PersonAddMultipleWindow {
 		button_accept.Sensitive = false;
 	}
 
-	void on_check_headers_toggled (object obj, EventArgs args) {
-		image_csv_headers.Visible = (check_headers.Active == true);
-		image_csv_noheaders.Visible = (check_headers.Active == false);
+	void on_check_headers_toggled (object obj, EventArgs args)
+	{
+		if(check_headers.Active) {
+			image_csv_headers.Visible = true;
+			image_csv_noheaders.Visible = false;
+			label_csv.Text = Catalog.GetString("CSV file has headers");
+
+		} else {
+			image_csv_headers.Visible = false;
+			image_csv_noheaders.Visible = true;
+			label_csv.Text = Catalog.GetString("CSV file does not have headers");
+		}
 
 		tablesVisibility();
 	}
-	
-	void on_check_name_1_column_toggled (object obj, EventArgs args) {
-		image_name1.Visible = (check_name_1_column.Active == true);
-		image_name2.Visible = (check_name_1_column.Active == false);
+
+	void on_check_name_1_column_toggled (object obj, EventArgs args)
+	{
+		if(check_name_1_column.Active) {
+			image_name1.Visible = true;
+			image_name2.Visible = false;
+			label_name.Text = Catalog.GetString("Full name in one column");
+		} else {
+			image_name1.Visible = false;
+			image_name2.Visible = true;
+			label_name.Text = Catalog.GetString("Full name in two columns");
+		}
 		
 		tablesVisibility();
 	}
 	
-	void on_radio_csv_toggled (object obj, EventArgs args) {
-		if(radio_csv.Active) {
-			hbox_csv.Sensitive = true;
-			hbox_manually.Sensitive = false;
-		}
+	void on_radio_csv_toggled (object obj, EventArgs args)
+	{
+		if(radio_csv.Active)
+			notebook.CurrentPage = 1;
 	}
-	void on_radio_manually_toggled (object obj, EventArgs args) {
-		if(radio_manually.Active) {
-			hbox_csv.Sensitive = false;
-			hbox_manually.Sensitive = true;
-		}
+	void on_radio_manually_toggled (object obj, EventArgs args)
+	{
+		if(radio_manually.Active)
+			notebook.CurrentPage = 0;
 	}
 		
 	void on_button_csv_load_clicked (object obj, EventArgs args) 
 	{
-		if(created_table) {
-			label_message.Text = tableAlreadyCreatedString;
-			label_message.Visible = true;
-			return;
-		}
-
 		Gtk.FileChooserDialog fc=
 			new Gtk.FileChooserDialog(Catalog.GetString("Select CSV file"),
 					null,
@@ -2000,37 +2193,21 @@ public class PersonAddMultipleWindow {
 		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
 		fc.Destroy();
 	}
-	
-	
-	void on_button_csv_help_clicked (object obj, EventArgs args) 
-	{
-		label_csv_help.Text =
-			"<b>" + Catalog.GetString("Import persons from an spreadsheet. Eg. Excel, LibreOffice, Google Drive.") + "</b>\n\n" +
-			Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n" +
-			Catalog.GetString("Spreadsheet structure need to have this structure:");
-		label_csv_help.UseMarkup = true;
 
-		notebook.CurrentPage = 1;
-	}
-	
-	void on_button_csv_help_close_clicked (object obj, EventArgs args) {
-		notebook.CurrentPage = 0;
-	}
-	
 	void on_button_manually_create_clicked (object obj, EventArgs args) 
 	{
-		if(created_table) {
-			label_message.Text = tableAlreadyCreatedString;
-			label_message.Visible = true;
-			return;
-		}
+		button_manually_create.Sensitive = false;
 
 		rows = Convert.ToInt32(spin_manually.Value);
 
 		createEmptyTable();
 	}
 
-	void createEmptyTable() {
+	void createEmptyTable()
+	{
+		vbox_top.Visible = false;
+		hbox_manually.Visible = false;
+
 		entries = new ArrayList();
 		radiosM = new ArrayList();
 		radiosF = new ArrayList();
@@ -2109,22 +2286,18 @@ public class PersonAddMultipleWindow {
 			sportStuffString += " " + Catalog.GetString("Level") + ":<i>" + Util.FindLevelName(currentSession.PersonsPractice) + "</i>.";
 
 		if(sportStuffString.Length > 0)
+		{
 			sportStuffString = Catalog.GetString("Persons will be created with default session values") + 
 				":\n" + sportStuffString;
-		label_message.Text = sportStuffString;
-		label_message.UseMarkup = true;
-		label_message.Visible = true;
+			label_message.Text = sportStuffString;
+			label_message.UseMarkup = true;
+			label_message.Visible = true;
+		}
 
 		table_main.Show();
 		scrolledwindow.Visible = true;
 		notebook.CurrentPage = 0;
-			
-		//once loaded table cannot be created again
-		//don't do this: it crashes
-		//button_manually_created.Sensitive = false;
-		//do this:
-		created_table = true;
-	
+
 		button_accept.Sensitive = true;
 	}
 
