@@ -23,13 +23,14 @@ using Gtk;
 using Gdk;
 using Glade;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List
 using System.IO; 
 
 public class PersonSelectWindow 
 {
 	[Widget] Gtk.Window person_select_window;
+	[Widget] Gtk.Viewport viewport1;
 	[Widget] Gtk.Table table1;
-	[Widget] Gtk.Button button_select;
 	[Widget] Gtk.Button button_edit;
 	[Widget] Gtk.Button button_delete;
 	[Widget] Gtk.VBox vbox_button_delete_confirm;
@@ -42,6 +43,7 @@ public class PersonSelectWindow
 	static PersonSelectWindow PersonSelectWindowBox;
 	
 	private ArrayList persons;
+	private int selectedFirstClickPersonID; //contains the uniqueID of person selected on first button click
 	public Person SelectedPerson;
 	public Gtk.Button FakeButtonAddPerson;
 	public Gtk.Button FakeButtonLoadPerson;
@@ -49,12 +51,16 @@ public class PersonSelectWindow
 	public Gtk.Button FakeButtonDeletePerson;
 	public Gtk.Button FakeButtonDone;
 
+	private List<PersonPhotoButton> list_ppb;
+
 	
 	PersonSelectWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_select_window.glade", "person_select_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
+		viewport1.HeightRequest = 170 * 3 + 8 * 2 + 4 * 2; //170 is button height, 8 is padding top botton (4+4), 4 the top and bottom of viewport1
+
 		//put an icon to window
 		UtilGtk.IconWindow(person_select_window);
 		person_select_window.Parent = parent;
@@ -115,9 +121,11 @@ public class PersonSelectWindow
 		
 		label_selected_person_name.Text = "";
 		SelectedPerson = null;
+		selectedFirstClickPersonID = -1;
 		personButtonsSensitive(false);
 		vbox_button_delete_confirm.Visible = false;
-		
+		list_ppb = new List<PersonPhotoButton>();
+
 		for (int row_i = 0; row_i < rows; row_i ++) {
 			for (int col_i = 0; col_i < cols; col_i ++) 
 			{
@@ -126,8 +134,10 @@ public class PersonSelectWindow
 				
 				Person p = (Person) persons[count ++];
 
-				PersonPhotoButton ppb = new PersonPhotoButton(p);
-				Gtk.Button b = ppb.CreateButton();
+				PersonPhotoButton ppb = new PersonPhotoButton(p.UniqueID, p.Name); //creates the button
+				list_ppb.Add(ppb);
+				Gtk.Button b = ppb.Button;
+
 				b.Show();
 			
 				b.Clicked += new EventHandler(on_button_portrait_clicked);
@@ -137,10 +147,9 @@ public class PersonSelectWindow
 						Gtk.AttachOptions.Fill, 
 						Gtk.AttachOptions.Fill, 
 						padding, padding);
-				
 			}
 		}
-				
+
 		table1.ShowAll();
 	}
 	
@@ -150,33 +159,41 @@ public class PersonSelectWindow
 
 		//access the button
 		Button b = (Button) o;
-	
-		int personID = PersonPhotoButton.GetPersonID(b);
 
-		LogB.Information("UniqueID: " + personID.ToString());
-				
-		//TODO: now need to process the signal and close
-		foreach(Person p in persons)
-			if(p.UniqueID == personID) {
-				SelectedPerson = p;
-				label_selected_person_name.Text = p.Name;
+		foreach(PersonPhotoButton ppb in list_ppb)
+		{
+			if(ppb.Button == b)
+			{
+				if(ppb.PersonID == selectedFirstClickPersonID)
+				{
+					FakeButtonDone.Click();
+					close_window();
+					return;
+				}
 
-				personButtonsSensitive(true);
+				ppb.Select(true);
+
+				foreach(Person p in persons)
+					if(p.UniqueID == ppb.PersonID)
+					{
+						SelectedPerson = p;
+						label_selected_person_name.Text = "<b>" + p.Name + "</b>";
+						label_selected_person_name.UseMarkup = true;
+						personButtonsSensitive(true);
+						selectedFirstClickPersonID = p.UniqueID;
+					}
 			}
+			else if(ppb.Selected)
+				ppb.Select(false);
+		}
 	}
 	
-	private void personButtonsSensitive(bool sensitive) {
-		button_select.Sensitive = sensitive;
+	private void personButtonsSensitive(bool sensitive)
+	{
 		button_edit.Sensitive = sensitive;
 		button_delete.Sensitive = sensitive;
 	}
 	
-	
-	private void on_button_select_clicked (object o, EventArgs args) {
-		FakeButtonDone.Click();
-		close_window();
-	}
-	
 	private void on_button_add_clicked (object o, EventArgs args) {
 		FakeButtonAddPerson.Click();
 	}
@@ -187,6 +204,28 @@ public class PersonSelectWindow
 		FakeButtonEditPerson.Click();
 	}
 
+	private void on_button_up_clicked (object o, EventArgs args)
+	{
+		vertical_scroll_change(viewport1.Vadjustment.Value - viewport1.Vadjustment.PageSize);
+	}
+
+	private void on_button_down_clicked (object o, EventArgs args)
+	{
+		vertical_scroll_change(viewport1.Vadjustment.Value + viewport1.Vadjustment.PageSize);
+	}
+
+	private void vertical_scroll_change (double newValue)
+	{
+		int min = 0;
+		double max = viewport1.Vadjustment.Upper - viewport1.Vadjustment.PageSize;
+
+		if(newValue < min)
+			newValue = min;
+		else if(newValue > max)
+			newValue = max;
+
+		viewport1.Vadjustment.Value = newValue;
+	}
 
 	//delete person stuff	
 	private void on_button_delete_clicked (object o, EventArgs args) {
@@ -220,7 +259,6 @@ public class PersonSelectWindow
 		close_window();
 	}
 	
-	//TODO: allow to close with ESC
 	private void on_delete_event (object o, DeleteEventArgs args)
 	{
 		PersonSelectWindowBox.person_select_window.Hide();
@@ -231,67 +269,156 @@ public class PersonSelectWindow
 //used by PersonSelectWindow
 public class PersonPhotoButton
 {
-	private Person p;
+	private int personID;
+	private string personName;
+	private Gtk.Button button;
+	public bool Selected;
 
-	public PersonPhotoButton (Person p) {
-		this.p = p;
+	//constructors -------------------------------
+
+	/*
+	//undefined
+	public PersonPhotoButton ()
+	{
+		personID = -1;
+		personName = "";
+		button = new Gtk.Button();
+		Selected = false;
+	}
+	*/
+
+	//used to create button
+	public PersonPhotoButton (int id, string name)
+	{
+		personID = id;
+		personName = name;
+
+		createButton();
+		Selected = false;
 	}
 
-	public Gtk.Button CreateButton () {
+	//used to get button on clicking
+	public PersonPhotoButton (Gtk.Button button)
+	{
+		this.button = button;
+		assignPersonData();
+	}
+
+	//public methods -------------------------------
+
+	public void Select (bool select)
+	{
+		Array box_elements = getButtonBoxElements(button);
+
+		//image
+		Gtk.Image image = (Gtk.Image) box_elements.GetValue(0); //the image
+
+		if(select)
+			assignPhotoToPixbuf(image, false, Util.GetImagePath(false) + "image_selected.png");
+		else
+			addUserPhotoIfExists(image);
+
+		Selected = select;
+	}
+
+
+	//private methods -------------------------------
+
+	private void assignPersonData ()
+	{
+		Array box_elements = getButtonBoxElements(button);
+
+		//access uniqueID
+		Gtk.Label l = (Gtk.Label) box_elements.GetValue(1); //the ID
+		personID = Convert.ToInt32(l.Text);
+		//LogB.Information("UniqueID: " + l.Text.ToString());
+
+		//access name
+		l = (Gtk.Label) box_elements.GetValue(2); //the name
+		personName = l.Text;
+		//LogB.Information("Name: " + l.Text.ToString());
+	}
+
+	private void createButton ()
+	{
 		Gtk.VBox vbox = new Gtk.VBox();
 
 		Gtk.Image image = new Gtk.Image();
-		string photoFile = Util.GetPhotoFileName(true, p.UniqueID);
-		if(photoFile != "" && File.Exists(photoFile)) {
-			try {
-				Pixbuf pixbuf = new Pixbuf (photoFile); //from a file
-				image.Pixbuf = pixbuf;
-				image.Visible = true;
-			}
-			catch {
-				LogB.Warning("catched while adding photo");
-			}
-		}
+		addUserPhotoIfExists(image);
+		image.HeightRequest = 150;
+		image.Visible = true;
 
-		Gtk.Label label_id = new Gtk.Label(p.UniqueID.ToString());
+		Gtk.Label label_select = new Gtk.Label("Select !");
+		label_select.Visible = false; //hide this to the user until button is clicked first time
+
+		Gtk.Label label_id = new Gtk.Label(personID.ToString());
 		label_id.Visible = false; //hide this to the user
 
-		Gtk.Label label_name = new Gtk.Label(p.Name);
+		Gtk.Label label_name = new Gtk.Label(personName);
 		label_name.Visible = true;
 
-		vbox.PackStart(image);
-		vbox.PackStart(label_id);
-		vbox.PackEnd(label_name, false, false, 1);
+		vbox.PackStart(image); 				//0
+		vbox.PackStart(label_id); 			//1
+		vbox.PackEnd(label_name, false, false, 1); 	//2
 
 		vbox.Show();
 
-		Button b = new Button(vbox);
-		b.WidthRequest=150;
-
-		return b;
+		button = new Button(vbox);
+		button.WidthRequest = 150;
+		button.HeightRequest = 170;
 	}
 
-	public static int GetPersonID (Gtk.Button b) 
+	private Array getButtonBoxElements (Gtk.Button b)
 	{
 		//access the vbox
 		Gtk.VBox box = (Gtk.VBox) b.Child;
-		
-		//access the memebers of vbox
-		Array box_elements = box.Children;
-		
-		//access uniqueID	
-		Gtk.Label l = (Gtk.Label) box_elements.GetValue(1); //the ID
-		int personID = Convert.ToInt32(l.Text);
 
-		//LogB.Information("UniqueID: " + l.Text.ToString());
-		
-		//access name
 		/*
-		l = (Gtk.Label) box_elements.GetValue(2); //the name
-		LogB.Information("Name: " + l.Text.ToString());
+		LogB.Information("printing children");
+		foreach(Gtk.Widget w in box.Children)
+			LogB.Information(w.ToString());
 		*/
 
-		return personID;
+		//access the memebers of vbox
+		return box.Children;
+	}
+
+	private void addUserPhotoIfExists (Gtk.Image image)
+	{
+		string photoFile = Util.UserPhotoURL(true, personID);
+
+		if(photoFile != "" && File.Exists(photoFile))
+			assignPhotoToPixbuf(image, true, photoFile);
+		else
+			assignPhotoToPixbuf(image, false, Util.GetImagePath(false) + "image_no_photo.png");
+	}
+
+	private void assignPhotoToPixbuf (Gtk.Image image, bool fromFile, string photoFile)
+	{
+		Pixbuf pixbuf;
+		try {
+			if(fromFile)
+				pixbuf = new Pixbuf (photoFile); //from a file
+			else
+				pixbuf = new Pixbuf (null, photoFile); //from assemblies
+
+			image.Pixbuf = pixbuf;
+		}
+		catch {
+			LogB.Warning("catched while assigning image: " + photoFile);
+		}
+	}
+
+	//------------------ accessors
+
+	public int PersonID
+	{
+		get { return personID; }
+	}
+
+	public Gtk.Button Button
+	{
+		get { return button; }
 	}
 }
 
