@@ -50,6 +50,7 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton check_appearance_maximized;
 	[Widget] Gtk.CheckButton check_appearance_maximized_undecorated;
 	[Widget] Gtk.CheckButton check_appearance_person_win_hide;
+	[Widget] Gtk.CheckButton check_appearance_person_photo;
 	[Widget] Gtk.CheckButton check_appearance_encoder_only_bars;
 	[Widget] Gtk.Alignment alignment_undecorated;
 	[Widget] Gtk.Alignment alignment_restart;
@@ -81,6 +82,7 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_do_not_use_heights_on_jump_indexes;
 			
 	//runs tab	
+	[Widget] Gtk.Image image_run_speed_start_help;
 	[Widget] Gtk.RadioButton radio_speed_ms;
 	[Widget] Gtk.RadioButton radio_speed_km;
 	[Widget] Gtk.RadioButton radio_runs_speed_start_arrival; 
@@ -108,20 +110,23 @@ public class PreferencesWindow
 	[Widget] Gtk.ComboBox combo_main_variable;
 	[Widget] Gtk.Image image_encoder_gravitatory;
 	[Widget] Gtk.Image image_encoder_inertial;
+	[Widget] Gtk.Image image_encoder_triggers;
 	[Widget] Gtk.Notebook notebook_encoder_capture_gi;
 	[Widget] Gtk.VBox vbox_encoder_inertial; //change Visible param to not have a vertical big first page with only one row of info
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_gravitatory;
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_inertial;
-	[Widget] Gtk.CheckButton checkbutton_encoder_capture_fully_extended;
-	[Widget] Gtk.HBox hbox_encoder_capture_fully_extended;
-	[Widget] Gtk.SpinButton spin_encoder_capture_fully_extended;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_best;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_4top;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
 	[Widget] Gtk.SpinButton spin_encoder_capture_barplot_font_size;
 	[Widget] Gtk.CheckButton check_show_start_and_duration;
-	[Widget] Gtk.CheckButton check_encoder_capture_cut_by_triggers;
+	[Widget] Gtk.RadioButton radio_encoder_triggers_no;
+	[Widget] Gtk.RadioButton radio_encoder_triggers_yes;
+	[Widget] Gtk.VBox vbox_encoder_triggers_yes;
+	[Widget] Gtk.RadioButton radio_encoder_triggers_yes_start_at_capture;
+	[Widget] Gtk.RadioButton radio_encoder_triggers_yes_start_at_first_trigger;
+	[Widget] Gtk.Image image_encoder_inactivity_help;
 	[Widget] Gtk.Image image_encoder_capture_cut_by_triggers_help;
 	
 	//encoder other tab
@@ -190,6 +195,10 @@ public class PreferencesWindow
 
 	//multimedia tab
 	[Widget] Gtk.CheckButton checkbutton_volume;
+	[Widget] Gtk.Table table_gstreamer;
+	[Widget] Gtk.RadioButton radio_gstreamer_0_1;
+	[Widget] Gtk.RadioButton radio_gstreamer_1_0;
+	[Widget] Gtk.Label label_test_sound_result;
 	[Widget] Gtk.Box hbox_combo_camera;
 	[Widget] Gtk.ComboBox combo_camera;
 
@@ -254,12 +263,15 @@ public class PreferencesWindow
 	}
 	
 	static public PreferencesWindow Show (Preferences preferences, List <ForceSensorRFD> rfdList, ForceSensorImpulse impulse,
-			Constants.Menuitem_modes menu_mode)
+			Constants.Menuitem_modes menu_mode, bool compujump)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
+		if(compujump)
+			PreferencesWindowBox.check_appearance_person_win_hide.Sensitive = false;
+
 		if(menu_mode !=	Constants.Menuitem_modes.JUMPSSIMPLE && menu_mode != Constants.Menuitem_modes.JUMPSREACTIVE)
 			PreferencesWindowBox.notebook.GetNthPage(JUMPSPAGE).Hide();
 		if(menu_mode !=	Constants.Menuitem_modes.RUNSSIMPLE && menu_mode != Constants.Menuitem_modes.RUNSINTERVALLIC)
@@ -295,6 +307,13 @@ public class PreferencesWindow
 		else
 			PreferencesWindowBox.check_appearance_person_win_hide.Active = false;
 
+		PreferencesWindowBox.check_appearance_person_photo.Sensitive = ! preferences.personWinHide;
+
+		if(preferences.personPhoto)
+			PreferencesWindowBox.check_appearance_person_photo.Active = true;
+		else
+			PreferencesWindowBox.check_appearance_person_photo.Active = false;
+
 		if(preferences.encoderCaptureShowOnlyBars)
 			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = true;
 		else
@@ -307,7 +326,15 @@ public class PreferencesWindow
 		else 
 			PreferencesWindowBox.checkbutton_volume.Active = false; 
 
-		PreferencesWindowBox.createComboCamera(UtilVideo.GetVideoDevices(), preferences.videoDeviceNum);
+		PreferencesWindowBox.table_gstreamer.Visible = ! UtilAll.IsWindows();
+
+		if(preferences.gstreamer == Preferences.GstreamerTypes.GST_0_1)
+			PreferencesWindowBox.radio_gstreamer_0_1.Active = true;
+		else
+			PreferencesWindowBox.radio_gstreamer_1_0.Active = true;
+		PreferencesWindowBox.label_test_sound_result.Text = "";
+
+		PreferencesWindowBox.createComboCamera(UtilMultimedia.GetVideoDevices(), preferences.videoDeviceNum);
 	
 
 		string [] decs = {"1", "2", "3"};
@@ -392,6 +419,8 @@ public class PreferencesWindow
 		PreferencesWindowBox.image_races_intervallic.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
+		PreferencesWindowBox.image_run_speed_start_help.Pixbuf = pixbuf;
+		PreferencesWindowBox.image_encoder_inactivity_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_encoder_capture_cut_by_triggers_help.Pixbuf = pixbuf;
 
 		if(menu_mode ==	Constants.Menuitem_modes.RUNSSIMPLE)
@@ -445,6 +474,8 @@ public class PreferencesWindow
 		PreferencesWindowBox.image_encoder_gravitatory.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_inertia.png");
 		PreferencesWindowBox.image_encoder_inertial.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_encoder_triggers_no.png");
+		PreferencesWindowBox.image_encoder_triggers.Pixbuf = pixbuf;
 
 		if(menu_mode ==	Constants.Menuitem_modes.POWERGRAVITATORY)
 		{
@@ -459,9 +490,6 @@ public class PreferencesWindow
 
 		PreferencesWindowBox.spin_encoder_capture_min_height_gravitatory.Value = preferences.encoderCaptureMinHeightGravitatory;
 		PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value = preferences.encoderCaptureMinHeightInertial;
-		PreferencesWindowBox.checkbutton_encoder_capture_fully_extended.Active = preferences.encoderCaptureCheckFullyExtended;
-		PreferencesWindowBox.spin_encoder_capture_fully_extended.Value = preferences.encoderCaptureCheckFullyExtendedValue;
-		PreferencesWindowBox.hbox_encoder_capture_fully_extended.Visible = preferences.encoderCaptureCheckFullyExtended;
 		
 		if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BEST)
 			PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active = true;
@@ -474,7 +502,16 @@ public class PreferencesWindow
 
 		PreferencesWindowBox.spin_encoder_capture_barplot_font_size.Value = preferences.encoderCaptureBarplotFontSize;
 		PreferencesWindowBox.check_show_start_and_duration.Active = preferences.encoderShowStartAndDuration;
-		PreferencesWindowBox.check_encoder_capture_cut_by_triggers.Active = preferences.encoderCaptureCutByTriggers;
+
+		if(preferences.encoderCaptureCutByTriggers == Preferences.TriggerTypes.NO_TRIGGERS)
+			PreferencesWindowBox.radio_encoder_triggers_no.Active = true;
+		else {
+			PreferencesWindowBox.radio_encoder_triggers_yes.Active = true;
+			if(preferences.encoderCaptureCutByTriggers == Preferences.TriggerTypes.START_AT_CAPTURE)
+				PreferencesWindowBox.radio_encoder_triggers_yes_start_at_capture.Active = true;
+			else
+				PreferencesWindowBox.radio_encoder_triggers_yes_start_at_first_trigger.Active = true;
+		}
 
 
 		//encoder other -->
@@ -527,18 +564,51 @@ public class PreferencesWindow
 		vbox_encoder_inertial.Visible = (PreferencesWindowBox.notebook_encoder_capture_gi.CurrentPage == 1);
 	}
 
+	/*
+	 * triggers stuff
+	 */
+
+	private void on_radio_encoder_triggers_toggled (object obj, EventArgs args)
+	{
+		Pixbuf pixbuf;
+		if(radio_encoder_triggers_no.Active)
+		{
+			vbox_encoder_triggers_yes.Visible = false;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_encoder_triggers_no.png");
+		PreferencesWindowBox.image_encoder_triggers.Pixbuf = pixbuf;
+		} else {
+			vbox_encoder_triggers_yes.Visible = true;
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_encoder_triggers.png");
+		}
+
+		image_encoder_triggers.Pixbuf = pixbuf;
+	}
+
 	private void on_button_encoder_capture_cut_by_triggers_help_clicked (object o, EventArgs args)
 	{
-		new DialogMessage(Constants.MessageTypes.WARNING,
-				"If active, repetitions will be cut from set using triggers." + "\n" +
-				"Triggers will be produced by a button connected to the Chronopic." + "\n\n" +
-				"This will be only used on gravitatory mode, concentric contraction.");
+		new DialogMessage(
+				"Chronojump triggers",
+				Constants.MessageTypes.INFO,
+				Catalog.GetString("If active, repetitions will be cut from set using triggers.") + "\n" +
+				Catalog.GetString("Trigger signal will be produced by a button connected to the Chronopic.") + "\n\n" +
+				Catalog.GetString("This will be only used on gravitatory mode, concentric contraction.") + "\n\n" +
+				Catalog.GetString("If \"Cut by triggers\" is inactive, repetitions will be cut automatically (default behaviour),") + " " +
+				Catalog.GetString("but pressing trigger button while capturing will plot vertical lines during analyze instant graphs.") + "\n\n" +
+				Catalog.GetString("Encoder Chronopics have trigger functionality since 2017.") + " " +
+			        Catalog.GetString("You can check if your encoder Chronopic accepts triggers pressing test button.") + " " +
+				Catalog.GetString("Your Chronopic is ready for triggers if the green light at the side of Chronopic test button changes it's state on pressing this button.") + " " +
+				Catalog.GetString("At Chronojump website there's a hand push button for using triggers with ease.")
+				);
 		/*
 		 * not on ecc-con because we cannot guaranteee that there will be an ecc and con phase,
 		 * and then R findECPhases() will fail
 		 */
 	}
-	
+
+	/*
+	 * end of triggers stuff
+	 */
+
 	private void createComboEncoderCaptureMainVariable(string v) {
 		combo_main_variable = ComboBox.NewText ();
 		string [] values = Constants.EncoderVariablesCaptureList;
@@ -574,15 +644,16 @@ public class PreferencesWindow
 		alignment_undecorated.Visible = check_appearance_maximized.Active;
 	}
 
+	private void on_check_appearance_person_win_hide_toggled (object obj, EventArgs args)
+	{
+		check_appearance_person_photo.Sensitive = ! check_appearance_person_win_hide.Active;
+	}
+
 	private void on_check_appearance_encoder_only_bars_toggled (object obj, EventArgs args) 
 	{
 		alignment_restart.Visible = ! check_appearance_encoder_only_bars.Active;
 	}
 
-	private void on_checkbutton_encoder_capture_fully_extended_toggled(object obj, EventArgs args) {
-		hbox_encoder_capture_fully_extended.Visible = checkbutton_encoder_capture_fully_extended.Active;
-	}
-
 
 	// ---- Force sensor stuff
 
@@ -876,9 +947,31 @@ public class PreferencesWindow
 
 	// ---- end of Force sensor stuff
 
+	// ---- multimedia stuff
+
+	private void on_button_test_sound_clicked (object o, EventArgs args)
+	{
+		label_test_sound_result.Text = "";
+		Util.SoundCodes sc;
+		Util.TestSound = true;
+
+		if(radio_gstreamer_0_1.Active)
+			sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, Preferences.GstreamerTypes.GST_0_1);
+		else // radio_gstreamer_1_0.Active
+			sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, Preferences.GstreamerTypes.GST_1_0);
+
+		if(sc == Util.SoundCodes.OK)
+			label_test_sound_result.Text = Catalog.GetString("Sound working");
+		else
+			label_test_sound_result.Text = Catalog.GetString("Sound not working");
+
+		Util.TestSound = false;
+	}
+
+	// ---- end of multimedia stuff
 
 	// ---- Language stuff
-	
+
 	private void createComboLanguage() {
 		
 		combo_language = ComboBox.NewText ();
@@ -946,7 +1039,24 @@ public class PreferencesWindow
 		else
 			hbox_indexes.Hide();
 	}
-	
+
+	private void on_button_run_speed_start_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage("Chronojump - " + Catalog.GetString("Race measurement"),
+				Constants.MessageTypes.INFO,
+				Catalog.GetString(
+					"\"Speed start\" means when athlete does not start with \"contact\" on the " +
+					"first platform or photocell.\n" +
+					"It starts before and arrives there with some speed.") +
+				"\n\n" +
+				Catalog.GetString("Chronojump race reaction time device allows to record reaction time and race time.") +
+				"\n -" +
+				Catalog.GetString("Reaction time is displayed on Description column.") +
+				"\n -" +
+				Catalog.GetString("If first option is choosen, race time includes reaction time.")
+				);
+	}
+
 	private void on_checkbutton_runs_prevent_double_contact_toggled (object o, EventArgs args) {
 		vbox_runs_prevent_double_contact.Visible = checkbutton_runs_prevent_double_contact.Active;
 	}
@@ -1403,6 +1513,10 @@ public class PreferencesWindow
 			SqlitePreferences.Update("personWinHide", PreferencesWindowBox.check_appearance_person_win_hide.Active.ToString(), true);
 			preferences.personWinHide = PreferencesWindowBox.check_appearance_person_win_hide.Active;
 		}
+		if( preferences.personPhoto != PreferencesWindowBox.check_appearance_person_photo.Active ) {
+			SqlitePreferences.Update("personPhoto", PreferencesWindowBox.check_appearance_person_photo.Active.ToString(), true);
+			preferences.personPhoto = PreferencesWindowBox.check_appearance_person_photo.Active;
+		}
 		if( preferences.encoderCaptureShowOnlyBars != PreferencesWindowBox.check_appearance_encoder_only_bars.Active ) {
 			SqlitePreferences.Update("encoderCaptureShowOnlyBars", PreferencesWindowBox.check_appearance_encoder_only_bars.Active.ToString(), true);
 			preferences.encoderCaptureShowOnlyBars = PreferencesWindowBox.check_appearance_encoder_only_bars.Active;
@@ -1580,16 +1694,6 @@ public class PreferencesWindow
 				preferences.encoderCaptureMinHeightInertial,
 				(int) PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value);
 
-		preferences.encoderCaptureCheckFullyExtended = preferencesChange(
-				"encoderCaptureCheckFullyExtended",
-				preferences.encoderCaptureCheckFullyExtended,
-				PreferencesWindowBox.checkbutton_encoder_capture_fully_extended.Active);
-		
-		preferences.encoderCaptureCheckFullyExtendedValue = preferencesChange(
-				"encoderCaptureCheckFullyExtendedValue",
-				preferences.encoderCaptureCheckFullyExtendedValue,
-				(int) PreferencesWindowBox.spin_encoder_capture_fully_extended.Value);
-
 		if(PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active) {
 			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), true);
 			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.BEST;
@@ -1616,11 +1720,27 @@ public class PreferencesWindow
 				"encoderShowStartAndDuration",
 				preferences.encoderShowStartAndDuration,
 				PreferencesWindowBox.check_show_start_and_duration.Active);
-		
-		preferences.encoderCaptureCutByTriggers = preferencesChange(
-				"encoderCaptureCutByTriggers",
-				preferences.encoderCaptureCutByTriggers,
-				PreferencesWindowBox.check_encoder_capture_cut_by_triggers.Active);
+
+		if(PreferencesWindowBox.radio_encoder_triggers_no.Active &&
+				preferences.encoderCaptureCutByTriggers != Preferences.TriggerTypes.NO_TRIGGERS)
+		{
+			SqlitePreferences.Update("encoderCaptureCutByTriggers", Preferences.TriggerTypes.NO_TRIGGERS.ToString(), true);
+			preferences.encoderCaptureCutByTriggers = Preferences.TriggerTypes.NO_TRIGGERS;
+		}
+		else if(PreferencesWindowBox.radio_encoder_triggers_yes.Active &&
+				PreferencesWindowBox.radio_encoder_triggers_yes_start_at_capture.Active &&
+				preferences.encoderCaptureCutByTriggers != Preferences.TriggerTypes.START_AT_CAPTURE)
+		{
+			SqlitePreferences.Update("encoderCaptureCutByTriggers", Preferences.TriggerTypes.START_AT_CAPTURE.ToString(), true);
+			preferences.encoderCaptureCutByTriggers = Preferences.TriggerTypes.START_AT_CAPTURE;
+		}
+		else if(PreferencesWindowBox.radio_encoder_triggers_yes.Active &&
+				PreferencesWindowBox.radio_encoder_triggers_yes_start_at_first_trigger.Active &&
+				preferences.encoderCaptureCutByTriggers != Preferences.TriggerTypes.START_AT_FIRST_ON)
+		{
+			SqlitePreferences.Update("encoderCaptureCutByTriggers", Preferences.TriggerTypes.START_AT_FIRST_ON.ToString(), true);
+			preferences.encoderCaptureCutByTriggers = Preferences.TriggerTypes.START_AT_FIRST_ON;
+		}
 
 		//---- end of encoder capture
 		
@@ -1681,6 +1801,17 @@ public class PreferencesWindow
 			preferences.volumeOn = PreferencesWindowBox.checkbutton_volume.Active;
 		}
 
+		if( preferences.gstreamer == Preferences.GstreamerTypes.GST_0_1 && radio_gstreamer_1_0.Active)
+		{
+			SqlitePreferences.Update(Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_1_0.ToString(), true);
+			preferences.gstreamer = Preferences.GstreamerTypes.GST_1_0;
+		}
+		else if( preferences.gstreamer == Preferences.GstreamerTypes.GST_1_0 && radio_gstreamer_0_1.Active)
+		{
+			SqlitePreferences.Update(Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_0_1.ToString(), true);
+			preferences.gstreamer = Preferences.GstreamerTypes.GST_0_1;
+		}
+
 		if( preferences.videoDeviceNum != UtilGtk.ComboGetActivePos(combo_camera) ) {
 			SqlitePreferences.Update("videoDevice", UtilGtk.ComboGetActivePos(combo_camera).ToString(), true);
 			preferences.videoDeviceNum = UtilGtk.ComboGetActivePos(combo_camera);
