@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -33,14 +33,10 @@ public partial class ChronoJumpWindow
 {
 	//presentation
 	[Widget] Gtk.Box vbox_presentation;
-	[Widget] Gtk.ScrolledWindow scrolledwindow_presentation;
-	[Widget] Gtk.Button button_presentation_fullscreen;
-	[Widget] Gtk.Button button_presentation_restore_screen;
 	[Widget] Gtk.Image image_presentation_logo;
 	[Widget] Gtk.Label label_presentation_current;
 
 	//static WebKit.WebView presentation;
-	Thread presentationThread;
 
 	bool presentationInitialized = false;
 
