@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -39,7 +39,7 @@ public class EditPulseWindow : EditEventWindow
 
 	EditPulseWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "edit_event", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "edit_event.glade", "edit_event", null);
 		gladeXML.Autoconnect(this);
 		this.parent 	= parent;
 		
@@ -124,9 +124,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_radio_pulses_custom;
 	[Widget] Gtk.RadioButton extra_window_radio_pulses_free;
 	
-	[Widget] Gtk.Label label_extra_window_radio_pulses_custom;
-	[Widget] Gtk.Label label_extra_window_radio_pulses_free;
-	
 	[Widget] Gtk.HBox hbox_extra_window_pulses;
 	[Widget] Gtk.SpinButton extra_window_pulses_spinbutton_pulse_step;
 	[Widget] Gtk.SpinButton extra_window_pulses_spinbutton_ppm;
@@ -136,7 +133,6 @@ public partial class ChronoJumpWindow
 	
 
 	double extra_window_pulseStep = 1.000;
-	bool extra_window_unlimited = true;
 	int extra_window_totalPulses = 10;
 	
 	private void on_extra_window_pulses_test_changed(object o, EventArgs args)
@@ -210,7 +206,6 @@ public class RepairPulseWindow
 	[Widget] Gtk.TextView textview1;
 
 	static RepairPulseWindow RepairPulseWindowBox;
-	Gtk.Window parent;
 
 	PulseType pulseType;
 	Pulse myPulse; //used on button_accept
@@ -218,13 +213,13 @@ public class RepairPulseWindow
 
 	RepairPulseWindow (Gtk.Window parent, Pulse myPulse, int pDN) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "repair_sub_event", "chronojump");
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "repair_sub_event.glade", "repair_sub_event", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
 		UtilGtk.IconWindow(repair_sub_event);
 
-		this.parent = parent;
+		repair_sub_event.Parent = parent;
 		this.myPulse = myPulse;
 	
 		repair_sub_event.Title = Catalog.GetString("Repair pulse");
