@@ -27,7 +27,8 @@ using Mono.Unix;
 public class RepetitiveConditionsWindow 
 {
 	[Widget] Gtk.Window repetitive_conditions;
-//	[Widget] Gtk.ScrolledWindow scrolled_conditions;
+	[Widget] Gtk.Notebook notebook_main;
+	//[Widget] Gtk.ScrolledWindow scrolled_conditions;
 
 	[Widget] Gtk.Frame frame_best_and_worst;
 	[Widget] Gtk.Box hbox_jump_best_worst;
@@ -71,6 +72,7 @@ public class RepetitiveConditionsWindow
 
 	/* encoder */
 	[Widget] Gtk.Frame frame_encoder_automatic_conditions;
+	[Widget] Gtk.RadioButton radio_encoder_relative_to_set;
 	[Widget] Gtk.HBox hbox_combo_encoder_variable_automatic;
 	[Widget] Gtk.ComboBox combo_encoder_variable_automatic;
 	[Widget] Gtk.CheckButton checkbutton_encoder_automatic_greater;
@@ -113,6 +115,7 @@ public class RepetitiveConditionsWindow
 
 
 	[Widget] Gtk.Button button_test_good;
+	[Widget] Gtk.Label label_test_sound_result;
 	[Widget] Gtk.Button button_close;
 
 	//bells good (green)
@@ -149,17 +152,47 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_encoder_power_lower;
 	[Widget] Gtk.Image image_encoder_peakpower_lower;
 	[Widget] Gtk.Image image_repetitive_test_bad;
-	
+
+	//encoder rhythm
+	[Widget] Gtk.Label label_rhythm_tab;
+	[Widget] Gtk.CheckButton check_rhythm_active;
+	[Widget] Gtk.RadioButton radio_rhythm_together;
+	[Widget] Gtk.RadioButton radio_rhythm_separated;
+	[Widget] Gtk.Notebook notebook_duration_repetition;
+	[Widget] Gtk.VBox vbox_rhythm_cluster;
+	[Widget] Gtk.Frame frame_rhythm;
+	[Widget] Gtk.CheckButton check_rhythm_use_clusters;
+	[Widget] Gtk.SpinButton	spin_rhythm_rep;
+	[Widget] Gtk.SpinButton	spin_rhythm_ecc;
+	[Widget] Gtk.SpinButton	spin_rhythm_con;
+	[Widget] Gtk.Label label_rhythm_ecc_plus_con;
+	[Widget] Gtk.SpinButton	spin_rhythm_rest_reps;
+	[Widget] Gtk.VBox vbox_rhythm_rest_after;
+	[Widget] Gtk.RadioButton radio_rest_after_ecc;
+	[Widget] Gtk.SpinButton	spin_rhythm_reps_cluster;
+	[Widget] Gtk.SpinButton	spin_rhythm_rest_clusters;
+	[Widget] Gtk.Image image_clusters_info;
+	[Widget] Gtk.HBox hbox_rhythm_rest_reps_value;
+	[Widget] Gtk.CheckButton check_rhythm_rest_reps;
+
+
+	const int FEEDBACKPAGE = 0;
+	const int RHYTHMPAGE = 1;
+
 	public Gtk.Button FakeButtonClose;
 
 	//static bool volumeOn;
 	bool volumeOn;
+	public Preferences.GstreamerTypes gstreamer;
 
-	private double bestSetValue;
+	public enum BestSetValueEnum { CAPTURE_MAIN_VARIABLE, AUTOMATIC_FEEDBACK}
+	private double bestSetValueCaptureMainVariable;
+	private double bestSetValueAutomaticFeedback;
 	
 	static RepetitiveConditionsWindow RepetitiveConditionsWindowBox;
 		
-	RepetitiveConditionsWindow () {
+	RepetitiveConditionsWindow ()
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "repetitive_conditions.glade", "repetitive_conditions", "chronojump");
 		gladeXML.Autoconnect(this);
@@ -174,10 +207,13 @@ public class RepetitiveConditionsWindow
 		
 		createComboEncoderAutomaticVariable();
 
-		bestSetValue = 0;
+		bestSetValueCaptureMainVariable = 0;
+		bestSetValueCaptureMainVariable = 0;
 		notebook_encoder_conditions.CurrentPage = 3; //power
 
 		putNonStandardIcons();
+
+		label_rhythm_tab.Text = Catalog.GetString("Rhythm") + " / " + Catalog.GetString("Protocol");
 	}
 
 	static public RepetitiveConditionsWindow Create ()
@@ -192,19 +228,21 @@ public class RepetitiveConditionsWindow
 		return RepetitiveConditionsWindowBox;
 	}
 	
-	public void View (Constants.BellModes bellMode, bool volumeOn) {
-		//this.volumeOn = volumeOn;
-
+	public void View (Constants.BellModes bellMode, bool volumeOn, Preferences.GstreamerTypes gstreamer,
+			EncoderRhythm encoderRhythm)
+	{
 		//when user "deleted_event" the window
 		if (RepetitiveConditionsWindowBox == null) {
 			RepetitiveConditionsWindowBox = new RepetitiveConditionsWindow (); 
 		}
-		RepetitiveConditionsWindowBox.showWidgets(bellMode);
+		RepetitiveConditionsWindowBox.showWidgets(bellMode, encoderRhythm);
+
 		RepetitiveConditionsWindowBox.repetitive_conditions.Show ();
 		RepetitiveConditionsWindowBox.volumeOn = volumeOn;
+		RepetitiveConditionsWindowBox.gstreamer = gstreamer;
 	}
 
-	void showWidgets(Constants.BellModes bellMode)
+	void showWidgets(Constants.BellModes bellMode, EncoderRhythm encoderRhythm)
 	{
 		frame_best_and_worst.Hide();
 		frame_conditions.Hide();
@@ -217,6 +255,9 @@ public class RepetitiveConditionsWindow
 		notebook_encoder_conditions.Hide();
 		checkbutton_inertial_discard_first_three.Hide();
 
+		notebook_main.GetNthPage(RHYTHMPAGE).Hide();
+		notebook_main.ShowTabs = false;
+
 		if(bellMode == Constants.BellModes.JUMPS) {
 			frame_best_and_worst.Show();
 			hbox_jump_best_worst.Show();
@@ -229,25 +270,48 @@ public class RepetitiveConditionsWindow
 			frame_conditions.Show();
 		} else { //encoder (grav and inertial)
 			frame_encoder_automatic_conditions.Show();
+			notebook_main.ShowTabs = true;
+
 			vbox_encoder_manual.Show();
 			if(checkbutton_encoder_show_manual_feedback.Active)
 				notebook_encoder_conditions.Show();
 
 			if(bellMode == Constants.BellModes.ENCODERINERTIAL)
 				checkbutton_inertial_discard_first_three.Show();
+
+			notebook_main.GetNthPage(RHYTHMPAGE).Show();
+			encoder_rhythm_set_values(encoderRhythm);
 		}
+
+		label_test_sound_result.Text = "";
 	}
 		
-	private void createComboEncoderAutomaticVariable() {
+	private void createComboEncoderAutomaticVariable()
+	{
 		combo_encoder_variable_automatic = ComboBox.NewText ();
-		string [] values = { Constants.MeanSpeed, Constants.MaxSpeed, Constants.MeanForce, Constants.MaxForce, Constants.MeanPower, Constants.PeakPower };
-		UtilGtk.ComboUpdate(combo_encoder_variable_automatic, values, "");
-		combo_encoder_variable_automatic.Active = UtilGtk.ComboMakeActive(combo_encoder_variable_automatic, "Mean power");
-		
+
+		comboEncoderAutomaticVariableFillThisSet();
+
 		hbox_combo_encoder_variable_automatic.PackStart(combo_encoder_variable_automatic, false, false, 0);
 		hbox_combo_encoder_variable_automatic.ShowAll();
 		combo_encoder_variable_automatic.Sensitive = true;
 	}
+	//all values
+	private void comboEncoderAutomaticVariableFillThisSet()
+	{
+		string [] values = { Constants.MeanSpeed, Constants.MaxSpeed, Constants.MeanForce, Constants.MaxForce, Constants.MeanPower, Constants.PeakPower };
+
+		UtilGtk.ComboUpdate(combo_encoder_variable_automatic, values, "");
+		combo_encoder_variable_automatic.Active = UtilGtk.ComboMakeActive(combo_encoder_variable_automatic, "Mean power");
+	}
+	//currently only power
+	private void comboEncoderAutomaticVariableFillHistorical()
+	{
+		string [] values = { Constants.MeanPower };
+
+		UtilGtk.ComboUpdate(combo_encoder_variable_automatic, values, "");
+		combo_encoder_variable_automatic.Active = UtilGtk.ComboMakeActive(combo_encoder_variable_automatic, "Mean power");
+	}
 
 	private void putNonStandardIcons() {
 		Pixbuf pixbuf;
@@ -286,15 +350,30 @@ public class RepetitiveConditionsWindow
 		image_encoder_power_lower.Pixbuf = pixbuf;
 		image_encoder_peakpower_lower.Pixbuf = pixbuf;
 		image_repetitive_test_bad.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
+		image_clusters_info.Pixbuf = pixbuf;
 	}
 
 	void on_button_test_clicked (object o, EventArgs args)
 	{
-		if(volumeOn) {
+		if(volumeOn)
+		{
+			Util.TestSound = true;
+
+			label_test_sound_result.Text = "";
+			Util.SoundCodes sc;
 			if (o == button_test_good) 
-				Util.PlaySound(Constants.SoundTypes.GOOD, true);
+				sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, gstreamer);
 			else //button_test_bad
-				Util.PlaySound(Constants.SoundTypes.BAD, true);
+				sc = Util.PlaySound(Constants.SoundTypes.BAD, true, gstreamer);
+
+			if(sc == Util.SoundCodes.OK)
+				label_test_sound_result.Text = Catalog.GetString("Sound working");
+			else
+				label_test_sound_result.Text = Catalog.GetString("Sound not working");
+
+			Util.TestSound = false;
 		} else
 			new DialogMessage(Constants.MessageTypes.INFO, 
 					Catalog.GetString("You need to activate sounds in preferences / multimedia."));
@@ -305,7 +384,7 @@ public class RepetitiveConditionsWindow
 	{
 		RepetitiveConditionsWindowBox.repetitive_conditions.Hide();
 		FakeButtonClose.Click();
-//		RepetitiveConditionsWindowBox = null;
+		//RepetitiveConditionsWindowBox = null;
 	}
 
 	void on_delete_event (object o, DeleteEventArgs args)
@@ -350,6 +429,9 @@ public class RepetitiveConditionsWindow
 	public bool VolumeOn {
 		set { volumeOn = value; }
 	}
+	public Preferences.GstreamerTypes Gstreamer {
+		set { gstreamer = value; }
+	}
 
 	/* Auto.mark checkbox if spinbutton is changed */
 	
@@ -391,6 +473,16 @@ public class RepetitiveConditionsWindow
 	}
 
 	/* encoder */
+
+	void on_radio_encoder_relative_to_toggled (object o, EventArgs args)
+	{
+		if(radio_encoder_relative_to_set.Active)
+			comboEncoderAutomaticVariableFillThisSet();
+		else
+			comboEncoderAutomaticVariableFillHistorical();
+	}
+
+
 	void on_spinbutton_encoder_automatic_greater_value_changed (object o, EventArgs args) {
 		checkbutton_encoder_automatic_greater.Active = true;
 	}
@@ -454,56 +546,205 @@ public class RepetitiveConditionsWindow
 		checkbutton_encoder_peakpower_lower.Active = true;
 	}
 
-			
-	public void ResetBestSetValue() {
-	       bestSetValue = 0;	
+	private double getBestSetValue (BestSetValueEnum b)
+	{
+		if(b == BestSetValueEnum.AUTOMATIC_FEEDBACK)
+			return bestSetValueAutomaticFeedback;
+		else	// b == BestSetValueEnum.CAPTURE_MAIN_VARIABLE
+			return bestSetValueCaptureMainVariable;
 	}
 
-	public void UpdateBestSetValue(EncoderCurve curve) 
+	public void ResetBestSetValue (BestSetValueEnum b)
 	{
+		if(b == BestSetValueEnum.AUTOMATIC_FEEDBACK)
+			bestSetValueAutomaticFeedback = 0;
+		else	// b == BestSetValueEnum.CAPTURE_MAIN_VARIABLE
+			bestSetValueCaptureMainVariable = 0;
+	}
+
+	public void UpdateBestSetValue (EncoderCurve curve)
+	{
+		BestSetValueEnum b = BestSetValueEnum.AUTOMATIC_FEEDBACK;
 		string autoVar = encoderAutomaticVariable;
 		if(encoderAutomaticHigher || encoderAutomaticLower) 
 		{
 			if(autoVar == Constants.MeanSpeed)
-				UpdateBestSetValue(curve.MeanSpeedD);
+				UpdateBestSetValue(b, curve.MeanSpeedD);
 			else if(autoVar == Constants.MaxSpeed)
-				UpdateBestSetValue(curve.MaxSpeedD);
+				UpdateBestSetValue(b, curve.MaxSpeedD);
 			else if(autoVar == Constants.MeanPower)
-				UpdateBestSetValue(curve.MeanPowerD);
+				UpdateBestSetValue(b, curve.MeanPowerD);
 			else if(autoVar == Constants.PeakPower)
-				UpdateBestSetValue(curve.PeakPowerD);
+				UpdateBestSetValue(b, curve.PeakPowerD);
 			else if(autoVar == Constants.MeanForce)
-				UpdateBestSetValue(curve.MeanForceD);
+				UpdateBestSetValue(b, curve.MeanForceD);
 			else if(autoVar == Constants.MaxForce)
-				UpdateBestSetValue(curve.MaxForceD);
+				UpdateBestSetValue(b, curve.MaxForceD);
 		}
 	}
-	public void UpdateBestSetValue(double d) {
-		if(d > bestSetValue)
-			bestSetValue = d;
+	public void UpdateBestSetValue(BestSetValueEnum b, double d)
+	{
+		if(b == BestSetValueEnum.AUTOMATIC_FEEDBACK)
+		{
+			if(d > bestSetValueAutomaticFeedback)
+				bestSetValueAutomaticFeedback = d;
+		} else
+		{ 	// b == BestSetValueEnum.CAPTURE_MAIN_VARIABLE
+			if(d > bestSetValueCaptureMainVariable)
+				bestSetValueCaptureMainVariable = d;
+		}
 	}
 		
 	//called from gui/encoderTreeviews.cs
-	public string AssignColorAutomatic(EncoderCurve curve, string variable)
+	public string AssignColorAutomatic(BestSetValueEnum b, EncoderCurve curve, string variable)
 	{
 		if(encoderAutomaticVariable != variable)
 			return UtilGtk.ColorNothing;
 
 		double currentValue = curve.GetParameter(variable);
 
-		return AssignColorAutomatic(currentValue);
+		return AssignColorAutomatic(b, currentValue);
 	}
-	//called from gui/encoder.cs plotCurvesGraphDoPlot
-	public string AssignColorAutomatic(double currentValue)
+	//called from previous function, gui/encoder.cs plotCurvesGraphDoPlot
+	public string AssignColorAutomatic(BestSetValueEnum b, double currentValue)
 	{
-		if(encoderAutomaticHigher && currentValue > bestSetValue * encoderAutomaticHigherValue / 100)
+		if(encoderAutomaticHigher && currentValue > getBestSetValue(b) * encoderAutomaticHigherValue / 100)
 			return UtilGtk.ColorGood;
-		else if (encoderAutomaticLower && currentValue < bestSetValue * encoderAutomaticLowerValue/ 100)
+		else if (encoderAutomaticLower && currentValue < getBestSetValue(b) * encoderAutomaticLowerValue/ 100)
 			return UtilGtk.ColorBad;
 
 		return UtilGtk.ColorNothing;
 	}
 
+	//encoder rhythm
+	private void on_check_rhythm_active_toggled (object o, EventArgs args)
+	{
+		frame_rhythm.Visible = check_rhythm_active.Active;
+	}
+
+	private void on_radio_rhythm_together_toggled (object o, EventArgs args)
+	{
+		if(radio_rhythm_together.Active)
+			notebook_duration_repetition.CurrentPage = 0;
+		else
+			notebook_duration_repetition.CurrentPage = 1;
+
+		should_show_vbox_rhythm_rest_after();
+	}
+
+	private void on_spin_rhythm_phases_values_changed (object o, EventArgs args)
+	{
+		label_rhythm_ecc_plus_con.Text = Util.TrimDecimals(spin_rhythm_ecc.Value + spin_rhythm_con.Value, 2);
+	}
+
+	private void should_show_vbox_rhythm_rest_after()
+	{
+		vbox_rhythm_rest_after.Visible = ( check_rhythm_use_clusters.Active ||
+				( check_rhythm_rest_reps.Active && radio_rhythm_separated.Active ) );
+	}
+
+	private void on_check_rhythm_rest_reps_toggled (object o, EventArgs args)
+	{
+		if(check_rhythm_rest_reps.Active)
+			hbox_rhythm_rest_reps_value.Visible = true;
+		else
+			hbox_rhythm_rest_reps_value.Visible = false;
+
+		should_show_vbox_rhythm_rest_after();
+	}
+
+	private void on_check_rhythm_use_clusters_toggled (object o, EventArgs args)
+	{
+		vbox_rhythm_cluster.Visible = check_rhythm_use_clusters.Active;
+		should_show_vbox_rhythm_rest_after();
+	}
+
+	private void on_button_use_clusters_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(
+				Catalog.GetString("Use clusters"),
+				Constants.MessageTypes.INFO,
+				Catalog.GetString("Use clusters in order to group repetitions inside a set separated by rest time.")
+				+ "\n\n" +
+				Catalog.GetString("Set will end when user press Finish or Cancel or when there's no change in the encoder during this time:\n" +
+					"1.5 * Rest between clusters") );
+	}
+
+
+	private void on_button_rhythm_default_clicked (object o, EventArgs args)
+	{
+		//have default values
+		EncoderRhythm encoderRhythm = new EncoderRhythm();
+		//But have rhythm active
+		encoderRhythm.Active = true;
+
+		//modify widgets
+		encoder_rhythm_set_values(encoderRhythm);
+	}
+
+	private void encoder_rhythm_set_values(EncoderRhythm encoderRhythm)
+	{
+		check_rhythm_active.Active = encoderRhythm.Active;
+
+		/*
+		if(encoderRhythm.RepsOrPhases)
+			radio_rhythm_together.Active = true;
+		else
+			radio_rhythm_separated.Active = true;
+			*/
+		//just before 1.8.0 always use separated
+		radio_rhythm_separated.Active = true;
+
+		//spin_rhythm_rep.Value = encoderRhythm.RepSeconds;
+		spin_rhythm_ecc.Value = encoderRhythm.EccSeconds;
+		spin_rhythm_con.Value = encoderRhythm.ConSeconds;
+		spin_rhythm_rest_reps.Value = encoderRhythm.RestRepsSeconds;
+		spin_rhythm_reps_cluster.Value = encoderRhythm.RepsCluster;
+		spin_rhythm_rest_clusters.Value = encoderRhythm.RestClustersSeconds;
+
+		frame_rhythm.Visible = check_rhythm_active.Active;
+
+		if(encoderRhythm.RepsOrPhases)
+			notebook_duration_repetition.CurrentPage = 0;
+		else
+			notebook_duration_repetition.CurrentPage = 1;
+
+		if(encoderRhythm.RestRepsSeconds < 0.1)
+			check_rhythm_rest_reps.Active = false;
+
+		if(encoderRhythm.UseClusters()) {
+			check_rhythm_use_clusters.Active = true;
+			vbox_rhythm_cluster.Visible = true;
+		} else {
+			check_rhythm_use_clusters.Active = false;
+			vbox_rhythm_cluster.Visible = false;
+		}
+
+		should_show_vbox_rhythm_rest_after();
+	}
+
+	public EncoderRhythm Encoder_rhythm_get_values()
+	{
+		int reps_cluster = Convert.ToInt32(spin_rhythm_reps_cluster.Value);
+		if(! check_rhythm_use_clusters.Active && reps_cluster > 1)
+			reps_cluster = 1;
+
+		//avoid problems like having spin values of: 1.38777878078145E-16 (true story)
+		double restReps = spin_rhythm_rest_reps.Value;
+		if(restReps < 0.1 || ! check_rhythm_rest_reps.Active)
+			restReps = 0;
+		double restClusters = spin_rhythm_rest_clusters.Value;
+		if(restClusters < 0.1)
+			restClusters = 0;
+
+		return new EncoderRhythm(
+				check_rhythm_active.Active, radio_rhythm_together.Active,
+				spin_rhythm_rep.Value, spin_rhythm_ecc.Value, spin_rhythm_con.Value,
+				restReps, radio_rest_after_ecc.Active,
+				reps_cluster, restClusters);
+	}
+
+
 	/* JUMPS */
 	public bool TfTcBest {
 		get { return checkbutton_jump_tf_tc_best.Active; }
@@ -609,7 +850,11 @@ public class RepetitiveConditionsWindow
 	private int encoderAutomaticLowerValue {
 		get { return Convert.ToInt32(spinbutton_encoder_automatic_lower.Value); }
 	}
-	
+
+	public bool EncoderRelativeToSet {
+		get { return radio_encoder_relative_to_set.Active; }
+	}
+
 	public double GetMainVariableHigher(string mainVariable) 
 	{
 		if(mainVariable == Constants.MeanSpeed && EncoderMeanSpeedHigher)
