@@ -898,17 +898,19 @@ public class RepairRunIntervalWindow
 public partial class ChronoJumpWindow
 {
 	//options runs
-	[Widget] Gtk.Label extra_window_runs_label_distance;
-	[Widget] Gtk.SpinButton extra_window_runs_spinbutton_distance;
-	[Widget] Gtk.Label extra_window_runs_label_distance_units;
-	
+	[Widget] Gtk.CheckButton check_run_simple_with_reaction_time;
+	[Widget] Gtk.Button button_runs_simple_track_distance;
+	[Widget] Gtk.Label label_runs_simple_track_distance_value;
+	[Widget] Gtk.Label label_runs_simple_track_distance_units;
+
 	//options runs interval
-	[Widget] Gtk.Label extra_window_runs_interval_label_distance;
-	[Widget] Gtk.SpinButton extra_window_runs_interval_spinbutton_distance;
-	[Widget] Gtk.Label extra_window_runs_interval_label_distance_units;
+	[Widget] Gtk.Button button_runs_interval_track_distance;
+	[Widget] Gtk.Label label_runs_interval_track_distance_value;
+	//[Widget] Gtk.Label label_runs_interval_track_distance_units; //always "m"
 	[Widget] Gtk.Label extra_window_runs_interval_label_limit;
 	[Widget] Gtk.SpinButton extra_window_runs_interval_spinbutton_limit;
 	[Widget] Gtk.Label extra_window_runs_interval_label_limit_units;
+	[Widget] Gtk.CheckButton check_run_interval_with_reaction_time;
 	
 
 	double extra_window_runs_distance = 100;
@@ -978,19 +980,17 @@ public partial class ChronoJumpWindow
 		currentEventType = myRunType;
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
 
-		extra_window_runs_label_distance.Text = Catalog.GetString("Lap distance (between barriers)");
-		extra_window_runs_label_distance_units.Text = Catalog.GetString("meters");
+		label_runs_simple_track_distance_units.Text = "m";
 
 		if(myRunType.Distance > 0) {
-			extra_window_runs_spinbutton_distance.Value = myRunType.Distance;
+			label_runs_simple_track_distance_value.Text = myRunType.Distance.ToString();
 			extra_window_showDistanceData(myRunType, true, false);	//visible, sensitive
 		} else {
 			if(myRunType.Name == "Margaria") {
-				extra_window_runs_label_distance.Text = Catalog.GetString("Vertical distance between\nstairs third and nine.");
-				extra_window_runs_label_distance_units.Text = Catalog.GetString("Millimeters.");
-				extra_window_runs_spinbutton_distance.Value = 1050;
+				label_runs_simple_track_distance_value.Text = "1050";
+				label_runs_simple_track_distance_units.Text = "mm";
 			} else {
-				extra_window_runs_spinbutton_distance.Value = extra_window_runs_distance; 
+				label_runs_simple_track_distance_value.Text = extra_window_runs_distance.ToString();
 			}
 			extra_window_showDistanceData(myRunType, true, true);	//visible, sensitive
 		}
@@ -1036,10 +1036,10 @@ public partial class ChronoJumpWindow
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
 
 		if(myRunType.Distance > 0) {
-			extra_window_runs_interval_spinbutton_distance.Value = myRunType.Distance;
+			label_runs_interval_track_distance_value.Text = myRunType.Distance.ToString();
 			extra_window_showDistanceData(myRunType, true, false);	//visible, sensitive
 		} else if(myRunType.Distance == 0) {
-			extra_window_runs_interval_spinbutton_distance.Value = extra_window_runs_interval_distance; 
+			label_runs_interval_track_distance_value.Text = extra_window_runs_interval_distance.ToString();
 			extra_window_showDistanceData(myRunType, true, true);	//visible, sensitive
 		} else { //variableDistancesString (eg. MTGUG) don't show anything
 			extra_window_showDistanceData(myRunType, false, false);	//visible, sensitive
@@ -1124,21 +1124,11 @@ public partial class ChronoJumpWindow
 
 	private void extra_window_showDistanceData (RunType myRunType, bool show, bool sensitive ) {
 		if(myRunType.HasIntervals) {
-			extra_window_runs_interval_label_distance.Visible = show;
-			extra_window_runs_interval_spinbutton_distance.Visible = show;
-			extra_window_runs_interval_label_distance_units.Visible = show;
-		
-			extra_window_runs_interval_label_distance.Sensitive = sensitive;
-			extra_window_runs_interval_spinbutton_distance.Sensitive = sensitive;
-			extra_window_runs_interval_label_distance_units.Sensitive = sensitive;
+			button_runs_interval_track_distance.Visible = show;
+			button_runs_interval_track_distance.Sensitive = sensitive;
 		} else {
-			extra_window_runs_label_distance.Visible = show;
-			extra_window_runs_spinbutton_distance.Visible = show;
-			extra_window_runs_label_distance_units.Visible = show;
-		
-			extra_window_runs_label_distance.Sensitive = sensitive;
-			extra_window_runs_spinbutton_distance.Sensitive = sensitive;
-			extra_window_runs_label_distance_units.Sensitive = sensitive;
+			button_runs_simple_track_distance.Visible = show;
+			button_runs_simple_track_distance.Sensitive = sensitive;
 		}
 	}
 	
@@ -1152,6 +1142,109 @@ public partial class ChronoJumpWindow
 		extra_window_runs_interval_label_limit_units.Sensitive = sensitive;
 	}
 
+	// ----
+	// ---- start of track distance
+	// ----
+
+	// ---- 1) gui calls
+
+	private void on_button_runs_simple_track_distance_clicked (object o, EventArgs args)
+	{
+		string text = Catalog.GetString("Lap distance (between barriers)");
+		string labelAtLeft = Catalog.GetString("Distance in meters");
+
+		if(currentRunType.Name == "Margaria")
+		{
+			text = Catalog.GetString("Vertical distance between stairs third and nine.");
+			labelAtLeft = Catalog.GetString("Distance in millimeters");
+		}
+
+		createGenericWinForTrackDistance(true, text, labelAtLeft,
+				Convert.ToDouble(label_runs_simple_track_distance_value.Text));
+	}
+
+	private void on_button_runs_interval_track_distance_clicked (object o, EventArgs args)
+	{
+		string text = Catalog.GetString("Lap distance (between barriers)");
+		string labelAtLeft = Catalog.GetString("Distance in meters");
+
+		createGenericWinForTrackDistance(false, text, labelAtLeft,
+				Convert.ToDouble(label_runs_interval_track_distance_value.Text));
+	}
+
+	// ---- 2) create genericWin
+
+	private void createGenericWinForTrackDistance(bool simpleOrInterval, string text, string labelAtLeft, double initialValue)
+	{
+		genericWin = GenericWindow.Show(Catalog.GetString("Track distance"), text, Constants.GenericWindowShow.HBOXSPINDOUBLE2);
+
+		genericWin.LabelSpinDouble2 = labelAtLeft;
+		genericWin.SetSpinDouble2Increments(0.1, 1);
+		genericWin.SetSpinDouble2Range(0, 100000.0);
+		genericWin.SetSpinDouble2Digits(1);
+		genericWin.SetSpinDouble2Value(initialValue);
+
+		if(simpleOrInterval) {
+			genericWin.Button_accept.Clicked -= new EventHandler(on_button_runs_simple_track_distance_accepted);
+			genericWin.Button_accept.Clicked += new EventHandler(on_button_runs_simple_track_distance_accepted);
+		} else {
+			genericWin.Button_accept.Clicked -= new EventHandler(on_button_runs_interval_track_distance_accepted);
+			genericWin.Button_accept.Clicked += new EventHandler(on_button_runs_interval_track_distance_accepted);
+		}
+	}
+
+	// ---- 3) return from genericWin
+	void on_button_runs_simple_track_distance_accepted (object obj, EventArgs args)
+	{
+		genericWin.Button_accept.Clicked -= new EventHandler(on_button_runs_simple_track_distance_accepted);
+
+		label_runs_simple_track_distance_value.Text = Util.TrimDecimals(genericWin.SpinDouble2Selected.ToString(),
+				preferences.digitsNumber);
+	}
+
+	void on_button_runs_interval_track_distance_accepted (object obj, EventArgs args)
+	{
+		genericWin.Button_accept.Clicked -= new EventHandler(on_button_runs_interval_track_distance_accepted);
+
+		label_runs_interval_track_distance_value.Text = Util.TrimDecimals(genericWin.SpinDouble2Selected.ToString(),
+				preferences.digitsNumber);
+	}
+
+	// ---- end of track distance
+
+	private bool changingCheckboxesRunWithReactionTime = false;
+	private void on_check_run_simple_with_reaction_time_clicked (object o, EventArgs args)
+	{
+		//avoid cyclic calls
+		if(changingCheckboxesRunWithReactionTime)
+			return;
+
+		changingCheckboxesRunWithReactionTime = true;
+		check_run_interval_with_reaction_time.Active = check_run_simple_with_reaction_time.Active;
+		changingCheckboxesRunWithReactionTime = false;
+	}
+	private void on_check_run_interval_with_reaction_time_clicked (object o, EventArgs args)
+	{
+		//avoid cyclic calls
+		if(changingCheckboxesRunWithReactionTime)
+			return;
+
+		changingCheckboxesRunWithReactionTime = true;
+		check_run_simple_with_reaction_time.Active = check_run_interval_with_reaction_time.Active;
+		changingCheckboxesRunWithReactionTime = false;
+	}
+
+	//valid for simple and for intervallic
+	private void on_button_run_with_reaction_time_help_clicked (object o, EventArgs args)
+	{
+		new DialogMessage(Constants.MessageTypes.INFO,
+				"TODO" +
+				"\nneed new device (introduce name)" +
+				"\ntest will start when person is at start pad and push button is pressed" +
+				"\nreaction time will be in ms and as a comment on Description"
+				);
+	}
+
 }
 
 
