@@ -546,7 +546,9 @@ public class SessionAddEditWindow {
 	void on_button_sport_add_clicked (object o, EventArgs args)
 	{
 		LogB.Information("sport add clicked");
-		genericWin = GenericWindow.Show(Catalog.GetString("Add new sport to database"), Constants.GenericWindowShow.ENTRY);
+		genericWin = GenericWindow.Show(Catalog.GetString("Add sport"),
+				Catalog.GetString("Add new sport to database"),
+				Constants.GenericWindowShow.ENTRY);
 		genericWin.Button_accept.Clicked += new EventHandler(on_sport_add_accepted);
 	}
 
@@ -590,6 +592,7 @@ public class SessionAddEditWindow {
 		//check if name of session exists (is owned by other session),
 		//but all is ok if the name is the same as the old name (editing)
 		string name = Util.RemoveTildeAndColon(entry_name.Text);
+		name = Util.RemoveChar(name, '/');
 
 		bool sessionNameExists = Sqlite.Exists (false, Constants.SessionTable, name);
 		if(sessionNameExists && name != currentSession.Name ) {
@@ -787,12 +790,19 @@ public class SessionLoadWindow {
 
 	private static int dateColumnCompare (TreeModel model, TreeIter iter1, TreeIter iter2)
 	{
-		DateTime val1;
-		DateTime val2;
-		val1 = UtilDate.FromSql(model.GetValue(iter1, 1).ToString());
-		val2 = UtilDate.FromSql(model.GetValue(iter2, 1).ToString());
+		var dt1String = (model.GetValue(iter1, 1).ToString());
+		var dt2String = (model.GetValue(iter2, 1).ToString());
 
-		return DateTime.Compare(val1, val2);
+		DateTime dt1;
+		DateTime dt2;
+
+		var converted1 = DateTime.TryParse(dt1String, out dt1);
+		var converted2 = DateTime.TryParse(dt2String, out dt2);
+
+		if(converted1 && converted2)
+			return DateTime.Compare(dt1, dt2);
+		else
+			return 0;
 	}
 	
 	static public SessionLoadWindow Show (Gtk.Window parent, WindowType type)
