@@ -31,6 +31,7 @@ using Mono.Unix;
 
 public class Json
 {
+	private bool connected; //know if server is connected. Do it when there's a change on RFID (pulse)
 	public string ResultMessage;
 	static string serverUrl = "http://api.chronojump.org:8080";
 	//string serverUrl = "http://192.168.200.1:8080";
@@ -182,12 +183,19 @@ public class Json
 		if(currentVersion != lastVersionPublished)
 			updateStr = "\n\n" + Catalog.GetString("Update software at ") + "www.chronojump.org";
 			*/
-			
-		this.ResultMessage =		
+
+		string str =
 			Catalog.GetString("Installed version is: ") + currentVersion + "\n" + 
 			Catalog.GetString("Last version published: ") + lastVersionPublished;
 			// + updateStr;
 			//TODO: add updateStr again when resolved that a experimental 1.7.0-xxx is more advanced than a stable 1.7.0
+
+		if(currentVersion == lastVersionPublished)
+			str += "\n\n" + Catalog.GetString("Your software is updated!");
+		else
+			str += "\n\n" + Catalog.GetString("Update software at ") + "www.chronojump.org";
+
+		this.ResultMessage = str;
 		
 		//ChronojumpUpdated = (currentVersion == ResultMessage);
 
@@ -277,6 +285,7 @@ public class Json
 
 	public Person GetPersonByRFID(string rfid)
 	{
+		connected = false;
 		Person person = new Person(-1);
 
 		// Create a request using a URL that can receive a post.
@@ -338,6 +347,7 @@ public class Json
 			person = personDeserialize(responseFromServer);
 		}
 
+		connected = true;
 		return person;
 
 	}
@@ -403,6 +413,8 @@ public class Json
 
 	public List<Task> GetTasks(int personID, int stationID)
 	{
+		connected = false;
+
 		// Create a request using a URL that can receive a post.
 		WebRequest request = WebRequest.Create (serverUrl + "/getTasks");
 
@@ -452,6 +464,8 @@ public class Json
 
 		LogB.Information("GetTasks: " + responseFromServer);
 
+		connected = true;
+
 		if(responseFromServer == "" || responseFromServer == "[]")
 		{
 			LogB.Information(" Empty ");
@@ -781,12 +795,20 @@ public class Json
 	}
 	*/
 
-	public bool UploadSprintData(int personId, Sprint sprint, double k, double vmax, double amax, double fmax, double pmax )
+	public bool UploadSprintData(int personId, Sprint sprint, List<double> splitTimesL,
+			double k, double vmax, double amax, double fmax, double pmax )
 	{
 		LogB.Information("calling upload sprint");
 		// Create a request using a URL that can receive a post.
 		WebRequest request = WebRequest.Create (serverUrl + "/uploadSprintData");
 
+
+		/*
+		LogB.Information("UploadSprintData doubles:");
+		foreach(double d in splitTimesL)
+			LogB.Information(d.ToString());
+			*/
+
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
@@ -799,7 +821,25 @@ public class Json
 
 		json.Add("personId", personId);
 		json.Add("distances", sprint.Positions);
-		json.Add("times", sprint.SplitTimes);
+		//json.Add("times", sprint.SplitTimes);
+		json.Add("t1", splitTimesL[1]);
+
+		//splitTimesL starts with a 0 that is not passed
+		if(splitTimesL.Count >= 3)
+			json.Add("t2", splitTimesL[2] - splitTimesL[1]); //return lap (partial time) and not split (accumulated time)
+		else
+			json.Add("t2", "");
+
+		if(splitTimesL.Count >= 4)
+			json.Add("t3", splitTimesL[3] - splitTimesL[2]);
+		else
+			json.Add("t3", "");
+
+		if(splitTimesL.Count >= 5)
+			json.Add("t4", splitTimesL[4] - splitTimesL[3]);
+		else
+			json.Add("t4", "");
+
 		json.Add("k", k);
 		json.Add("vmax", vmax);
 		json.Add("amax", amax);
@@ -842,7 +882,7 @@ public class Json
 		dataStream.Close ();
 		response.Close ();
 
-		this.ResultMessage = "Encoder data sent.";
+		this.ResultMessage = "Sprint data sent.";
 		return true;
 	}
 
@@ -932,6 +972,9 @@ public class Json
 		return true;
 	}
 
+	public bool Connected {
+		get { return connected; }
+	}
 
 	~Json() {}
 }
@@ -1048,7 +1091,7 @@ public class UploadEncoderDataObject
 			if(compareTo > highest)
 				highest = compareTo;
 		}
-		return Convert.ToInt32(Util.DivideSafeFraction(100.0 * (highest - lowest), highest));
+		return Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest));
 	}
 }
 
