@@ -21,15 +21,18 @@
 using System;
 using System.Collections.Generic; //List<T>
 
+//TODO: new code should use Timespan to make operations with minutes, seconds ...
 public class LastTestTime
 {
 	private int personID;
+	private string personName;
 	private DateTime time;
 
 	//constructor
-	public LastTestTime(int pID)
+	public LastTestTime(int pID, string pName)
 	{
 		this.personID = pID;
+		this.personName = pName;
 		this.time = DateTime.Now;
 	}
 	
@@ -50,7 +53,7 @@ public class LastTestTime
 		get {
 			TimeSpan ts = DateTime.Now.Subtract(time);
 			if(ts.TotalMinutes >= 60)
-				return maxTimeString; //TODO: check if this is correctly sorted on treeview persons
+				return maxTimeString;
 
 			//add a 0 if values are <10 to order them correctly on treeview persons
 			int m = ts.Minutes;
@@ -66,6 +69,13 @@ public class LastTestTime
 		}
 	}
 
+	//better a double because an int on > 30" marks as 1 minute
+	public double GetTotalMinutes()
+	{
+		TimeSpan ts = DateTime.Now.Subtract(time);
+		return ts.TotalMinutes;
+	}
+
 	public static int GetSeconds(string restedTime)
 	{
 		if(restedTime == null || restedTime == "")
@@ -87,21 +97,28 @@ public class LastTestTime
 	{
 		get { return personID; } 
 	}
+
+	public string PersonName
+	{
+		get { return personName; }
+	}
 }
 
 public class RestTime
 {
-	private List<LastTestTime> list;
+	private List<LastTestTime> listAll;
+	private List<LastTestTime> listLastMin; //for Compujump, list of last 20' on the top
 
 	public RestTime()
 	{
 		//initialize list when Chronojump starts
-		list = new List<LastTestTime>();
+		listAll = new List<LastTestTime>();
+		listLastMin = new List<LastTestTime>();
 	}
 	
 	public string RestedTime(int personID)
 	{
-		foreach(LastTestTime ltt in list)
+		foreach(LastTestTime ltt in listAll)
 			if(ltt.PersonID == personID)
 				return ltt.RestedTime;
 		
@@ -110,7 +127,7 @@ public class RestTime
 
 	public bool CompujumpPersonNeedLogout(int personID)
 	{
-		foreach(LastTestTime ltt in list)
+		foreach(LastTestTime ltt in listAll)
 			if(ltt.PersonID == personID)
 			{
 				if(LastTestTime.GetSeconds(ltt.RestedTime) > 180) //3 min
@@ -123,36 +140,75 @@ public class RestTime
 		return true;
 	}
 
-	public void AddOrModify(int personID, bool print)
+	public void AddOrModify(int personID, string personName, bool print)
 	{
-		if(exists(personID))
-			modifyRestTime(personID);
+		//listAll
+		if(exists(listAll, personID))
+			modifyRestTime(listAll, personID);
 		else
-			addRestTime(personID);
+			addRestTime(listAll, personID, personName);
 
 		if(print)
-			foreach(LastTestTime ltt in list)
+			foreach(LastTestTime ltt in listAll)
 				LogB.Information(ltt.ToString());
+
+		//listLastMin
+		if(exists(listLastMin, personID))
+			modifyRestTime(listLastMin, personID);
+		else {
+			//add but have only five values
+			if(listLastMin.Count == 5)
+			{
+				int secondsMax = 0;
+				int seconds;
+				int highestTimePos = 0;
+				for (int i = listLastMin.Count - 1; i >= 0; i--)
+				{
+					seconds = LastTestTime.GetSeconds(listLastMin[i].RestedTime);
+					if(seconds > secondsMax)
+					{
+						secondsMax = seconds;
+						highestTimePos = i;
+					}
+				}
+				listLastMin.RemoveAt(highestTimePos);
+			}
+
+			//add the new value
+			addRestTime(listLastMin, personID, personName);
+		}
 	}
 
-	private bool exists(int personID)
+	private bool exists(List<LastTestTime> l, int personID)
 	{
-		foreach(LastTestTime ltt in list)
+		foreach(LastTestTime ltt in l)
 			if(ltt.PersonID == personID)
 				return true;
 		
 		return false;
 	}
 	
-	private void addRestTime(int personID)
+	private void addRestTime(List<LastTestTime> l, int personID, string personName)
 	{
-		list.Add(new LastTestTime(personID));
+		l.Add(new LastTestTime(personID, personName));
 	}
 	
-	private void modifyRestTime(int personID)
+	private void modifyRestTime(List<LastTestTime> l, int personID)
 	{
-		foreach(LastTestTime ltt in list)
+		foreach(LastTestTime ltt in l)
 			if(ltt.PersonID == personID)
 				ltt.Update();
 	}
+
+	public List<LastTestTime> LastMinList()
+	{
+		//remove reverse in order to not hung the program on removing while iteratin
+		for (int i = listLastMin.Count - 1; i >= 0; i--)
+		{
+			if(listLastMin[i].GetTotalMinutes() > 10 )//10 minutes
+				listLastMin.RemoveAt(i);
+		}
+
+		return listLastMin;
+	}
 }
