@@ -36,6 +36,22 @@ class SqlitePreferences : Sqlite
 	public const string EncoderMassGravitatory = "encoderMassGravitatory";
 	public const string EncoderWeightsInertial = "encoderWeightsInertial";
 
+	public const string ForceSensorTareDateTimeStr = "forceSensorTareDateTime";
+	public const string ForceSensorTareStr = "forceSensorTare";
+	public const string ForceSensorCalibrationDateTimeStr = "forceSensorCalibrationDateTime";
+	public const string ForceSensorCalibrationWeightStr = "forceSensorCalibrationWeight";
+	public const string ForceSensorCalibrationFactorStr = "forceSensorCalibrationFactor";
+
+	public const string EncoderRhythmActiveStr = "encoderRhythmActive";
+	public const string EncoderRhythmRepsOrPhasesStr = "encoderRhythmRepsOrPhases";
+	public const string EncoderRhythmRepSecondsStr = "encoderRhythmRepSeconds";
+	public const string EncoderRhythmEccSecondsStr = "encoderRhythmEccSeconds";
+	public const string EncoderRhythmConSecondsStr = "encoderRhythmConSeconds";
+	public const string EncoderRhythmRestRepsSecondsStr = "encoderRhythmRestRepsSeconds";
+	public const string EncoderRhythmRestAfterEccStr = "encoderRhythmRestAfterEcc";
+	public const string EncoderRhythmRepsClusterStr = "encoderRhythmRepsCluster";
+	public const string EncoderRhythmRestClustersSecondsStr = "encoderRhythmRestClustersSeconds";
+
 	protected internal static new void createTable()
 	{
 		dbcmd.CommandText = 
@@ -63,6 +79,7 @@ class SqlitePreferences : Sqlite
 				//appearance
 				Insert ("maximized", Preferences.MaximizedTypes.NO.ToString(), dbcmdTr);
 				Insert ("personWinHide", "False", dbcmdTr);
+				Insert ("personPhoto", "True", dbcmdTr);
 				Insert ("encoderCaptureShowOnlyBars", "False", dbcmdTr);
 				Insert ("digitsNumber", "3", dbcmdTr);
 				Insert ("showPower", "True", dbcmdTr);
@@ -77,8 +94,10 @@ class SqlitePreferences : Sqlite
 				Insert ("heightPreferred", "False", dbcmdTr);
 				Insert ("metersSecondsPreferred", "True", dbcmdTr);
 				Insert ("language", "", dbcmdTr); 
+				Insert ("crashLogLanguage", "", dbcmdTr);
 				Insert ("allowFinishRjAfterTime", "True", dbcmdTr); 
 				Insert ("volumeOn", "True", dbcmdTr); 
+				Insert (Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_0_1.ToString(), dbcmdTr);
 				Insert ("videoOn", "True", dbcmdTr); 
 				Insert ("evaluatorServerID", "-1", dbcmdTr);
 				Insert ("versionAvailable", "", dbcmdTr);
@@ -111,7 +130,7 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderCaptureCheckFullyExtendedValue", "4", dbcmdTr);
 				Insert ("encoderCaptureBarplotFontSize", "14", dbcmdTr);
 				Insert ("encoderShowStartAndDuration", "False", dbcmdTr);
-				Insert ("encoderCaptureCutByTriggers", "False", dbcmdTr);
+				Insert ("encoderCaptureCutByTriggers", Preferences.TriggerTypes.NO_TRIGGERS.ToString(), dbcmdTr);
 				Insert ("encoderPropulsive", "True", dbcmdTr);
 				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
 				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
@@ -122,20 +141,33 @@ class SqlitePreferences : Sqlite
 
 				if(encoderExercises.Count > 0) {
 					EncoderExercise ex = (EncoderExercise) encoderExercises[0];
-					Insert (EncoderExerciseIDGravitatory, ex.uniqueID.ToString());
-					Insert (EncoderExerciseIDInertial, ex.uniqueID.ToString());
+					Insert (EncoderExerciseIDGravitatory, ex.uniqueID.ToString(), dbcmdTr);
+					Insert (EncoderExerciseIDInertial, ex.uniqueID.ToString(), dbcmdTr);
 				}
 				else {
-					Insert (EncoderExerciseIDGravitatory, "1");
-					Insert (EncoderExerciseIDInertial, "1");
+					Insert (EncoderExerciseIDGravitatory, "1", dbcmdTr);
+					Insert (EncoderExerciseIDInertial, "1", dbcmdTr);
 				}
 
-				Insert (EncoderContractionGravitatory, Constants.Concentric);
-				Insert (EncoderContractionInertial, Constants.EccentricConcentric);
-				Insert (EncoderLateralityGravitatory, "RL");
-				Insert (EncoderLateralityInertial, "RL");
-				Insert (EncoderMassGravitatory, "10");
-				Insert (EncoderWeightsInertial, "0");
+				Insert (EncoderContractionGravitatory, Constants.Concentric, dbcmdTr);
+				Insert (EncoderContractionInertial, Constants.EccentricConcentric, dbcmdTr);
+				Insert (EncoderLateralityGravitatory, "RL", dbcmdTr);
+				Insert (EncoderLateralityInertial, "RL", dbcmdTr);
+				Insert (EncoderMassGravitatory, "10", dbcmdTr);
+				Insert (EncoderWeightsInertial, "0", dbcmdTr);
+
+				//encoderRhythm
+				EncoderRhythm er = new EncoderRhythm();
+				Insert (EncoderRhythmActiveStr, er.Active.ToString(), dbcmdTr);
+				Insert (EncoderRhythmRepsOrPhasesStr, er.RepsOrPhases.ToString(), dbcmdTr);
+				Insert (EncoderRhythmRepSecondsStr, Util.ConvertToPoint(er.RepSeconds), dbcmdTr);
+				Insert (EncoderRhythmEccSecondsStr, Util.ConvertToPoint(er.EccSeconds), dbcmdTr);
+				Insert (EncoderRhythmConSecondsStr, Util.ConvertToPoint(er.ConSeconds), dbcmdTr);
+				Insert (EncoderRhythmRestRepsSecondsStr, Util.ConvertToPoint(er.RestRepsSeconds), dbcmdTr);
+				Insert (EncoderRhythmRestAfterEccStr, er.RestAfterEcc.ToString(), dbcmdTr);
+				Insert (EncoderRhythmRepsClusterStr, Util.ConvertToPoint(er.RepsCluster), dbcmdTr);
+				Insert (EncoderRhythmRestClustersSecondsStr, Util.ConvertToPoint(er.RestClustersSeconds), dbcmdTr);
+
 
 				Insert ("videoDevice", "0", dbcmdTr); //first
 				Insert ("inertialmomentum", "0.01", dbcmdTr);
@@ -145,6 +177,11 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), dbcmdTr); 
 				Insert ("email", "", dbcmdTr);
 				Insert ("muteLogs", "False", dbcmdTr);
+				Insert (ForceSensorTareDateTimeStr, "", dbcmdTr);
+				Insert (ForceSensorTareStr, "-1", dbcmdTr); //result value from sensor. Decimal is point!!
+				Insert (ForceSensorCalibrationDateTimeStr, "", dbcmdTr);
+				Insert (ForceSensorCalibrationWeightStr, "-1", dbcmdTr);
+				Insert (ForceSensorCalibrationFactorStr, "-1", dbcmdTr); //result value from sensor. Decimal is point!!
 				
 				//removed on 1.37
 				//Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
@@ -219,7 +256,9 @@ class SqlitePreferences : Sqlite
 
 		return myReturn;
 	}
-	
+
+	//Some are sent to preferences window, others not
+	//check: preferences.cs at the top
 	public static Preferences SelectAll () 
 	{
 		Sqlite.Open();
@@ -236,12 +275,13 @@ class SqlitePreferences : Sqlite
 			//LogB.Debug("Reading preferences");
 			//LogB.Information(reader[0].ToString() + ":" + reader[1].ToString());
 
-	 		//these are sent to preferences window
 			if(reader[0].ToString() == "maximized")
 				preferences.maximized = (Preferences.MaximizedTypes)
 					Enum.Parse(typeof(Preferences.MaximizedTypes), reader[1].ToString());
 			else if(reader[0].ToString() == "personWinHide")
 				preferences.personWinHide = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "personPhoto")
+				preferences.personPhoto = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureShowOnlyBars")
 				preferences.encoderCaptureShowOnlyBars = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showPower")
@@ -286,7 +326,8 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "encoderShowStartAndDuration")
 				preferences.encoderShowStartAndDuration = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureCutByTriggers")
-				preferences.encoderCaptureCutByTriggers = reader[1].ToString() == "True";
+				preferences.encoderCaptureCutByTriggers = (Preferences.TriggerTypes)
+					Enum.Parse(typeof(Preferences.TriggerTypes), reader[1].ToString());
 			//encoder other
 			else if(reader[0].ToString() == "encoderPropulsive")
 				preferences.encoderPropulsive = reader[1].ToString() == "True";
@@ -296,6 +337,32 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "encoder1RMMethod")
 				preferences.encoder1RMMethod = (Constants.Encoder1RMMethod) 
 					Enum.Parse(typeof(Constants.Encoder1RMMethod), reader[1].ToString()); 
+
+			//encoder rhythm
+			else if(reader[0].ToString() == EncoderRhythmActiveStr)
+				preferences.encoderRhythmActive = reader[1].ToString() == "True"; //bool
+			else if(reader[0].ToString() == EncoderRhythmRepsOrPhasesStr)
+				preferences.encoderRhythmRepsOrPhases = reader[1].ToString() == "True"; //bool
+			else if(reader[0].ToString() == EncoderRhythmRepSecondsStr)
+				preferences.encoderRhythmRepSeconds = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == EncoderRhythmEccSecondsStr)
+				preferences.encoderRhythmEccSeconds = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == EncoderRhythmConSecondsStr)
+				preferences.encoderRhythmConSeconds = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == EncoderRhythmRestRepsSecondsStr)
+				preferences.encoderRhythmRestRepsSeconds = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == EncoderRhythmRestAfterEccStr)
+				preferences.encoderRhythmRestAfterEcc = reader[1].ToString() == "True"; //bool
+			else if(reader[0].ToString() == EncoderRhythmRepsClusterStr)
+				preferences.encoderRhythmRepsCluster = Convert.ToInt32(reader[1].ToString()); //int
+			else if(reader[0].ToString() == EncoderRhythmRestClustersSecondsStr)
+				preferences.encoderRhythmRestClustersSeconds = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+
 			//video... other
 			else if(reader[0].ToString() == "videoDevice")
 				preferences.videoDeviceNum = Convert.ToInt32(reader[1].ToString());
@@ -303,15 +370,19 @@ class SqlitePreferences : Sqlite
 				preferences.CSVExportDecimalSeparator = reader[1].ToString();
 			else if(reader[0].ToString() == "language")
 				preferences.language = reader[1].ToString();
+			else if(reader[0].ToString() == "crashLogLanguage")
+				preferences.crashLogLanguage = reader[1].ToString();
 			else if(reader[0].ToString() == "RGraphsTranslate")
 				preferences.RGraphsTranslate = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "useHeightsOnJumpIndexes")
 				preferences.useHeightsOnJumpIndexes = reader[1].ToString() == "True";
-	 		//these are NOT sent to preferences window
 			else if(reader[0].ToString() == "allowFinishRjAfterTime")
 				preferences.allowFinishRjAfterTime = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "volumeOn")
 				preferences.volumeOn = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == Preferences.GstreamerStr)
+				preferences.gstreamer = (Preferences.GstreamerTypes)
+					Enum.Parse(typeof(Preferences.GstreamerTypes), reader[1].ToString());
 			else if(reader[0].ToString() == "videoOn")
 				preferences.videoOn = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "evaluatorServerID")
@@ -320,7 +391,6 @@ class SqlitePreferences : Sqlite
 				preferences.versionAvailable = reader[1].ToString();
 			else if(reader[0].ToString() == "runSpeedStartArrival")
 				preferences.runSpeedStartArrival = reader[1].ToString() == "True";
-			
 			else if(reader[0].ToString() == "runDoubleContactsMode")
 				preferences.runDoubleContactsMode = (Constants.DoubleContact) 
 					Enum.Parse(typeof(Constants.DoubleContact), reader[1].ToString()); 
@@ -337,6 +407,24 @@ class SqlitePreferences : Sqlite
 				preferences.thresholdRuns = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "thresholdOther")
 				preferences.thresholdOther = Convert.ToInt32(reader[1].ToString());
+
+			//force sensor tare
+			else if(reader[0].ToString() == ForceSensorTareDateTimeStr)
+				preferences.forceSensorTareDateTime = reader[1].ToString();
+			else if(reader[0].ToString() == ForceSensorTareStr)
+				preferences.forceSensorTare = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+
+			//force sensor calibrate
+			else if(reader[0].ToString() == ForceSensorCalibrationDateTimeStr)
+				preferences.forceSensorCalibrationDateTime = reader[1].ToString();
+			else if(reader[0].ToString() == ForceSensorCalibrationWeightStr)
+				preferences.forceSensorCalibrationWeight = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == ForceSensorCalibrationFactorStr)
+				preferences.forceSensorCalibrationFactor = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+
 			//advanced tab
 			else if(reader[0].ToString() == "digitsNumber")
 				preferences.digitsNumber = Convert.ToInt32(reader[1].ToString());
@@ -344,7 +432,6 @@ class SqlitePreferences : Sqlite
 				preferences.askDeletion = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "muteLogs")
 				preferences.muteLogs = reader[1].ToString() == "True";
-
 			else if(reader[0].ToString() == "machineID")
 				preferences.machineID = reader[1].ToString();
 			else if(reader[0].ToString() == "multimediaStorage")
