@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -89,7 +89,7 @@ class SqliteRunInterval : SqliteRun
 		return myLast;
 	}
 
-	public new static string[] SelectRuns(bool dbconOpened, int sessionID, int personID, string filterType) 
+	public static string[] SelectRuns(bool dbconOpened, int sessionID, int personID, string filterType) 
 	{
 		if(!dbconOpened)
 			Sqlite.Open();
