@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -65,13 +65,11 @@ public class StatChronojumpProfile : Stat
 	
 	public override void PrepareData() 
 	{
-		string sessionString = obtainSessionSqlString(sessions, "jump");
-		bool multisession = false;
+		//string sessionString = obtainSessionSqlString(sessions, "jump");
 		//if(sessions.Count > 1) {
 		//	multisession = true;
 		//}
 
-		string indexType = "ChronojumpProfile";
 		/*
 		if(statsJumpsType == 3) { //avg of each jumper
 			if(multisession) {
@@ -107,7 +105,7 @@ public class StatChronojumpProfile : Stat
 				//			statsJumpsType, limit),
 				//		true, dataColumns);
 
-				string [] sessionFull = sessions[0].ToString().Split(new char[] {':'});
+				//string [] sessionFull = sessions[0].ToString().Split(new char[] {':'});
 				//SqliteStat.SelectChronojumpProfile(sessionFull[0]);
 				//processDataSimpleSession (SqliteStat.SelectChronojumpProfile(sessionFull[0]), true, dataColumns);
 			//}
