@@ -94,6 +94,7 @@ public class Util
 	
 	//used for load from the database all numbers with correct decimal separator (locale defined)
 	//used also for the tvString, tcString, and runIntervalTimesString
+	//also used for reading . data coming from force sensor
 	public static string ChangeDecimalSeparator(string myString) {
 		if(myString == "") {
 			return "0";
@@ -990,12 +991,39 @@ public class Util
 	public static string GetVideoFileNameOnlyFolder (int sessionID) {
 		return GetVideoSessionDir(sessionID);
 	}
+
+	/*
+	 * --------------------- GetPhoto stuff
+	 */
+	//returns the jpg, png or ""
+	public static string UserPhotoURL (bool small, int uniqueID)
+	{
+		string jpeg = GetPhotoFileName (small, uniqueID);
+		if(File.Exists(jpeg))
+			return jpeg;
+
+		string png = GetPhotoPngFileName (small, uniqueID);
+		if(File.Exists(png))
+			return png;
+
+		return "";
+	}
 	
+	//jpg
 	public static string GetPhotoFileName (bool small, int uniqueID) {
 		return GetPhotosDir(small) + Path.DirectorySeparatorChar + uniqueID.ToString() +
 			GetMultimediaExtension(Constants.MultimediaItems.PHOTO);
 	}
-	
+	//png
+	public static string GetPhotoPngFileName (bool small, int uniqueID) {
+		return GetPhotosDir(small) + Path.DirectorySeparatorChar + uniqueID.ToString() +
+			GetMultimediaExtension(Constants.MultimediaItems.PHOTOPNG);
+	}
+
+	/*
+	 * --------------------- End of GetPhoto stuff
+	 */
+
 	public static string GetVideoTempFileName() {
 		return Path.Combine(
 				Path.GetTempPath(), Constants.VideoTemp + 
@@ -1011,11 +1039,23 @@ public class Util
 				Path.GetTempPath(), fileName + GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
 	}
 	
+	public static string GetMultimediaExtension (string filename)
+	{
+		if(UtilMultimedia.GetImageType(filename) == UtilMultimedia.ImageTypes.JPEG)
+			return Constants.ExtensionPhoto;
+		if(UtilMultimedia.GetImageType(filename) == UtilMultimedia.ImageTypes.PNG)
+			return Constants.ExtensionPhotoPng;
+
+		return "";
+	}
+
 	public static string GetMultimediaExtension (Constants.MultimediaItems multimediaItem) {
 		if(multimediaItem == Constants.MultimediaItems.VIDEO)
 			return Constants.ExtensionVideo;
-		else //multimediaItem = Constants.MultimediaItems.PHOTO
+		else if(multimediaItem == Constants.MultimediaItems.PHOTO)
 			return Constants.ExtensionPhoto;
+		else //multimediaItem == Constants.MultimediaItems.PHOTOPNG
+			return Constants.ExtensionPhotoPng;
 	}
 			
 	public static bool CopyTempVideo(int sessionID, Constants.TestTypes type, int uniqueID) {
@@ -1316,9 +1356,14 @@ public class Util
 	 * ------------- sound stuff -----------
 	 */
 
-	public static void PlaySound (Constants.SoundTypes mySound, bool volumeOn) {
+	public enum SoundCodes { VOLUME_OFF, OK, PROBLEM_NO_FILE, PROBLEM_OTHER };
+	public static bool TestSound;
+
+	public static SoundCodes PlaySound (Constants.SoundTypes mySound,
+			bool volumeOn, Preferences.GstreamerTypes gstreamer)
+	{
 		if ( ! volumeOn )
-			return;
+			return SoundCodes.VOLUME_OFF;
 		
 		/*
 		 * Using GstreamerMethod because .Net method makes crash some Linux ALSA,
@@ -1327,12 +1372,13 @@ public class Util
 
 		if( UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX ||
 				UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX )
-			playSoundGstreamer(mySound);
+			return playSoundGstreamer(mySound, gstreamer);
 		else //Windows
-			playSoundWindows(mySound);
+			return playSoundWindows(mySound);
 	}
 	
-	private static void playSoundGstreamer (Constants.SoundTypes mySound) 
+//	private enum gstreamerVersions { GST_0_1, GST_1_0 }
+	private static SoundCodes playSoundGstreamer (Constants.SoundTypes mySound, Preferences.GstreamerTypes gstreamer)
 	{
 		string fileName = "";
 		switch(mySound) {
@@ -1357,29 +1403,52 @@ public class Util
 
 		if(! File.Exists(fileName)) {
 			LogB.Warning("Cannot found this sound file: " + fileName);
-			return;
+			return SoundCodes.PROBLEM_NO_FILE;
 		}
 
+		Process p;
 		try {
 			ProcessStartInfo pinfo = new ProcessStartInfo();
-			string pBin="gst-launch-0.10";
+
+			string pBin= "";
+			if(gstreamer == Preferences.GstreamerTypes.GST_0_1) {
+				pBin="gst-launch-0.10";
+				pinfo.Arguments = "playbin2 " + @"uri=file://" + fileName;
+			}
+			else { //gstreamer == Preferences.GstreamerTypes.GST_1_0
+				pBin="gst-launch-1.0";
+				pinfo.Arguments = "playbin " + @"uri=file://" + fileName;
+			}
 
 			pinfo.FileName=pBin;
-			pinfo.Arguments = "playbin2 " + @"uri=file://" + fileName;
+
 			LogB.Information("Arguments:", pinfo.Arguments);
 			pinfo.CreateNoWindow = true;
 			pinfo.UseShellExecute = false;
 
-			Process p = new Process();
+			if(TestSound)
+				pinfo.RedirectStandardError = true;
+
+			p = new Process();
 			p.StartInfo = pinfo;
 			p.Start();
 		} catch {
 			LogB.Error("Cannot playSoundGstreamer");
+			return SoundCodes.PROBLEM_OTHER;
 		}
+
+		if(TestSound)
+		{
+			string stderr = p.StandardError.ReadToEnd ().TrimEnd ('\n');
+			if(stderr != "")
+				return SoundCodes.PROBLEM_OTHER;
+		}
+
+		return SoundCodes.OK;
 	}
 
 	//maybe in the future this method will be deprecated and it only will be used the Gstreamer method
-	private static void playSoundWindows (Constants.SoundTypes mySound) 
+	private static SoundCodes playSoundWindows (Constants.SoundTypes mySound)
 	{
 		try {
 			switch(mySound) {
@@ -1396,7 +1465,10 @@ public class Util
 			}
 		} catch {
 			LogB.Error("Cannot playSoundWindows");
+			return SoundCodes.PROBLEM_OTHER;
 		}
+
+		return SoundCodes.OK;
 	}
 	
 	/*
@@ -1640,14 +1712,21 @@ public class Util
 		return addExtensionIfNeeded(myFile, ".txt");
 	}
 	private static string addExtensionIfNeeded(string myFile, string extension)
+	{
+		if(myFile.ToLower().EndsWith(extension))
+			return myFile;
+
+		return myFile + extension;
+	}
+
+	public static string RemoveExtension(string myFile)
 	{
 		int posOfDot = myFile.LastIndexOf('.');
-		if (posOfDot == -1) 
-			myFile += extension;
-		
+		if (posOfDot > 0)
+			myFile = myFile.Substring(0, posOfDot);
+
 		return myFile;
 	}
-	
 
 	public static bool IntToBool (int myInt) {
 		if(myInt == 1)
@@ -1734,11 +1813,12 @@ public class Util
 	//avoids divide by zero
 	//thought for being between 0, 1
 	//ideal for progressBars
-	public static double DivideSafeFraction (double val1, double val2) {
-		if(val1 == 0 || val2 == 0)
+	public static double DivideSafeFraction (double num, double denom)
+	{
+		if(num == 0 || denom == 0)
 			return 0;
 
-		double result = val1 / val2;
+		double result = num / denom;
 		
 		if(result > 1)
 			result = 1;
@@ -1752,6 +1832,15 @@ public class Util
 		return DivideSafeFraction(Convert.ToDouble(val1), Convert.ToDouble(val2));
 	}
 
+	//Not restricted to values 0-1
+	public static double DivideSafe (double val1, double val2)
+	{
+		if(val1 == 0 || val2 == 0)
+			return 0;
+
+		return val1 / val2;
+	}
+
 	/*
 	//converts all values to positive
 	public static string StringValuesAbsolute (string myString) {
