@@ -37,6 +37,7 @@ public class UtilDate
 	}
 	
 	//records date & time, useful to backup database without having strange chars on filename
+	//used also on SQL when time wants to be stored also
 	public static string ToFile (DateTime dt)
 	{
 		return UtilAll.DigitsCreate(dt.Year,4) + "-" + 
@@ -52,12 +53,13 @@ public class UtilDate
 	//return datetime
 	public static DateTime FromSql (string date)
 	{
+		LogB.Information("UtilDate.FromSql date: " + date);
 		/*
 		   on report we do a session select with uniqueID = -1
 		   it returns nothing, date has nothing
 		   */
 		if(date == null || date == "")
-			return DateTime.Now;
+			return DateTime.Now; //TODO: ensure this now is year-month-day
 
 		/*
 		   maybe date format is before 0.72 (d/m/Y)
