@@ -253,6 +253,12 @@ public class UtilEncoder
 	public static string GetmifScript() {
 		return System.IO.Path.Combine(GetSprintPath(), "maximumIsometricForce.R");
 	}
+	public static string GetmifCSVFileName() {
+		return Path.Combine(Path.GetTempPath(), "cj_mif_Data.csv");
+	}
+	public static string GetmifTempFileName() {
+		return Path.Combine(Path.GetTempPath(), "cj_mif_Graph.png");
+	}
 
 	/********** end of r-scripts paths ************/
 
@@ -328,7 +334,9 @@ public class UtilEncoder
 		return operatingSystem;
 	}
 
-	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate, string triggerStr)
+	public static EncoderGraphROptions PrepareEncoderGraphOptions(
+			string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate,
+			bool cutByTriggers, string triggerStr)
 	{
 		string operatingSystem = OperatingSystemForRGraphs();
 			
@@ -383,7 +391,7 @@ public class UtilEncoder
 				title, operatingSystem,
 				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
 				Util.StringArrayToString(encoderTranslatedWordsOK,";"),
-				debug, crossValidate, triggerStr
+				debug, crossValidate, cutByTriggers, triggerStr
 				);
 	}
 
